#include "CavePackerEntityType.h"

namespace cavepacker {

namespace EntityTypes {
EntityType SOLID("solid");
EntityType GROUND("ground");
EntityType PLAYER("player");
EntityType PACKAGE("package");
EntityType TARGET("target");
}

}
