#include "CaveExpressMapFailedReasons.h"

namespace caveexpress {

namespace MapFailedReasons {
MapFailedReason FAILED_NO;
MapFailedReason FAILED_WATER_HEIGHT;
MapFailedReason FAILED_NPC_FLYING;
MapFailedReason FAILED_NPC_WALKING;
MapFailedReason FAILED_NPC_MAMMUT;
MapFailedReason FAILED_NPC_FISH;
MapFailedReason FAILED_HITPOINTS;
MapFailedReason FAILED_NO_MORE_PLAYERS;
MapFailedReason FAILED_ALL_NPCS_DIED;
MapFailedReason FAILED_SIDESCROLL;
MapFailedReason FAILED_MAX;
}

}
