2(rdrrur)rdrddluu3dllur3luurrdull3dllur3luurrdull3dllur3luurrdull3dllur3luurrdull3dllurlluurd3uluurdd4uluurdd3urrdl3rddlludrr3urrdl3rddlludrr3urrdl3rddlludrr3urrdl3rddlludrr3urrdlrrddlu3drddluull3(ddlluurr4l)ddlluurr
