3dlluluurdrrddllulurdd5rurrddllull3drruulrdd4ldllu4ruudd3l4uluur5duurruulrddlluluurdrrurrdluldlldd3r3dlldllur3u3r3dlldlu3ruu4ruulldurr2(ddll)3ur4lulu3rduurrdluldlldd3r3drruulrdd4ldllur3u3rdrrdd4ldlu5ruurruullddllur4lulu3rduurrdluldlldd3rd4ruulldurrdd3l3rddlludrruulldd4ldllur4ulu3rduurrdluldll5d5ruurrdd6ldl4urrllulu3rduurrdluld
