rd6ruuruul4drddluru5ldl6u5d5r4u3rddllul3drddluru6ldl7urul7d6ruu4rddlddrurruruu6lul3drddluru6ldl6u5d6r4urr3u3r3dlrrdrd6lul3drddluru5ldl7ulur7d5r5ur3d3ruu3lul5drddluru5ldl5u4d5r4u5ruulduu5rdd4ld4lul5drddluru6ldl7udr5d5r4u5ruulduu3rdurr4dllrruu4ld4lul5drddluru6ldl5u4d6r4u5r3u3ldduurr3drrduurrdrdlld6lul3drddluru5ldl7udl5d6ruu7rddldlluuddrrdr4u6lul3drddluru6ldl4u3d6r2(uu3r)duurrddld6lul3drddluru5ldl6udl4d6r2(uu3r)d4r3dllruuru3ld6lul3drddluru5ldl4u3d5r2(uu3r)drd6lul3drddluru6ldl6udr4d5ruu4r3d3r3uluullduu4rddlrrddldluu6lul3drddluru5ldl5u4d5r2(uu3r)duurrddld6lul3drddluru5ldl4u3d5r2(uu3r)drd6lul3drddluru6ldl5u4d6ruu3ruullul5drddluru6ldl4u
