lu3ldllu3l3ullddrurduu3ruulldrdlrr3drruulrddlluurru3ruulldrdlrr3drruulrddlluurru3ruulldrdlrr3drruulrddlluurru3ruulldrdlrr3drruuldludd3lddrrudlluurrddr3drruuldludd3lddrrulurll3ullddrluurrddlld3lddrrulurll3ullddrluurrddlld3lddrrulurll3ullddrluurrddlld3lddrrulurll3ullddrurduu3ruulldu4ruulduldrrddlldllurdrddrruldlurru3ruulldu4ruulduldrrddlldllurdrddrruldlurru3rdd2(rruu)lluullddlldurruurrdluldrrdrrddlurulddlddllurdrullulluurdldr
