dl3d4ldd3l4ur3u4luu4lul3duu4rdrd4l6d3rulldl4u3drruuruudd5r3u7lruru3luldrruu3rdd3l4urrdull4d3ruullruull3durrululdd4rurrd5lrrddl5d3rulld4r3urruuldrd6l3u3dllrddrdluldr3u6ruuldrd5l4r3d5l3ulurdruurdll4d5r3u4l4ruuldrdlr3d5l4ulur4d4r5d3ruullrrdd3l4uru4ldlurr3drluurrdd3rdd3l3udll3u3rd3ldd9ruu4lurd3ruruu3lddldrrl3u3rddlddrd7lrrdd3l3udll3u3rdldd7r3ulrruu3lddldrrurddrd7lrrdd3luull3urr3d3rdd4r4ull3u3rddllrruu3lddldrrurddrd8l3ull3drl3ull2(drur)d
