#pragma once

#include "network/IProtocolMessage.h"
#include "caveexpress/shared/network/ProtocolMessageTypes.h"

namespace caveexpress {

PROTOCOL_CLASS_SIMPLE(DropMessage, protocol::PROTO_DROP);

}
