5(rd)r5(lu)u5(lu)l6(rd)d5(rd)d4l5(urd3l)uruld5(d3ruulrdl)d4ruullrrddluluurd2(luulululu)luluu4r5(dlu3r)dldruu3lddrluullddrluurr2(dru3l)d2(rldruu3ld)rldruu4lddrrlluurdr3d4(rd)drdrdr4d14luulull4urdrdull3u4(rd)r3d3u3(lu)ll3u7(rd)u5(lu)ll3u8(rd)u6(lu)ll9drrdrdd14r4u4(lu)ululul4u9l9(dr)d8(ul)uurrdlu3rdld6(dr)d6(ul)uu3r3lddrud3lurluurrddrdluululdu4rdll3rdllddrul3u4r3d3lddruluuruurr4dllu3druluurrdrdllddruluurrdrdll4u6druurrdlldluur3druuruldrrddlrrdrdr4d4l7urulldldrur3(rd)r4d4l7urulddrrdldluurul7dll3url3drr3ulurdlldrurd4ullurdrddlurr3uld3l3ulurlluuddrruulr6d4rddllururd3lurdrruuld3luurdldrrll4ul3(lu)u3l6(dr)l4(ul)uu3l10(dr)3drr3u10(lu)lldl11drrdrdd14r4ulu3lruuldllurlddurdrll3ul6(lu)u3l10(dr)ruul7(lu)l6(rd)rr6(ul)r3(dr)r4drrdrruulldlluurdrruldll3ul3(lu)u6r7dlluurlddrruullul3(lu)u3l6(dr)d3ruuldrdrrddld3l3u2(rllulu)luluu3l7(dr)r7(ul)ldl11drrdrdd14r4ulululld3lulurdd3rddlludrr3urrdrdr4d14luulull11uru3rd4(dr)3drrddrrlddrruudd3(lu)ull3u4(lu)u3ldl11drrdrdd14r4ulullrrdr4d14luulull11uru5rdl3(rd)rruu4lrrddrululluu3l5(dr)lur3d5(lu)drdrdrrurd3lurdrr3ulluulldduurrddrrdrrull3dllulluuddrr4u5ldl11drrdrdd9ruul3uluulluluuruldlurrurrdluldl3drdrrddr3drdd9luulull11uru5r3d3u5ldl11drrdrdd9ruul3u2(luullu)rdrddrdrrddr3drdd5r4ulull3uluur3u3dlddr3drrdr4d5luul3uluullulul6u18rddrdrr4dluludrr3d4(lu)l3u3d3(rd)rr3d7(lu)d5(rd)rr3d8(lu)d6(rd)rr9ulluluu18l5drddrdrrddr3drdd14r10(ul)u9(dr)ddllur8(lu)3lr4drrdr4d4ruruuldrdd3luu4rlddllulurruulddllurruuldrdd3luurruuldrddllulurruuldrddllulurrdrdl4ulduullddrrll3u3lddrru3r3drdluulluluuldurrurr3duldldd3r6d5luul3uluullulul6u10r4d4u15ldlddrudrd3rllurulldllddrul3drurudlluurrddluruurrdrd3lurrllddll3druruudrurrdluu3rddlurulldlddllrdl3ull6drr4urudl4dll6u4rddll5drdd9ruul3uluullu4lrr3(dl)ruruuldlldduurruurdd3lddrruuru3r3(dl)lrruulurrd3ldrdrururrd4l3rdlu3rdr3drdd5l5uruuluull7dlldd4ruulluurl4urrdrddl3dll5u3r6lddrrudl2(lurr)urrdlrrddldluuddlddru3(ur)rullrrddll3rdrrdldluur4d3ruulluld3rddrruullrruurrdrd3lrrululdd4u3luuluur3urlddrruu3(dl)ddrdd3rddrr4drudrrullrululldrurd3l4uludr4d4rdd3rulu4l3r6(ul)rdr3d3u2(lduu)3lr3drrurrddrdl3ullddrluurd3l5urr3dullu3ldrrururrdr3dul3ulldlddrddrruuddllurdrurrdll3rddlluurul3ululldlddrddrrdrdrruulullddrd4r4d5r8(ul)r4(dr)ddu3(ul)drrdrddrrdrruuldrdlu8(ul)lr7(rd)rruulddr4ulddrddl3(lu)rrlddrdrr9ulluluu8ldduu8rddrdrr9dlluluul4(lu)ll7(dr)lulu3ldlluluurrllddr3d4r4l4ulururuul3dlddr3d4rdd5ruruu3(ldr3u)ldrdd5ld3ldlluluur3urrdrdduu3lddlddrdrru3ruururrlurdlldd4rddlldldrlluurr3lur4ldlluluuruu3rddrduluu3lddlddrdrrurrurdluuld3u3lddlddrdrru3r3lddullddrrllurdruulluluuruu3r3d3ruldlluurdrr3(ul)rdrrllulldrdrrurduul4d5r6ulluluu4l8drr6urruu4lddrr8dllurruulluurl3urr3duldl3u3dr3dull6ruullrdrd4lulldrrl5urddlddrddrd2(dluu)lullurrllddrrlldldlldrrlluurrllululldrruururruulldd
