ruurr3uldlrrddl3(lu)ulldurrddrdr3dllddllulu4(ul)u3luu4rdrdrrllulu4lddrrd3(dr)rululrddlulud3r2(ddrr)3ululldllulluluurdrdull3(dr)rddrr4drururd3l3ulluururrdr4d4ulullulddllurlluurdrd2(dlurul)u3ldd3rdrd3rurrdr3dllu4lulluludrdrrd4rdrr3ululldllull3u3lddrddrdrrd4rdr3(rd)dld4lululuu6luluururldlddrd6rddrdrd3ru4rudlluulul4ululldllull3u3lddrrurullrddlluurrdrrdrddrrurrdr3dllu4lulluluururrdldrl3u3lddrrurrddluruldllddrdrrd4rdr3(rd)dld4lululuu6luluururldlddrd6rddrdrd3rurru3(ul)lu4l3uddlldllu3r5lddrd6rddrdrd3rurruulul4ululld3lulullddrddllurr3lurdllddrd6rddrdrd3rurruulul4ululld3lululldduururuldrrd3lddldllddrd6rddrdrd3rurruulul4ulullu3l3rdd3lulurulr3d3rurrdr4drdduululldrdrluurdrdu3luu4luu3rdu3ldd3rurddrddlluruuluuldulldd3rurdluu3lulullddldllddrd6rddrdrd3rurd4lululuu6luluur2(urru)r3d3ruulddrdd3luurrdullddrruulluluurdrldrdrruulrddllururddldrldll3uluurdldrrlur4lddrdrluluu3rddrrddlluuruulldrddllulld3rll3u3rddrrddlluu3ruu3lrdurddu3rdrdrruurrdrd4(dr)r3(ul)rdrdd5(lu)ull3drdrrdrrulld3rdrrululldlluurdrdrurdldrd3ruu3lu4l3u3rdrrdrdulullu3l3d4r3d3rdd4lulullrrdrd4r4ulldldrrluurrdduuluulullu3l3d4rdulldrdrluurdrdulldrdrluurruululldd3luuluul3(lu)uru4rdrdrdd6rdrddldlruruulu6luululu3ldlld3(dr)rd4rdrrurrdll4ruulu6luululu3ldllddruddrdrrululrddlulud3rdd4rddlldluud3ruu3ldluuluurrdldll3drdrrdruruldluud3ruu3ldlurrddrdldluuruldd4rd2(dlurul)dlurdd4ruululrdrddllu4l3u3rddlddrruldluruurrurrdrruulu6luululu3ldlu4rdrdrdd6rdrdd5lrr3dllu4l3u3r3duu5rdlu4lddrdrruuru3lrr3dllululdll3u3rddlldluudrrddrruldluruu3r3dlldlululld3r
