rurrdrdr4u3ldu3(rd)dluludrruluurdduu3ldrrll3ullddlddrurrurrdlrddlur2(uull)ddlddrdrurrl3udrrdlu3ruuldrdlldlddruruuldlddrdruudllu4luurdld3rll4ururrdl3drruldlu4ruuldrdlldllu3(rd)dlur3u3dlludrruuld3ldluluurdld4rluurdlldlluuruururrdlddrdl3rulldld3luurd3r3l3ururrdlddrdlu4ruuldrd3l3(dl)uluurdldrurrll3ururrdl3dllddrul4urur3d
