rdrr3drruuluuruullu4ldduu4rdrrddld3lu6ldl3udd5r3urrdluldduu4rdrrddld3lu6ldluud5r3u4rd3lulddu6rddld3lu6l4r4d3lurrdr4urrd3rdrdd4lulldllurdr3uddrrdrru4lrrd4ruululldulu5l3r4dllurdr3uddrrdrruluulu4ldlu5rdrdd3ldllurdr3udd3ruulu4lullrd5rd3rdrd6ldllurdr3udd3ruulu4ldlluuddru5rdrrdrd5ldllurdr3udd3ruulu5l5rd3ruuru4lulldduurrd3r3d3lu4luld3r3urrdlulddu5r3d3lu4ldl3urul
