drurdr3u2(lduulldr)ll2(ddru)drrulldllulluldlddull3ururrdl2(rdlr)ddlu3lulldrl3ururddluldrddrr5drdd4ruruurrdlr3uludrrudlddrdrrddlurddlddllurdllulluurdu3lulr3dluddllurlluulldrurrd4ulldduurrdlr3ulluurr4duulluru3rddlurrull
