dl3d4ldd3l4ur3u9luurr4urrdull4d4rduluullruu2(ll3d)r5drruu6r3u7l9ruu3ldu3rdd6luu3l3rdd4r3dllurdruudl5d3ruullrrdd3l4ullddrluu3lddll4ul4urrd3rddllrud4ruu3rdd5l3r3dllurdruudl3d3rdd3l3udlluulurd3lurl3dll4ul4u3(rrd)3r3d5lulddu3ruld3rulr3d7ruu4lurd3ruruu3lddldrrl3u3rddlddrd7lrrdd3l3udlluururrd3ldd9r3ulrruu3lddldrrurddrd7lrrdd3l3u3d7r4ull3u3rddllrruu3lddldrrurddrd7lrrdd3luulluururrdlddlluururdr3u3l3(ull)4dr5d3ruluu4rurruu3luullrrddrruu3rdd3luurrdluldr3dlldllurd3lurl4dll5ul4urru3rdururrd5lruullddrrul
