3d4rdrr3ulldd4l3ull3d3rddl4uddll3uruurrddllr3d3ruruuldldurrdldlldl3uddll3ulurdruurrddllr3d3ruuldrdlldl3uddrruu4rdlrddlu4ldlull3uruurrddl3dll3ulur4drr3ulrruulldldduururrddlluldruuruul3durrddllr3d5rddluru6l3ruu3rdrd6lrruurrdrd4l
