3dlldlddrdrr3u3dlluluururr3urrdlul3ulluluururr3d3urrdrddldll3dllurdrud4luululldlddrud3rddludd2(lluur)dlddrdrruruullrruuldr3dldllul3urrll3drdrrur4ululldurrdrddrrurrdllrr3dlldlddrdrr6urulullddrluurrdlrdu4ruururrdrddlud3lddrudd2(rruul)drddldlluluurrlluurdl3drdrrur3ullrr3dldllul4ururrdulldlddlldllurrll3urruruulull6dldr7ulldlddrdrluluururrdlr3drrulrr2(uulld)rurrdrddldlluuddllurd3ruruulu3ldduu3rdrddld4luluurlddrdrrddlddruuddrruulrddllurl3dlldlddrdrr5u5drruruululrdrddldllurl3ulldrll2(ddrru)ldlluluururrdduurrdlu3ldlddrd3ruudd3luluuru4rdrddl
