textures = {
	["font-10"] = {
		image = "cavepacker-ui-fonts-small",
		x0 = 0.5,
		y0 = 0.625,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["font-12"] = {
		image = "cavepacker-ui-fonts-small",
		x0 = 0.5,
		y0 = 0.5,
		x1 = 0.5,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 64,
		untrimmedwidth = 128,
		untrimmedheight = 64,
	},
	["font-24"] = {
		image = "cavepacker-ui-fonts-small",
		x0 = 0,
		y0 = 0.5,
		x1 = 0.5,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["font-48"] = {
		image = "cavepacker-ui-fonts-small",
		x0 = 0,
		y0 = 0,
		x1 = 1,
		y1 = 0.5,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 256,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
	["font-8"] = {
		image = "cavepacker-ui-fonts-small",
		x0 = 0.75,
		y0 = 0.625,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
}
