ulluruuruul4dldrrdd5l5u3r3l5d5ruul3u3drdrrululr3d5l3uluu4rddrddrd4l3r3ulldr3uruuldd4l6dr3ul3u4rddrddrd4l3r3uluu4l6dru4r3ulluddrurddrd5lul4u3rdruruul4dldrurdrdd5ldluud6ruuldrd5lulldrurd4ruul3u4l3d3u3rddrr3d6lur
