d3rdd4ruu5rdr5d26l14u26r8d4luu3r3ldd4ruu6luurruuddllddrrddll4d4u5rddr4d3luul4ullddll3d3urruurr6d4l4ulluu3luu3ruurr3u3dlldd3ldd3rdd4ruu6ruuluur4u8ldllu4l4drruu4dlddl4d4ullddll3d3urruu3ruuruull4u12l14d8r4urruu3ruu3l5u5d4ruull4ull4dllddll4udd5l5r4dlldd3ldlu4rdd4u2(rruu)rr4u6rdrru5rddlddlludllrrdd6r2(dd4l)3dlld6lull3urruu3ruurddllurr3ull4ull6drr2(ddll)3drrd6rurr5u4l4rddrruull5dlld6lull3u2(rruu)rdru4l6u6rdrr5d4l4ruurrddll8rdd6l4drluurrdlu3l4d4ruuluu3lurdrrddlururuu3rdd3ldd4u4ruu6ldu6rddlddr4d8l6u5r3luurdu5rddldd3luulrdd3ruu3l4ruu4lddulluulul4urr4dl2(dd3r)dd3l3ud4ruu5l4ruuldrd3l6drddl4u3ruuruuluur4u3lddllrruu3l3durdurruu3r4d3ldrdl3rddlddlludrruullrdrdlluu3ruuluur4u8l4drddldduuruul3ullu6l6d3(rrd)dllrruullulldllddlluullrrddrruull4rurrd4l6rddlludrruullrrdlulullull6urr4dllddrrdrrurruullulrdrrddlldllulluurruudrrdrrddllurlddllulluurrurrdrddrr3ldd3rud3luurrdduuluurrldullulldll4u6r4d3urrddlruuldduld3u6l6drrdrrdrddrulurllulldllddll3drrd6r5udrl3drruulrd2(dluu)luulull3d3rludlluullddll3drrd4r4ullddrl4ullddll3drrd4r3udlul3ullddrlurd3luu3r3l6d8l3ur3uluur3ul3u8rdrr5d3r3luu3r3lddrrudlluurrldldrrll6urr4durruldldll4urr3d3ulldllu8l3drd5rdd5r5luu5ldl3drddl4d8rurr3uruuluu3d3ulldrurdduu4luu5ldl3drddl4d8r7ururruul3ullu8l3drd5rddrrdrruruul3dllullddrrddllururuullddrddr4d5luur4u3rddr3drr3(ul)uuluurrdrr6ulldrur4d3ulldrurddull3u8l3drd5rddrruurlddlluurrlldru6lul3u8r3d3u8l3drd5r4drddrdrddluu3d5luur4urr4ulldd3rlddrddl4uddll4dldd3r4uruu3ldd3luu4r5luuruu3r3durdl3u3ldl3drdd3r4u5drldldd3r3u3dll3urrdluldldd3l3ur3uluuruu5rdrdluu5lul3u6r4d4ullddrluu4l3drd5ruulldrurdll3u4l3drd3r3ldl3d4r6u4drldd3lddrurlluluu4ruuldulldrrldr3ldd3r3luur3ul3u4r3d3u4l3drddl4u7drddluu6d3ruurdurrdd5l7rurrdll6ruulldurrddll4rurrdll6ruulldurrddll6r3ul3ur5d7uluurdd6u3lddludlluu5r7ldllurr6lddrrudlluurr4ldllurr6lddrrudlluurr
