uurul5d4ur3ulldlddl4drdrrllul4urrudll4drdrr5ulur6dlddrruruur4uluululldurrdrddr4dlld3lul4u3r4drdl5u3l4drddrdrruruulluurrlldd3ruudrruululldr3d3luurrurd3ldd4ruruululldd4lrruu3lddullddrdrrul3u3rddlldlu3ru2(ulld)lddrd3rlddrdrrur3udrruruulu3l
