rddldllrrdrddlulldllddllurdrul4uluur5d4urrd3ruruuldldurrdldllrrdrddlullullrrd3(dl)lur4uluurdrrdrddrr3uruul4dullddrrl3(ld)llur3urrlluluurdrrurrlldd3rddllud3(dl)lur3u3(rru)uldrdld3luurrll3dllulurrlddrru3ruruuld3ldd3rurul3drdrddlulullud3(dl)5ulurrlddrruull5drrururruullrruruuldldurrdl4drruldl4urul4dlluddlldl4ulurr
