l3dllurdrruruullddr4dllurdr3ululldrr3urrddlruullddr3dr4dllurdrr3dllurruul3uruld2(lulldrr3u)rrddlruullddr3dr3dldrur3dld3r2(uldl3ur)uld2(lulldrr3u)rrddl3dr3dldr4ulldr4uruullddldru3(r3d)ldrru3r7urdlldduulurllurur3drruldlluurdldrur7drrddlludrruu5ldl3uruldlulldrr3uruldlulldrr3ul3urrddlruullddldru3(r3d)ldru4r4uluruulldrur7drrddlludrruu6ldllurdr2(3uruldl)3ul3urrddlruulldd3(r3d)4ruul3uruulldrur7drrddlludrruull6u3ru3ldlluurdldrur7d4ldllurdr3uruldlulldrr3uruld2(lulldrr3u)rrddlruulldd3(r3d)
