4rurd9lulldr3d6r3d3rdrddludlluruururdluurdd4l3u6l3u9rurrd10lul3duu10r4dlddr5u5d4l3u5lddlluu5r4l3u9rurrd10lul3duu10r6drruulrddll5u5d4luulu4lddlluu5r4l3u9rurrd10lul3duu10r6dll3drr8u5d4l4uld4lddlluu6r5l3u9rurrd10lul3duu10r6dllddrdr8u5d4l3uldu4lddlluu6r5l3u9rurrd10lul3duu10r6dlldrdr7u5d3lull3urddu5lddlluu6rdru6l3u9rurrd10lul3duu10r6d4luluu4lddlluu5rlddrruu
