textures = {
	["dead-hitpoints"] = {
		image = "caveexpress-ui-dead-small",
		x0 = 0,
		y0 = 0.71875,
		x1 = 0.3662109375,
		y1 = 0.2021484375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 375,
		trimmedheight = 207,
		untrimmedwidth = 375,
		untrimmedheight = 207,
	},
	["dead-npc-fish"] = {
		image = "caveexpress-ui-dead-small",
		x0 = 0,
		y0 = 0,
		x1 = 0.5546875,
		y1 = 0.3740234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 568,
		trimmedheight = 383,
		untrimmedwidth = 568,
		untrimmedheight = 383,
	},
	["dead-npc-flying"] = {
		image = "caveexpress-ui-dead-small",
		x0 = 0.5537109375,
		y0 = 0.576171875,
		x1 = 0.3603515625,
		y1 = 0.3544921875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 369,
		trimmedheight = 363,
		untrimmedwidth = 369,
		untrimmedheight = 363,
	},
	["dead-npc-mammut"] = {
		image = "caveexpress-ui-dead-small",
		x0 = 0,
		y0 = 0.3740234375,
		x1 = 0.5537109375,
		y1 = 0.3447265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 567,
		trimmedheight = 353,
		untrimmedwidth = 567,
		untrimmedheight = 353,
	},
	["dead-npc-walking"] = {
		image = "caveexpress-ui-dead-small",
		x0 = 0.5546875,
		y0 = 0.296875,
		x1 = 0.41015625,
		y1 = 0.279296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 420,
		trimmedheight = 286,
		untrimmedwidth = 420,
		untrimmedheight = 286,
	},
	["dead-waterheight"] = {
		image = "caveexpress-ui-dead-small",
		x0 = 0.5546875,
		y0 = 0,
		x1 = 0.4208984375,
		y1 = 0.296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 431,
		trimmedheight = 304,
		untrimmedwidth = 431,
		untrimmedheight = 304,
	},
}
