r4dld13luu9ruurrudlluurdl3d9ldd13rur4u3l3d10l10r3u3r4dld13l6uddll3u4rurd3l5d11rulruulddrd10l9r3u4r4dld13l6uddll3u3rd4rurdlddrrulu3luuldll5d10ruuldrd9l9r3u4r4dld13l6u4d10r4ul3drd9l8r5urrdd3r4dld13l3ull4u3rd4rurddrdluu3luuldr3d3ldd9ru3rululddld9ldd13rur4u3luurdllddldd9ldd13rur4u3l3d10l10r3u3r4dld13l6u3dll4u4rurddu3l5d9ruurdrd10l10r3u3r4dld13l6u4d9r4ur3drd10l8r3u5r4dld13l3ull4u4rurd3l6duullurl3urr5d
