ulluu3rurrd4l3r5dllull3dll4u4drr3ul3rdrr5u3lulld3rllddldldrr3dlluururdl3uruu3rurrdl5dllulrdl3r5u3lulldrddrrddldr3u3l3dldd4r3u3d4luururldldd4ruulluluuruu3rurrdl5dllullrr3dlluuddlluururldl2(ddrruu)ll4r5u3lulldrddrr3dllddrrudlluurr3ulluurr5d3u3ldllu3ruurr5dllddll3u3drruul3r5ururrdl5d4lddrrudlluurrdd4luurrddrr7ullddldduulldrurruurr7d4l3udrldd4r7ullddrluurr4duu3ldduulldrurduruu3rurrd4lulddurrdd3ldllu4rluurr3d
