uull3uru7r12d12l10urulurl12d12r12u8l5dlull3ruuldr3u8r12d12l8u3rdr5dldur4uluu3l8d10r7luuruu4r3d3u4lddldd5r4u3r3l4u3rdr3uldr6du4l4u3rur3duu4luurudl6d7l3r3dldrr5luurdldrl6uddrruldlud4ruul3ur4d3u7rurddu4l4d7luld4r8u5rddlurull
