ruur3uldrddldd4ldd3udrruluururrlldl3d3ruldll3ururrurd3ldl3d3r3ulr3d3lurrd4lurruulddrdrruldluluurdldldrrlddlddruud3ldrddrrud3luudd3ruuddlddluurrurrdlrddlull3ruu2(lldr)u3lu3(ur)ddullddldr3urrdluldllurrl3dru
