textures = {
	["ui-scene-cave-ice"] = {
		image = "caveexpress-ui-scene-big",
		x0 = 0.5,
		y0 = 0.494140625,
		x1 = 0.244140625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 500,
		trimmedheight = 500,
		untrimmedwidth = 500,
		untrimmedheight = 500,
	},
	["ui-scene-cave-rock"] = {
		image = "caveexpress-ui-scene-big",
		x0 = 0.75,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 512,
		trimmedheight = 512,
		untrimmedwidth = 512,
		untrimmedheight = 512,
	},
	["ui-scene-caveart-ice"] = {
		image = "caveexpress-ui-scene-big",
		x0 = 0.25,
		y0 = 0.498046875,
		x1 = 0.244140625,
		y1 = 0.2431640625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 500,
		trimmedheight = 498,
		untrimmedwidth = 500,
		untrimmedheight = 500,
	},
	["ui-scene-caveart-rock"] = {
		image = "caveexpress-ui-scene-big",
		x0 = 0.5,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 512,
		trimmedheight = 512,
		untrimmedwidth = 512,
		untrimmedheight = 512,
	},
	["ui-scene-ground1-ice"] = {
		image = "caveexpress-ui-scene-big",
		x0 = 0.25,
		y0 = 0.25,
		x1 = 0.25,
		y1 = 0.248046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 2,
		trimmedwidth = 512,
		trimmedheight = 508,
		untrimmedwidth = 512,
		untrimmedheight = 512,
	},
	["ui-scene-ground1-rock"] = {
		image = "caveexpress-ui-scene-big",
		x0 = 0.25,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 512,
		trimmedheight = 512,
		untrimmedwidth = 512,
		untrimmedheight = 512,
	},
	["ui-scene-ground2-ice"] = {
		image = "caveexpress-ui-scene-big",
		x0 = 0,
		y0 = 0.75,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 512,
		trimmedheight = 512,
		untrimmedwidth = 512,
		untrimmedheight = 512,
	},
	["ui-scene-ground2-rock"] = {
		image = "caveexpress-ui-scene-big",
		x0 = 0,
		y0 = 0.5,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 512,
		trimmedheight = 512,
		untrimmedwidth = 512,
		untrimmedheight = 512,
	},
	["ui-scene-tile1-ice"] = {
		image = "caveexpress-ui-scene-big",
		x0 = 0.744140625,
		y0 = 0.25,
		x1 = 0.244140625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 500,
		trimmedheight = 500,
		untrimmedwidth = 500,
		untrimmedheight = 500,
	},
	["ui-scene-tile1-rock"] = {
		image = "caveexpress-ui-scene-big",
		x0 = 0,
		y0 = 0.25,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 512,
		trimmedheight = 512,
		untrimmedwidth = 512,
		untrimmedheight = 512,
	},
	["ui-scene-tile2-ice"] = {
		image = "caveexpress-ui-scene-big",
		x0 = 0.5,
		y0 = 0.25,
		x1 = 0.244140625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 500,
		trimmedheight = 500,
		untrimmedwidth = 500,
		untrimmedheight = 500,
	},
	["ui-scene-tile2-rock"] = {
		image = "caveexpress-ui-scene-big",
		x0 = 0,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 512,
		trimmedheight = 512,
		untrimmedwidth = 512,
		untrimmedheight = 512,
	},
}
