4l5d6r3uludr3d6l5u4ruurrdd5l4rddr3d6l4ulluurr5d4u5rddr3d5lddlluu7rurddrdllruull6drdllru3r6d5l4ulluurr5d4urru3r6d4lddlluu5r4l5urru3r5drrddll7ulurrurddulldd6rurddul3u6r5d4lddlluu5r4luul3u6r4drrddll5u4d5luul3u5ruurrdd7ldluulurrlddrr6ulurrld3l6u5r4drrddll5u4dlld3l6u4ruurrdd5l4r5dlld3l5ulluurr7drdlldluudrruu5l
