textures = {
	["cooldown-1"] = {
		image = "caveexpress-ui-big",
		x0 = 0.248046875,
		y0 = 0.8671875,
		x1 = 0.029296875,
		y1 = 0.123046875,
		trimmedoffsetx = 1,
		trimmedoffsety = 1,
		trimmedwidth = 60,
		trimmedheight = 63,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["cooldown-2"] = {
		image = "caveexpress-ui-big",
		x0 = 0.97314453125,
		y0 = 0.140625,
		x1 = 0.02685546875,
		y1 = 0.1171875,
		trimmedoffsetx = 6,
		trimmedoffsety = 4,
		trimmedwidth = 55,
		trimmedheight = 60,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-campaign-ice"] = {
		image = "caveexpress-ui-big",
		x0 = 0.9384765625,
		y0 = 0.7421875,
		x1 = 0.0615234375,
		y1 = 0.240234375,
		trimmedoffsetx = 2,
		trimmedoffsety = 3,
		trimmedwidth = 126,
		trimmedheight = 123,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["icon-campaign-rock"] = {
		image = "caveexpress-ui-big",
		x0 = 0.125,
		y0 = 0.62890625,
		x1 = 0.0615234375,
		y1 = 0.240234375,
		trimmedoffsetx = 2,
		trimmedoffsety = 3,
		trimmedwidth = 126,
		trimmedheight = 123,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["icon-campaign"] = {
		image = "caveexpress-ui-big",
		x0 = 0.9384765625,
		y0 = 0.4921875,
		x1 = 0.0615234375,
		y1 = 0.25,
		trimmedoffsetx = 2,
		trimmedoffsety = 0,
		trimmedwidth = 126,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["icon-checkbox-off"] = {
		image = "caveexpress-ui-big",
		x0 = 0.94921875,
		y0 = 0.275390625,
		x1 = 0.03125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-checkbox-on"] = {
		image = "caveexpress-ui-big",
		x0 = 0.3076171875,
		y0 = 0.62890625,
		x1 = 0.03125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-close"] = {
		image = "caveexpress-ui-big",
		x0 = 0.3076171875,
		y0 = 0.861328125,
		x1 = 0.03271484375,
		y1 = 0.111328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 67,
		trimmedheight = 57,
		untrimmedwidth = 67,
		untrimmedheight = 57,
	},
	["icon-google-login"] = {
		image = "caveexpress-ui-big",
		x0 = 0.248046875,
		y0 = 0.62890625,
		x1 = 0.0595703125,
		y1 = 0.23828125,
		trimmedoffsetx = 11,
		trimmedoffsety = 11,
		trimmedwidth = 122,
		trimmedheight = 122,
		untrimmedwidth = 144,
		untrimmedheight = 144,
	},
	["icon-heart"] = {
		image = "caveexpress-ui-big",
		x0 = 0.34814453125,
		y0 = 0.75,
		x1 = 0.03125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-plus"] = {
		image = "caveexpress-ui-big",
		x0 = 0.94921875,
		y0 = 0,
		x1 = 0.03369140625,
		y1 = 0.140625,
		trimmedoffsetx = 29,
		trimmedoffsety = 28,
		trimmedwidth = 69,
		trimmedheight = 72,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["icon-reload"] = {
		image = "caveexpress-ui-big",
		x0 = 0.1865234375,
		y0 = 0.62890625,
		x1 = 0.0615234375,
		y1 = 0.240234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 3,
		trimmedwidth = 126,
		trimmedheight = 123,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["icon-result"] = {
		image = "caveexpress-ui-big",
		x0 = 0.3076171875,
		y0 = 0.75390625,
		x1 = 0.04052734375,
		y1 = 0.107421875,
		trimmedoffsetx = 21,
		trimmedoffsety = 38,
		trimmedwidth = 83,
		trimmedheight = 55,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["icon-scroll-page-DIR"] = {
		image = "caveexpress-ui-big",
		x0 = 0.3388671875,
		y0 = 0.62890625,
		x1 = 0.0341796875,
		y1 = 0.12109375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 70,
		trimmedheight = 62,
		untrimmedwidth = 70,
		untrimmedheight = 62,
	},
	["icon-settings"] = {
		image = "caveexpress-ui-big",
		x0 = 0.34033203125,
		y0 = 0.875,
		x1 = 0.03076171875,
		y1 = 0.1171875,
		trimmedoffsetx = 1,
		trimmedoffsety = 3,
		trimmedwidth = 63,
		trimmedheight = 60,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-star-disabled"] = {
		image = "caveexpress-ui-big",
		x0 = 0.693359375,
		y0 = 0,
		x1 = 0.1279296875,
		y1 = 0.4921875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 262,
		trimmedheight = 252,
		untrimmedwidth = 262,
		untrimmedheight = 252,
	},
	["icon-star-enabled"] = {
		image = "caveexpress-ui-big",
		x0 = 0.8212890625,
		y0 = 0,
		x1 = 0.1279296875,
		y1 = 0.4921875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 262,
		trimmedheight = 252,
		untrimmedwidth = 262,
		untrimmedheight = 252,
	},
	["map-icon-locked"] = {
		image = "caveexpress-ui-big",
		x0 = 0.8134765625,
		y0 = 0.4921875,
		x1 = 0.0625,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["map-icon-unlocked-0"] = {
		image = "caveexpress-ui-big",
		x0 = 0.8759765625,
		y0 = 0.4921875,
		x1 = 0.0625,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["map-icon-unlocked-1"] = {
		image = "caveexpress-ui-big",
		x0 = 0.8134765625,
		y0 = 0.7421875,
		x1 = 0.0625,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["map-icon-unlocked-2"] = {
		image = "caveexpress-ui-big",
		x0 = 0.8759765625,
		y0 = 0.7421875,
		x1 = 0.0625,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["map-icon-unlocked-3"] = {
		image = "caveexpress-ui-big",
		x0 = 0,
		y0 = 0.62890625,
		x1 = 0.0625,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["map-icon-unlocked"] = {
		image = "caveexpress-ui-big",
		x0 = 0.0625,
		y0 = 0.62890625,
		x1 = 0.0625,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["mouse"] = {
		image = "caveexpress-ui-big",
		x0 = 0.94921875,
		y0 = 0.140625,
		x1 = 0.02392578125,
		y1 = 0.134765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 49,
		trimmedheight = 69,
		untrimmedwidth = 49,
		untrimmedheight = 69,
	},
	["ui-background-gameover"] = {
		image = "caveexpress-ui-big",
		x0 = 0.38037109375,
		y0 = 0,
		x1 = 0.31298828125,
		y1 = 0.9140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 641,
		trimmedheight = 468,
		untrimmedwidth = 641,
		untrimmedheight = 468,
	},
	["ui-background-title"] = {
		image = "caveexpress-ui-big",
		x0 = 0,
		y0 = 0,
		x1 = 0.38037109375,
		y1 = 0.62890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 779,
		trimmedheight = 322,
		untrimmedwidth = 779,
		untrimmedheight = 322,
	},
	["ui-button-start"] = {
		image = "caveexpress-ui-big",
		x0 = 0.693359375,
		y0 = 0.4921875,
		x1 = 0.1201171875,
		y1 = 0.47265625,
		trimmedoffsetx = 6,
		trimmedoffsety = 5,
		trimmedwidth = 246,
		trimmedheight = 242,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
}
