r4uruu4lur3dluru3rd3rdrddludllddll4uru3rdrddludllddll4uru3rurddu3ldll4drruu4rul5ulddr4d3lddll4uruurrluurl4dll4drruulrddlluu5r7uldll4d3lulurrurd3lurddllddrdrrudll3uru3rdd3lr4drruulrddll3udllulld4r3l3urruull3duru4r2(ddll)3u3dllurdruudd2(rruu)3l3ulldrurdll4drddllurd3ruulr4drruulrddlluu5r6u3luld
