urrururrd7rurddu8lulld9r6l3u3luu3r4dld6r5l3u3lu3ldrddld10r9l3u4rlluu3r4dld4rurd9lu4r4luu5rddld4rd3rllu6ldlddlddrurruruuddldll3urru4ru3rdduulddlu5ldll3drruruulu6r5l3dlddr4ulu5r4ld3lddrrdr3ulu4rurrld4lu5lddru7rdrrlu4l3d3luulu7rurdldr
