dlld9(dr)l7(ul)3u3rd8(dr)r3u5(lu)llu7(ur)u6(dl)d3lddllullddrulurl3u5r7(ur)uu3l5(dl)ddl7(lu)l6(rd)r3dl8(lu)ll3d5(rd)rrd7(dl)d6(ur)u3rd8(dl)dd3r5(ur)uur7(rd)3ru7(ul)u4luu3l6(dl)3dr7(ru)r4urr3u6(lu)3ld7(dr)d4rdd3r6(ur)3ul8(ld)llrrdldlu4rdlldluur3druurulldd3lddrulurrurrddlurulddlull2(ddru)lluul4u4rddr4dlulr5u4l4drd3(dr)uurrdlr5(rd)d3l3(ul)3ur3urrdlr4(rd)r3dl4(lu)llr4(rd)d3lulul3udl4(lu)ul4u4rdd3r6(ur)r6(dl)d5(ur)5ul8(ld)d3r5(ur)l5(dl)lddrrululdl3u4l4drd4(dr)rur3u3dldl4(lu)ul4u4r3d4r6(ur)3dlu4(dl)d4(ur)r5uluul7(ld)l3d4r3(ur)ldldld4l3u4l4drd4(dr)rur4(rd)rr3u3(lu)llr3(rd)r3dl4(lu)lldl4(lu)ul4u4r3d4rd4(ru)dldld6l3u4l4drd4(dr)rur4(rd)rr3u4(lu)ulu4l3u7(ru)rrddr5dl3(ld)3lrr3dluuddr3(rd)r3dl3(lu)l3u3dlr3(rd)d3lul3ur3urrdl4u3(ru)rr5(dl)ddrrdrdrr5ul3uddl3(ld)dru3(dr)r3ululudrr4dl3dllulul3u3dlrrdrdd3l3urrdlrrddlluurrdl3r3ululldduurrdlrr3dllurldd3l7(ul)uul4u5r7(ur)r2(ddr6dl)ldurrulruuldrdd3luururr3uldrddlldllurrlu4d3ruu3l3rullrur4dluuddlurr5uluur6uluul7(ld)5l4drd8(dr)ru3r3u3dll3u3druul3d3l7(ul)l4u4dr7(rd)d7(lu)ud5(dr)dd5(lu)l5u5d4(rd)d4(lu)lr4uluu3r4ul8(lu)ll3d5(rd)rrd7(dl)3dr7(ru)3ruullrur3dluuruu3r7(ur)r2(ddr6dl)dll3d9lulul5uruuddl3druul4druu3drd8ru3r3u2(r6uluu)l7(ld)3l4d3l7(dl)dd3rd6r3udd10rdruluurrdluldrd7l6r3ulddrd4lrururd3r3uruul4drdllr4ulddurr4ul4d3u5(lddu)urruu4r5ul4d3u5(lddu)urruu3r4ul3dldr3u4(lddu)ruu4r4uruu2(l4d3u)l3(ddul)dduruurruu3r4ul3drdlulddr4u5(lddu)urruu4r5ul4d3u4(lddu)lddll2(rruu)3r5ul7(ld)3l4d3l7(dl)dd3rd3rururldd4lu4(ur)l3(dl)dd4ruuruuld3ur3ul7(ld)d3r3(ur)ldrr3ldldd3ruuddllur5lu7(ur)r3d5(ld)3luurdld6(ru)r4(ld)4l3u7(ru)ul5(lu)l3urru3r7(dr)ru5(ur)u3rd7(dl)d3l4dld3l5(dl)d3ldr8(ru)rdl6(ld)ll3u7(ru)ul5(lu)l3urru3r7(dr)ru5(ur)u3rd7(dl)d3lddlldurrdlr3u3r7(ur)uu3l5(dl)ddl7(lu)3ld8(dr)rl8(lu)ll3d5(rd)rrd7(dl)3dr6(ru)3ruruulur3dluu3dllurdruruulludrrddld3l6(dl)l3u6(ru)3rd8(dl)lurluurdd3u5(ru)3rd7(dl)lrrulr6(ru)u3l4(dl)3drrulr5(ru)u3l3(dl)3drrulr4(ru)u3ldldl3drrulr3(ru)u3ldl3drrulrruruu3l3drrulrruullddrul3ul5(lu)l3urru3r7(dr)ru5(ur)u3rd8(dl)4d4l4ruu4(rrlluurd)4r4luurdldrrlu2(rrlluurd)ur3uldduulldrddurruld3ruldlluurdu3ldrlldr4d4u2(lldrdduu)lld3rlldduulldrddurulurdd4l6(ul)u3ldll3d5(rd)rr3drrd4r5u5d4lull3ul5(lu)l3urru3r7(dr)rdrulurl7dll5url5drr5ulur6d4lull3ul5(lu)l3urru3r7(dr)r6dll3url3drr4udlul4dll3urrllddll3ul5(lu)l3ur8(rd)rr4dll3uddlluurrddlurddrruullrul3druud3lurrlluul5(lu)l3ur7(rd)r3dldr4l5(dl)luurdl3urdrd3(ur)u3rlludr3(dl)ruruu3(ld)uru6r4u7(lu)ll3d6(rd)drdlulu4(dl)l4(ur)udr3(dl)ruruu3(ld)uru4rd3r4u7(lu)ll3d6(rd)ululddrrurddu4l3(dl)l5(ur)r4(dl)rururuu4(ld)ururu6ru7(ul)l3d3(rd)ululull6drurll5ur4(rd)dlud5ru7(ul)l3dl5drrurldlluurd3r4l4urrdrdduulul3ur7(rd)d5lul3ulull3drrll3ur5(rd)rrddrlullu5(ul)ldrd5ur7(rd)d3l4(ul)r4(dr)rddruddrdrr3u5l6(ul)3urrdlr5(rd)r3d3r3dlluuddrr3u3l3u6(lu)u3r6(dr)4d3l3u6(lu)lld3r5(dr)dd3l4(ul)uurd4u3r6(dr)4d3l3u3(lu)3l4(rd)ululuull4u3r6(dr)4d3l3u3(lu)3luurdluulldrurd3ulddrdrud5(dr)3d3r4u5(lu)3lddrud4(dr)3d3r4u4(lu)3lddrud3(dr)3d3r4u3(lu)3lddruddrdr3d3r4ululu3lddruddr3d3r4ulu3lddru4d3r4u3lddrul3d3r3ulldrllddrudrrullr4u5(lu)urrdlu3rdldl6(rd)lldldl4d4r3ulldurr3d4l4urururr3d3ul4(lu)drdrdrr4(ul)uu6(rd)l4(lu)drdrdrr4(ul)uu6(rd)llrurruurr3u5ld3lrru3rdldlruu3rdlrrddluruulldrru4ldrrdulld3rddluddlluuddrruluu3dlurul3dl2(3dr4u)3d2(ruud)d4l5d2(r4u3d)ruudruudd6ld3rdruulurrll4dlluulurdru3dllulu4rdruudd6l4d4r5ulu3r4l4druu3l4d4r5ulurdd4ldrrdr3ur5dl4ulu3rl5dll3ulu3r4ldd3rdr3u4l3drdr4u
