rd3(dr)r3u4r4u4l3u3l4u4l4d3l3d4l4d4r3d3r3drruldd3r4u3r3u4r4u4l3u3l4u4l4d3l3d4l4d4r3d3rddlurulrruuldlrrdlrddrddrr4u3r3u4r4u4l3u3l4u4l4d3l3d4l4d4r4drrd3rddrruullrruuldr3d5luudd3ruururduul4uddrdd3rullrr3ulldrdrdl3urd3ruuldldllu3rldr3l3d3luurdrdruud3l3urrdrrldd3l3drruulr2(dd3l)uu3rddlludr3(ruu)luulluurrdd4ldlldd3ruruu4rd3(rru)u4l3u3l4u4l4d3l3d4l4drrdrlull4u4r3u3r4u4r4d3r3d4rd3(dll)u4l3d4ldlu5rdd5ulldlldurru6rd3(rru)u4l3u3l4u4l4d3l3d4l4drrdrlulldrrl3urdll3u4r3u3r4u4r4d3r3d4rd3(dll)u6ldldulurr4lulluurrdduurrdlu3lddrrurulrr3u3r3urrdluu3r4dl4dlldduullull3u4ruudluddllddlddlluurdrull3dlluurlu3rdrdl3rullr3u2(rruu)rr4dl4dlluululrdru3drr4ur4ull2(dd3l)dururru3ruurr4dl4d4lulldrrl3ur3urrddlrdllrrd4uruullduldduu5rddllrrddlu5dlldd4rdrrduurrurruu4ldllururuu3luurdll5dlldd4rdrrurrddluruurruu4l4u3l3urddlddl4dlldd4rdr3drruur3urruu4l4ull3u3lddrluu3r3drr4drruldluluuruldrrddrdrrddllddl3dll3ulu4luurr5udrrllddrulurdrll3dllddrruuddrrdr3drr3ulullrd3rullrrurruullullddlluru3rdrrullrr3dludlullulld4rdrrullrr3dlulld3lu4rldrl3dlluudrdruudludd4lddldd3r3u3d3luuruur2(rlldd)rruruu3d3luuruuruul3duu3rurrddldlruruuruullduldduu3ruurrdluldrr3uldr5dllrrulru3(ull)d3r
