function getName()
	return "Second Ice 04"
end

function onMapLoaded()
end

function initMap()
	-- get the current map context
	local map = Map.get()
	map:addTile("tile-background-ice-07", -2, -2)
	map:addTile("tile-background-ice-04", -2, -1)
	map:addTile("tile-background-ice-03", -2, 0)
	map:addTile("tile-background-ice-04", -2, 1)
	map:addTile("tile-ground-ice-02", -2, 2)
	map:addTile("tile-rock-ice-big-01", -2, 3)
	map:addTile("tile-rock-ice-big-01", -2, 5)
	map:addTile("tile-rock-ice-02", -2, 7)
	map:addTile("tile-rock-ice-02", -2, 8)
	map:addTile("tile-rock-ice-01", -2, 9)
	map:addTile("tile-background-ice-02", -1, -2)
	map:addTile("tile-background-ice-03", -1, -1)
	map:addTile("tile-background-ice-07", -1, 0)
	map:addTile("tile-background-ice-01", -1, 1)
	map:addTile("tile-ground-ice-01", -1, 2)
	map:addTile("tile-rock-ice-02", -1, 7)
	map:addTile("tile-rock-ice-01", -1, 8)
	map:addTile("tile-rock-ice-02", -1, 9)
	map:addTile("tile-background-ice-03", 0, -2)
	map:addTile("tile-background-ice-04", 0, -1)
	map:addTile("tile-background-ice-07", 0, 0)
	map:addTile("tile-background-ice-03", 0, 1)
	map:addTile("tile-ground-ice-02", 0, 2)
	map:addTile("tile-rock-ice-01", 0, 3)
	map:addTile("tile-rock-ice-02", 0, 4)
	map:addTile("tile-rock-ice-02", 0, 5)
	map:addTile("tile-rock-ice-02", 0, 6)
	map:addTile("tile-rock-ice-big-01", 0, 7)
	map:addTile("tile-rock-ice-02", 0, 9)
	map:addTile("tile-background-ice-03", 1, -2)
	map:addTile("tile-background-ice-04", 1, -1)
	map:addTile("tile-background-ice-01", 1, 0)
	map:addTile("tile-background-ice-01", 1, 1)
	map:addTile("tile-ground-ice-02", 1, 2)
	map:addTile("tile-rock-ice-02", 1, 3)
	map:addTile("tile-rock-ice-01", 1, 4)
	map:addTile("tile-rock-ice-big-01", 1, 5)
	map:addTile("tile-rock-ice-01", 1, 9)
	map:addTile("tile-background-ice-05", 2, -2)
	map:addTile("tile-background-ice-01", 2, -1)
	map:addTile("tile-background-ice-06", 2, 0)
	map:addTile("tile-background-ice-07", 2, 1)
	map:addTile("tile-ground-ice-01", 2, 2)
	map:addTile("tile-rock-ice-02", 2, 3)
	map:addTile("tile-rock-ice-02", 2, 4)
	map:addTile("tile-rock-ice-02", 2, 7)
	map:addTile("tile-rock-ice-01", 2, 8)
	map:addTile("tile-rock-ice-02", 2, 9)
	map:addTile("tile-background-ice-03", 3, -2)
	map:addTile("tile-background-ice-03", 3, -1)
	map:addTile("tile-background-ice-03", 3, 0)
	map:addTile("tile-background-ice-06", 3, 1)
	map:addTile("tile-background-ice-05", 3, 2)
	map:addTile("tile-ground-ice-02", 3, 4)
	map:addTile("tile-rock-slope-ice-right-02", 3, 5)
	map:addTile("tile-rock-slope-ice-right-01", 3, 6)
	map:addTile("tile-rock-ice-03", 3, 7)
	map:addTile("tile-rock-ice-01", 3, 8)
	map:addTile("tile-rock-ice-01", 3, 9)
	map:addTile("tile-background-ice-03", 4, -2)
	map:addTile("tile-background-ice-01", 4, -1)
	map:addTile("tile-background-ice-01", 4, 0)
	map:addTile("tile-background-ice-02", 4, 1)
	map:addTile("tile-background-ice-05", 4, 2)
	map:addTile("tile-background-ice-window-02", 4, 3)
	map:addTile("tile-ground-ice-01", 4, 4)
	map:addTile("tile-rock-shim-ice-01", 4, 5)
	map:addTile("tile-background-ice-06", 4, 6)
	map:addTile("tile-packagetarget-ice-01-idle", 4, 7)
	map:addTile("tile-rock-ice-big-01", 4, 8)
	map:addTile("tile-background-ice-05", 5, -2)
	map:addTile("tile-background-ice-03", 5, -1)
	map:addTile("tile-background-ice-01", 5, 0)
	map:addTile("tile-background-ice-01", 5, 1)
	map:addTile("tile-background-ice-05", 5, 2)
	map:addTile("tile-background-ice-05", 5, 3)
	map:addTile("tile-ground-ice-02", 5, 4)
	map:addTile("tile-rock-slope-ice-left-02", 5, 5)
	map:addTile("tile-background-ice-03", 5, 6)
	map:addTile("tile-rock-slope-ice-right-01", 5, 7)
	map:addTile("tile-background-ice-big-01", 6, -2)
	map:addTile("tile-background-ice-06", 6, 0)
	map:addTile("tile-background-ice-06", 6, 1)
	map:addTile("tile-background-ice-03", 6, 2)
	map:addTile("tile-background-ice-05", 6, 3)
	map:addTile("tile-ground-ice-03", 6, 4)
	map:addTile("tile-rock-slope-ice-right-02", 6, 5)
	map:addTile("tile-background-ice-06", 6, 6)
	map:addTile("tile-rock-slope-ice-left-01", 6, 7)
	map:addTile("tile-rock-ice-01", 6, 8)
	map:addTile("tile-rock-ice-03", 6, 9)
	map:addTile("tile-background-ice-03", 7, 0)
	map:addTile("tile-background-ice-05", 7, 1)
	map:addTile("tile-background-ice-03", 7, 2)
	map:addTile("tile-background-ice-05", 7, 3)
	map:addTile("tile-ground-ice-03", 7, 4)
	map:addTile("tile-background-ice-06", 7, 5)
	map:addTile("tile-background-ice-06", 7, 6)
	map:addTile("tile-ground-ice-01", 7, 7)
	map:addTile("tile-rock-ice-big-01", 7, 8)
	map:addTile("tile-background-ice-03", 8, -2)
	map:addTile("tile-background-ice-01", 8, -1)
	map:addTile("tile-background-ice-04", 8, 0)
	map:addTile("tile-background-ice-01", 8, 1)
	map:addTile("tile-ground-ice-03", 8, 2)
	map:addTile("tile-rock-ice-02", 8, 3)
	map:addTile("tile-rock-ice-03", 8, 4)
	map:addTile("tile-background-ice-06", 8, 5)
	map:addTile("tile-background-ice-01", 8, 6)
	map:addTile("tile-ground-ice-02", 8, 7)
	map:addTile("tile-background-ice-03", 9, -2)
	map:addTile("tile-background-ice-03", 9, -1)
	map:addTile("tile-background-ice-big-01", 9, 0)
	map:addTile("tile-ground-ice-02", 9, 2)
	map:addTile("tile-rock-ice-01", 9, 3)
	map:addTile("tile-rock-slope-ice-right-02", 9, 4)
	map:addTile("tile-rock-slope-ice-left-01", 9, 5)
	map:addTile("tile-rock-ice-big-01", 9, 6)
	map:addTile("tile-rock-ice-02", 9, 8)
	map:addTile("tile-rock-ice-03", 9, 9)
	map:addTile("tile-background-ice-05", 10, -2)
	map:addTile("tile-background-ice-01", 10, -1)
	map:addTile("tile-ground-ledge-ice-right-01", 10, 2)
	map:addTile("tile-background-ice-04", 10, 3)
	map:addTile("tile-background-ice-04", 10, 4)
	map:addTile("tile-ground-ice-02", 10, 5)
	map:addTile("tile-rock-ice-03", 10, 8)
	map:addTile("tile-rock-ice-02", 10, 9)
	map:addTile("tile-background-ice-big-01", 11, -2)
	map:addTile("tile-background-ice-02", 11, 0)
	map:addTile("tile-background-ice-03", 11, 1)
	map:addTile("tile-background-ice-03", 11, 2)
	map:addTile("tile-background-ice-02", 11, 3)
	map:addTile("tile-background-ice-02", 11, 4)
	map:addTile("tile-ground-ice-01", 11, 5)
	map:addTile("tile-rock-ice-02", 11, 6)
	map:addTile("tile-rock-ice-03", 11, 7)
	map:addTile("tile-rock-ice-02", 11, 8)
	map:addTile("tile-rock-ice-03", 11, 9)
	map:addTile("tile-background-ice-big-01", 12, 0)
	map:addTile("tile-background-ice-07", 12, 2)
	map:addTile("tile-background-ice-07", 12, 3)
	map:addTile("tile-background-ice-06", 12, 4)
	map:addTile("tile-ground-ice-01", 12, 5)
	map:addTile("tile-rock-ice-03", 12, 6)
	map:addTile("tile-rock-ice-big-01", 12, 7)
	map:addTile("tile-rock-ice-02", 12, 9)
	map:addTile("tile-background-ice-01", 13, -2)
	map:addTile("tile-background-ice-03", 13, -1)
	map:addTile("tile-background-ice-02", 13, 2)
	map:addTile("tile-background-ice-05", 13, 3)
	map:addTile("tile-background-ice-03", 13, 4)
	map:addTile("tile-ground-ice-02", 13, 5)
	map:addTile("tile-rock-ice-02", 13, 6)
	map:addTile("tile-rock-ice-03", 13, 9)

	map:addCave("tile-cave-ice-01", 3, 3, "npc-man", 1000)

	map:addEmitter("tree", 0, 0, 1, 0, "")
	map:addEmitter("npc-blowing", 10, 4, 1, 0, "right=false")

	map:setSetting("fishnpc", "false")
	map:setSetting("flyingnpc", "false")
	map:setSetting("gravity", "9.81")
	map:setSetting("height", "10")
	map:setSetting("packagetransfercount", "1")
	map:addStartPosition("7", "3")
	map:setSetting("points", "100")
	map:setSetting("referencetime", "16")
	map:setSetting("theme", "ice")
	map:setSetting("waterchangespeed", "0.4")
	map:setSetting("waterfallingdelay", "7500")
	map:setSetting("waterheight", "1.4")
	map:setSetting("waterrisingdelay", "0")
	map:setSetting("width", "14")
	map:setSetting("wind", "0.0")
end
