uulldduu4rddll4d3rur3u3l3r3dld3l5udlluurruu3ldl3drruurr8d4rurur4u5l3r3dld3luurrudll4ullddr3l3uru3ruu4ldldl4d4ruurruu8d3rur3u3lrddll4ullddrluurr4duu6r4dldld8lulul3ulu6r5l4ururu8rdrdr3drd3l3dld6luluuddrd3rdu3rur3ullddlldurruu4r4ululu8ldldl4drr3uru6rdrdduulu3lud3ldl3drruurru5drruulrddll4ullddrluu2(rrdd)4lud4r4ulrddlldu3l
