6rurrd10ldlu14rdrruruu5ldu5rddldllu13luld12ruu7ruulldurrdd6lulddu5rddldllu13ldluu3r6u7r2(dru3l)dru4lddrururrd3ldllururrdl3rurrd4lurrdrrurrd4lurr6lddrulu4rdllullddrulurrlddlddll3d13rdrru3rddluruldl3u5lddrrd3r3urruulldurrdd6l4u8l8rdd5ldldlluru6r3du5r3d3lu14lr3urrdd4uru9r3dl3drrd3r3u4luu7lddrulu6r3dld9lullddru8ru3ru5rddrrddluruldluudd3lu13luld12ruu5ruurrdd6lulddu5r3d3lu12luldrr6u10r3dl3drrd3r3u4luu3ldllullddrulu6r3du5r3d3lu13lrr3u3ldurdurr3u10r3dl3drrd3r3u4lulddu5r3d3lu12l
