uurdd4lururrldld3l2(urrdrr)ururuururruruululld4l3(dl)ddu3(ur)uululldld4lulldlddr4dldlddrur4uddldlddrdr3d4(ru)dldldll6ud3rddurlu3ldd3rludll3drruuddllurl3dlddr4u3druul4druudrrulldluudd6rdrdrruru4rdrruruul4ururu4(ul)lddldd3ldld3(dl)ddllrruururr3uru3ruuruu3rddrdrddldl4drddldllu4ldldllulullrrdrdrr3(ul)lru3(dr)r3(ul)lrudruu3drddlulldru7rdrru9ldlurud10ruuldrd5l4r6ururuuldl7drd3lrr8uruuldlur6d3ulur4u3lddldd3r3luuruuluddu4r4d7lurr3luurrduurld3luurduururu4rurrdrddldd3ldllu3luurduuru4rurrdrddldd3ldll3ulr3drru3r4d7lulld4r3urrdrr3lruu3ruuruululld4ld3(dr)ruld3rddrdd4ludl5ruulldur3ulddrdrddlddrul4uluurduuruuldd3ulldr3d3ull3durluu3lululldrdrrddrrll3ululldld3r7lulld8r9lddrulu7rururrdld4lrrururrdrd4l5rdu3rurrd4l5rddluru3l
