rr3u3rlluuldd3u4ldl10d5ruu3rurd5r9ldd5ldlddru11ruu3rurrurd3lur3luul3ulr3drrurrdldd9ldd3luuruul3uruurl5durrurrd3l5rddld3ldd5l10uru4rdrddlddrd3rddld3ldd5ldlddru11ruu3ruru3lrrd3ru4lrd5ru5ldd3ldd11luu5ruu4r3ullullulruruulu4ldl9d9uru4r3dulldlddrul3druudrrurrdl3rddl3dr3ud4ldd3luur3u3dldd3r3urrudr3d3lruulur
