function getName()
	return "Map 10"
end

function onMapLoaded()
end

function initMap()
	-- get the current map context
	local map = Map.get()
	map:addTile("tile-background-ice-05", 0, 0)
	map:addTile("tile-background-ice-07", 0, 1)
	map:addTile("tile-ground-ice-01", 0, 2)
	map:addTile("tile-rock-ice-03", 0, 3)
	map:addTile("tile-rock-ice-01", 0, 4)
	map:addTile("tile-rock-ice-03", 0, 5)
	map:addTile("tile-rock-ice-02", 0, 6)
	map:addTile("tile-background-ice-01", 1, 0)
	map:addTile("tile-background-ice-02", 1, 1)
	map:addTile("tile-rock-slope-ice-right-01", 1, 2)
	map:addTile("tile-rock-slope-ice-right-02", 1, 3)
	map:addTile("tile-rock-slope-ice-right-01", 1, 4)
	map:addTile("tile-rock-ice-03", 1, 5)
	map:addTile("tile-rock-ice-02", 1, 6)
	map:addTile("tile-background-ice-07", 2, 0)
	map:addTile("tile-background-ice-05", 2, 1)
	map:addTile("tile-background-ice-06", 2, 2)
	map:addTile("tile-rock-slope-ice-left-01", 2, 3)
	map:addTile("tile-background-ice-05", 2, 4)
	map:addTile("tile-packagetarget-ice-01-idle", 2, 5)
	map:addTile("tile-rock-ice-03", 2, 6)
	map:addTile("tile-background-ice-07", 3, 0)
	map:addTile("tile-background-ice-07", 3, 1)
	map:addTile("tile-geyser-ice-01-active", 3, 2)
	map:addTile("tile-rock-ice-03", 3, 4)
	map:addTile("tile-rock-ice-big-01", 3, 5)
	map:addTile("tile-background-ice-04", 4, 0)
	map:addTile("tile-background-ice-02", 4, 1)
	map:addTile("tile-background-ice-07", 4, 2)
	map:addTile("tile-ground-ice-03", 4, 3)
	map:addTile("tile-rock-ice-02", 4, 4)
	map:addTile("tile-background-ice-06", 5, 0)
	map:addTile("tile-background-ice-cave-art-01", 5, 1)
	map:addTile("tile-geyser-ice-01-active", 5, 2)
	map:addTile("tile-rock-ice-02", 5, 4)
	map:addTile("tile-rock-ice-03", 5, 5)
	map:addTile("tile-rock-ice-01", 5, 6)
	map:addTile("tile-background-ice-02", 6, 0)
	map:addTile("tile-background-ice-05", 6, 1)
	map:addTile("tile-background-ice-03", 6, 2)
	map:addTile("tile-background-ice-cave-art-01", 6, 3)
	map:addTile("bridge-wall-ice-left-01", 6, 3)
	map:addTile("tile-background-ice-05", 6, 4)
	map:addTile("tile-background-ice-03", 6, 5)
	map:addTile("tile-background-ice-02", 6, 6)
	map:addTile("tile-background-ice-01", 7, 0)
	map:addTile("tile-background-ice-cave-art-01", 7, 1)
	map:addTile("tile-background-ice-07", 7, 2)
	map:addTile("tile-background-ice-04", 7, 3)
	map:addTile("bridge-plank-ice-01", 7, 3)
	map:addTile("tile-background-ice-06", 7, 4)
	map:addTile("tile-background-ice-04", 7, 5)
	map:addTile("tile-background-ice-04", 7, 6)
	map:addTile("tile-background-ice-06", 8, 0)
	map:addTile("tile-background-ice-02", 8, 1)
	map:addTile("tile-background-ice-01", 8, 2)
	map:addTile("tile-background-ice-03", 8, 3)
	map:addTile("bridge-wall-ice-right-01", 8, 3)
	map:addTile("tile-background-ice-03", 8, 4)
	map:addTile("tile-background-ice-03", 8, 5)
	map:addTile("tile-background-ice-06", 8, 6)
	map:addTile("tile-background-ice-02", 9, 0)
	map:addTile("tile-background-ice-02", 9, 1)
	map:addTile("tile-background-ice-02", 9, 2)
	map:addTile("tile-ground-ledge-ice-left-01", 9, 3)
	map:addTile("tile-background-ice-03", 9, 4)
	map:addTile("tile-background-ice-06", 9, 5)
	map:addTile("tile-background-ice-07", 9, 6)
	map:addTile("tile-background-ice-06", 10, 0)
	map:addTile("tile-background-ice-07", 10, 1)
	map:addTile("tile-background-ice-04", 10, 2)
	map:addTile("tile-ground-ice-03", 10, 3)
	map:addTile("tile-background-ice-07", 10, 4)
	map:addTile("tile-background-ice-07", 10, 5)
	map:addTile("tile-background-ice-07", 10, 6)

	map:addEmitter("item-package-ice", 6, 2, 2, 0, "")
	map:addEmitter("item-package-ice", 6.5, 2, 1, 0, "")

	map:setSetting("fishnpc", "false")
	map:setSetting("flyingnpc", "true")
	map:setSetting("gravity", "9.81")
	map:setSetting("height", "7")
	map:setSetting("packagetransfercount", "3")
	map:addStartPosition("0", "1")
	map:setSetting("points", "100")
	map:setSetting("referencetime", "30")
	map:setSetting("theme", "ice")
	map:setSetting("waterheight", "1")
	map:setSetting("waterchangespeed", "0")
	map:setSetting("waterrisingdelay", "0")
	map:setSetting("width", "11")
	map:setSetting("wind", "0.0")
end
