dd3rll3dldldlul6(lu)ulld5(dr)d4r9ulluurrdulldd7ruurrddlruull7dll3dldldlu4l5(ul)uurrd4(dr)d4(ul)l4(dr)d4r9ulluurrdulldd7ruurrddlruull4d3lddr4dldldlu4l3(ul)uu4(rd)ululull3(dr)d4r9ulluurrdulldd7rdd3lddr4dldldl10ulluurrdulldd6r4l9drruruul4u3ruu5l9d4lululuu3(rd)ululldrdrd4r9u5rdd3lddr4dldldl9u8drruruul4u3ruu5l5rdd3l3d3r4u4dll3dld6luluurdrdulldrd4r4u4rl3dldldlu4luurdld4r9u5d3r3dldldl9u
