d4luurrurulluld3rulu3(ur)d3lurl5dll4dll7u3rlluurrdr3drdlddll3url3drruulr2(ddll)6ur3urrdr3dll4d4urr3ulullddl7d13rll3u6r3u7r5d7l3d3l3ud12luurrurullul4durr6ulullddl7d13rllu2(u3rdruul)u7rdr3u7d8l3d3l3ud14l7u3rur3drdllul4durr6u3rururrdld4lurlddlluur4duu4l7d13rllu2(u3rdruul)u7rdrruulddrdl3d8l3d3l3ud12luurrurullul4durr6u5ruuldrd4ldlluur4duu4l7d13rllu2(u3rdruul)u7rdrruul3drddld8l3d3l3ud12luurrurullul4durr6urrurdrruuldrd4ldlluur4duu4l7d13rllu2(u3rdruul)u7rdrruulddr3dld8l3d3l3ud12luurrurullul4durr7u3rdrruuldrd4lul4duu4l7d13rllu2(u3rdruul)u7rdrur4dld8l3d3l3ud12luurrurullul4durr6u4ruu3rurrdld3luldrd4lul4duu4l7d13rllu2(u3rdruul)u7rdrr3dld8l3d3l3ud12luurrurullul4durr7u8ruuldrd3luldrd4lul4duu4l7d13rlluu3rdruulu4ruu6rdrr3dld8l3d3l4udd12luurrurullul4durr7u7ruu3rurdrddlu2(3luldrd)4lul4duu4l7d13rll3u7r3u6rdrr3dld8l3d3l3ud12luurrurullul4durr6u4ruu6ruurdrd4luldrd3luldrd4lul4duu4l7d13rllu2(u3rdruul)u3rurrdrrdrr3dld8l3d3l3ud12luurrurullul4durr6u4ruu7rddlddr3uru4luldrd3luldrd4lul4duu4l7d13rllu2(u3rdruul)uru4rdrrdrr3dld8l3d3l3ud12luurrurullul4durr5u3lurrur4duu4l7d13rlluu3rdruulurrdrur3u4rdrrdrr3dld8l3d3l4udd12luurrurullul4durr5u4l7d13rll3u5rurr3u4rdrrdrr3dld8l3d3l3ud12luurru3ru4lul4durr5u4l7d13rlluu3ruu4r3u4rdrrdrr3dld8l3d3l3urullrdd12luurru3r3urrdd6lul4durr5u4l7d13rll3u3ru4r3u4rdrrdrr3dld8l3d3l3ud12luurru3r3urdrurrurrllddrulurdd3ld6lul4durr5u4l7d13rll3urrdruu4r3u4rdrrdrr3dld8l3d3l3ud12luurru3r3urdrd4l4rd4lullul4d3urr3u4l7d13r11luurrurullul4durr6u4ruu7r4d3luldrd3luldu7ru2(uldrd3l)d6lul3drru3r3urd3ruurrdrru2(uldrd3l)d6lulddu5ruurdrd6luldrr3u4l7d11r3urrdlurrurrdlu3r3u4rdrrdrr3dld8l3d3luu13ldl5u4d15ruuldrd14ldl4u3d14rdd3r3u7rurr3ullulu5l3d4l3drd14ldl3udd14r3u3ldduu3r3d13ldluud14r4urrdlul3drd14ldlu14r4u4rd3lul3drd14l10r3u7r3ulddrd3lul3drd13l9r3u7r4urrdlu3rdl3d6lul3drd12l8r3u9rulluldrd3lul3drd11l7r3u10r4u3l3drd4lul3drd10l6r3u10r3ullul3drd4lul3drd9l5r3u6r3u7rdrru7lul3drd4lul3drd8l4r3u6r3u9ruuldrd7lul3drd4lul3drd7l3r3u6r3u8ruuluur3drd7lul3drd4lul3drd6l5rdd3r3u7r4uru6lul3drd4lul3drd5l4rdd3r3u7rurruluuru7l2(ul3drd4l)3rdd3r3u7r4uru6lul3drd4lul3drdllruulluldd
