lu6luluuluu6rurru6r6ldllu6r6l4drr3ulu4rurd4lddrulu3rd4ruullddlu4l4dr3ulu6r8l3druulu7r4l4dl3ulu5r3ldd9lddrulu7r6l4dlddr5ulu6rdruulu5ru4rdrduullddr3lu3l3dluulu4ru4r3ldrr5ldd6lddlulu6r4ldll3dlddr5ulu6rdruulu7r4l3dluulu5r7ldrd3ldllu6r6l7drruldl6ulu6rddluru3ldllu4rdruulu6rd3rurdlluurlld3l3dluulu7r5l3dlluulu7r4ldd8l5d4rurrd5ldl5ulu7r6l5d6rddluru5ldl5ulu6r5l5d5rddluru4ldl5ulu5rdruulu7r3l3dluulu4rd3ruulldr4l3dlluulu6r3ldd9luurdld7r6luurdld5r4luurdld3rdruulu6rdrrlu3l3dluulu4rurrld3l3dlluulu5rdrulur
