3urur3ulu7r8l7drur5ulu6r7l5drdr3urrdluluulu5r6l5drr4ulu4rd11r7d4ldllu4rdrulurdr6u6d5luluulldldd7rdrulurdr5uruu10l6rd3rur4dl3d9luurrdulldd7rdrulurdr6u6d7l3u3ruu4lddrrddld5rdrulurdr5uruu9l5rd3rur3dl4d9luurrurddld5rdrulurdr6u6d9ld4luuru5rurddld5rdrulurdr5uruu8l4rd3rurddl5d10ludd3luu3rlu4rurddld5rdrulurdr6u6d6luu3ldld8rdrulurdr5uruu7l3rd3rurdl6d9ld3lulu3ruurddld8rdrulurdr4u4d6l3urruu4ldduul4dld8rdrulurdr3u3d9luurru3rurrd5lrddld5rdrulurdruudd9l4urdldrrurddld5rdrulurdru
