4rdd3rurrurrdr3d9l4r4d3rdrurrdruruurrdd9ldl3udd3ruullu7luldrru5r3u3rdrdrd8lr3drruru5lu4r3urrurr3drd11ldlurrd5r3d8ruurdrd9ldl3uru4l3r3d8r4ulullrrdrruruu5ldlduru5rddldllulld11lrrdrrd8rdu5l5ur3(rd)10l5r3urrurr3drd9l8ru3rdr3dld6ldl3uru7l4rd8rdrd6ldl3udd4rudrruu5lu6lru8ru3rdrru4luldrddu8l3r3u8rdurrdd5luldrd7lrr3u6rdurrdd3luldrd4luldrd5lrrddrrudd6ruu5lu4lrddrruru3l
