dlludrrul3u2(lluurdr3d)lluururdl3urddldlddr3uruuld3rulrddlu3lddrulu3rlluuldd3ruldlluurdldr4drruldl4uluurdrrddluddlluurldlld3rddluruluurd3ulddrdrruulrddllurlluurdldrddlddr4ulddrddrruldl3urdlddrruluu4ldrrurr3dlluulur
