textures = {
	["bridge-plank-01-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["bridge-plank-ice-01-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.125,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["bridge-wall-ice-left-01-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.25,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["bridge-wall-ice-right-01-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.375,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["bridge-wall-left-01-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.5,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["bridge-wall-right-01-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.625,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["bubble-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.75,
		y0 = 0,
		x1 = 0.0166015625,
		y1 = 0.0166015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 17,
		trimmedheight = 17,
		untrimmedwidth = 17,
		untrimmedheight = 17,
	},
	["bubble-02"] = {
		image = "caveexpress-entity-big",
		x0 = 0.7666015625,
		y0 = 0,
		x1 = 0.00390625,
		y1 = 0.00390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 4,
		trimmedheight = 4,
		untrimmedwidth = 4,
		untrimmedheight = 4,
	},
	["bubble-04"] = {
		image = "caveexpress-entity-big",
		x0 = 0.7666015625,
		y0 = 0,
		x1 = 0.00390625,
		y1 = 0.00390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 4,
		trimmedheight = 4,
		untrimmedwidth = 4,
		untrimmedheight = 4,
	},
	["bubble-07"] = {
		image = "caveexpress-entity-big",
		x0 = 0.7666015625,
		y0 = 0,
		x1 = 0.00390625,
		y1 = 0.00390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 4,
		trimmedheight = 4,
		untrimmedwidth = 4,
		untrimmedheight = 4,
	},
	["bubble-03"] = {
		image = "caveexpress-entity-big",
		x0 = 0.7705078125,
		y0 = 0,
		x1 = 0.009765625,
		y1 = 0.0107421875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 10,
		trimmedheight = 11,
		untrimmedwidth = 10,
		untrimmedheight = 11,
	},
	["bubble-05"] = {
		image = "caveexpress-entity-big",
		x0 = 0.7802734375,
		y0 = 0,
		x1 = 0.0126953125,
		y1 = 0.0126953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 13,
		trimmedheight = 13,
		untrimmedwidth = 13,
		untrimmedheight = 13,
	},
	["bubble-06"] = {
		image = "caveexpress-entity-big",
		x0 = 0.79296875,
		y0 = 0,
		x1 = 0.01171875,
		y1 = 0.0107421875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 12,
		trimmedheight = 11,
		untrimmedwidth = 12,
		untrimmedheight = 11,
	},
	["bubble-08"] = {
		image = "caveexpress-entity-big",
		x0 = 0.8046875,
		y0 = 0,
		x1 = 0.0068359375,
		y1 = 0.0068359375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 7,
		trimmedheight = 7,
		untrimmedwidth = 7,
		untrimmedheight = 7,
	},
	["bubble-09"] = {
		image = "caveexpress-entity-big",
		x0 = 0.8115234375,
		y0 = 0,
		x1 = 0.01171875,
		y1 = 0.0126953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 12,
		trimmedheight = 13,
		untrimmedwidth = 12,
		untrimmedheight = 13,
	},
	["cave-sign-01-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.8232421875,
		y0 = 0,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["cave-sign-02-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["cave-sign-03-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.125,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["cave-sign-04-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.25,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["cave-sign-05-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.375,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["cave-sign-06-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.5,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["cave-sign-07-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.625,
		y0 = 0.125,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["cavenumber1"] = {
		image = "caveexpress-entity-big",
		x0 = 0.75,
		y0 = 0.125,
		x1 = 0.0830078125,
		y1 = 0.0458984375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 85,
		trimmedheight = 47,
		untrimmedwidth = 85,
		untrimmedheight = 47,
	},
	["cavenumber2"] = {
		image = "caveexpress-entity-big",
		x0 = 0.8330078125,
		y0 = 0.125,
		x1 = 0.0830078125,
		y1 = 0.0458984375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 85,
		trimmedheight = 47,
		untrimmedwidth = 85,
		untrimmedheight = 47,
	},
	["cavenumber3"] = {
		image = "caveexpress-entity-big",
		x0 = 0.916015625,
		y0 = 0.125,
		x1 = 0.0830078125,
		y1 = 0.0458984375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 85,
		trimmedheight = 47,
		untrimmedwidth = 85,
		untrimmedheight = 47,
	},
	["cavenumber4"] = {
		image = "caveexpress-entity-big",
		x0 = 0,
		y0 = 0.25,
		x1 = 0.0830078125,
		y1 = 0.0458984375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 85,
		trimmedheight = 47,
		untrimmedwidth = 85,
		untrimmedheight = 47,
	},
	["cavenumber5"] = {
		image = "caveexpress-entity-big",
		x0 = 0.0830078125,
		y0 = 0.25,
		x1 = 0.0830078125,
		y1 = 0.0458984375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 85,
		trimmedheight = 47,
		untrimmedwidth = 85,
		untrimmedheight = 47,
	},
	["cavenumber6"] = {
		image = "caveexpress-entity-big",
		x0 = 0.166015625,
		y0 = 0.25,
		x1 = 0.0830078125,
		y1 = 0.0458984375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 85,
		trimmedheight = 47,
		untrimmedwidth = 85,
		untrimmedheight = 47,
	},
	["cavenumber7"] = {
		image = "caveexpress-entity-big",
		x0 = 0.2490234375,
		y0 = 0.25,
		x1 = 0.0830078125,
		y1 = 0.0458984375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 85,
		trimmedheight = 47,
		untrimmedwidth = 85,
		untrimmedheight = 47,
	},
	["cavenumber8"] = {
		image = "caveexpress-entity-big",
		x0 = 0.33203125,
		y0 = 0.25,
		x1 = 0.0830078125,
		y1 = 0.0458984375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 85,
		trimmedheight = 47,
		untrimmedwidth = 85,
		untrimmedheight = 47,
	},
	["icon-cavenumber1"] = {
		image = "caveexpress-entity-big",
		x0 = 0.4150390625,
		y0 = 0.25,
		x1 = 0.0244140625,
		y1 = 0.0166015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 25,
		trimmedheight = 17,
		untrimmedwidth = 25,
		untrimmedheight = 17,
	},
	["icon-cavenumber2"] = {
		image = "caveexpress-entity-big",
		x0 = 0.439453125,
		y0 = 0.25,
		x1 = 0.0244140625,
		y1 = 0.0166015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 25,
		trimmedheight = 17,
		untrimmedwidth = 25,
		untrimmedheight = 17,
	},
	["icon-cavenumber3"] = {
		image = "caveexpress-entity-big",
		x0 = 0.4638671875,
		y0 = 0.25,
		x1 = 0.0244140625,
		y1 = 0.0166015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 25,
		trimmedheight = 17,
		untrimmedwidth = 25,
		untrimmedheight = 17,
	},
	["icon-cavenumber4"] = {
		image = "caveexpress-entity-big",
		x0 = 0.48828125,
		y0 = 0.25,
		x1 = 0.0244140625,
		y1 = 0.0166015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 25,
		trimmedheight = 17,
		untrimmedwidth = 25,
		untrimmedheight = 17,
	},
	["icon-cavenumber5"] = {
		image = "caveexpress-entity-big",
		x0 = 0.5126953125,
		y0 = 0.25,
		x1 = 0.0244140625,
		y1 = 0.0166015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 25,
		trimmedheight = 17,
		untrimmedwidth = 25,
		untrimmedheight = 17,
	},
	["icon-cavenumber6"] = {
		image = "caveexpress-entity-big",
		x0 = 0.537109375,
		y0 = 0.25,
		x1 = 0.0244140625,
		y1 = 0.0166015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 25,
		trimmedheight = 17,
		untrimmedwidth = 25,
		untrimmedheight = 17,
	},
	["icon-cavenumber7"] = {
		image = "caveexpress-entity-big",
		x0 = 0.5615234375,
		y0 = 0.25,
		x1 = 0.0244140625,
		y1 = 0.0166015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 25,
		trimmedheight = 17,
		untrimmedwidth = 25,
		untrimmedheight = 17,
	},
	["icon-cavenumber8"] = {
		image = "caveexpress-entity-big",
		x0 = 0.5859375,
		y0 = 0.25,
		x1 = 0.0244140625,
		y1 = 0.0166015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 25,
		trimmedheight = 17,
		untrimmedwidth = 25,
		untrimmedheight = 17,
	},
	["icon-targetcave"] = {
		image = "caveexpress-entity-big",
		x0 = 0.6103515625,
		y0 = 0.25,
		x1 = 0.0126953125,
		y1 = 0.0087890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 13,
		trimmedheight = 9,
		untrimmedwidth = 13,
		untrimmedheight = 9,
	},
	["item-apple-idle-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.623046875,
		y0 = 0.25,
		x1 = 0.04296875,
		y1 = 0.048828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 44,
		trimmedheight = 50,
		untrimmedwidth = 44,
		untrimmedheight = 50,
	},
	["item-banana-idle-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.666015625,
		y0 = 0.25,
		x1 = 0.048828125,
		y1 = 0.044921875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 50,
		trimmedheight = 46,
		untrimmedwidth = 50,
		untrimmedheight = 46,
	},
	["item-bomb-idle-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.71484375,
		y0 = 0.25,
		x1 = 0.056640625,
		y1 = 0.056640625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 58,
		trimmedheight = 58,
		untrimmedwidth = 58,
		untrimmedheight = 58,
	},
	["item-egg-idle-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.771484375,
		y0 = 0.25,
		x1 = 0.04296875,
		y1 = 0.0517578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 44,
		trimmedheight = 53,
		untrimmedwidth = 44,
		untrimmedheight = 53,
	},
	["item-package-ice-idle-middle-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.814453125,
		y0 = 0.25,
		x1 = 0.064453125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 64,
		untrimmedwidth = 66,
		untrimmedheight = 64,
	},
	["item-package-idle-middle-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.87890625,
		y0 = 0.25,
		x1 = 0.064453125,
		y1 = 0.0615234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 63,
		untrimmedwidth = 66,
		untrimmedheight = 63,
	},
	["item-stone-idle-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0,
		y0 = 0.3125,
		x1 = 0.08203125,
		y1 = 0.0556640625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 84,
		trimmedheight = 57,
		untrimmedwidth = 84,
		untrimmedheight = 57,
	},
	["item-stone-idle-front-02"] = {
		image = "caveexpress-entity-big",
		x0 = 0.08203125,
		y0 = 0.3125,
		x1 = 0.08203125,
		y1 = 0.0556640625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 84,
		trimmedheight = 57,
		untrimmedwidth = 84,
		untrimmedheight = 57,
	},
	["item-stone-idle-front-03"] = {
		image = "caveexpress-entity-big",
		x0 = 0.1640625,
		y0 = 0.3125,
		x1 = 0.08203125,
		y1 = 0.0556640625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 84,
		trimmedheight = 57,
		untrimmedwidth = 84,
		untrimmedheight = 57,
	},
	["liane-01-front-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.24609375,
		y0 = 0.3125,
		x1 = 0.0322265625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 33,
		trimmedheight = 250,
		untrimmedwidth = 33,
		untrimmedheight = 250,
	},
	["particle-water"] = {
		image = "caveexpress-entity-big",
		x0 = 0.2783203125,
		y0 = 0.3125,
		x1 = 0.0048828125,
		y1 = 0.0048828125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 5,
		trimmedheight = 5,
		untrimmedwidth = 5,
		untrimmedheight = 5,
	},
	["player-crashed-middle-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.283203125,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.111328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 114,
		untrimmedwidth = 128,
		untrimmedheight = 114,
	},
	["player-flying-middle-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.408203125,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.111328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 114,
		untrimmedwidth = 128,
		untrimmedheight = 114,
	},
	["player-flying-middle-02"] = {
		image = "caveexpress-entity-big",
		x0 = 0.533203125,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.111328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 114,
		untrimmedwidth = 128,
		untrimmedheight = 114,
	},
	["player-flying-middle-03"] = {
		image = "caveexpress-entity-big",
		x0 = 0.658203125,
		y0 = 0.3125,
		x1 = 0.125,
		y1 = 0.111328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 114,
		untrimmedwidth = 128,
		untrimmedheight = 114,
	},
	["rope"] = {
		image = "caveexpress-entity-big",
		x0 = 0.783203125,
		y0 = 0.3125,
		x1 = 0.0625,
		y1 = 0.0078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 8,
		untrimmedwidth = 64,
		untrimmedheight = 8,
	},
	["snow-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.845703125,
		y0 = 0.3125,
		x1 = 0.01171875,
		y1 = 0.01171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 12,
		trimmedheight = 12,
		untrimmedwidth = 12,
		untrimmedheight = 12,
	},
	["sparkle-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.857421875,
		y0 = 0.3125,
		x1 = 0.00390625,
		y1 = 0.00390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 4,
		trimmedheight = 4,
		untrimmedwidth = 4,
		untrimmedheight = 4,
	},
	["sparkle-02"] = {
		image = "caveexpress-entity-big",
		x0 = 0.861328125,
		y0 = 0.3125,
		x1 = 0.0029296875,
		y1 = 0.0029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 3,
		trimmedheight = 3,
		untrimmedwidth = 3,
		untrimmedheight = 3,
	},
	["sparkle-03"] = {
		image = "caveexpress-entity-big",
		x0 = 0.8642578125,
		y0 = 0.3125,
		x1 = 0.00390625,
		y1 = 0.00390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 4,
		trimmedheight = 4,
		untrimmedwidth = 4,
		untrimmedheight = 4,
	},
	["tree-dazed-middle-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0,
		y0 = 0.556640625,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 256,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
	["tree-idle-middle-03"] = {
		image = "caveexpress-entity-big",
		x0 = 0,
		y0 = 0.556640625,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 256,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
	["tree-idle-middle-01"] = {
		image = "caveexpress-entity-big",
		x0 = 0.25,
		y0 = 0.556640625,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 256,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
	["tree-idle-middle-02"] = {
		image = "caveexpress-entity-big",
		x0 = 0.5,
		y0 = 0.556640625,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 256,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
}
