textures = {
	["tile-packagetarget-rock-01-active-front-01"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.75,
		y0 = 0.625,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-active-front-02"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.5,
		y0 = 0.625,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-active-front-03"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.25,
		y0 = 0.875,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-active-front-04"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.25,
		y0 = 0.75,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-active-front-05"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.25,
		y0 = 0.625,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-active-front-06"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.75,
		y0 = 0.5,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-active-front-07"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.5,
		y0 = 0.5,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-active-front-08"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.25,
		y0 = 0.5,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-active-front-09"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0,
		y0 = 0.875,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-idle-front-01"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0,
		y0 = 0.75,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-01"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0,
		y0 = 0.625,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-02"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0,
		y0 = 0.5,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-03"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.75,
		y0 = 0.375,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-04"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.5,
		y0 = 0.375,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-05"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.25,
		y0 = 0.375,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-06"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0,
		y0 = 0.375,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-07"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.75,
		y0 = 0.25,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-08"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.5,
		y0 = 0.25,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-09"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.25,
		y0 = 0.25,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-10"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0,
		y0 = 0.25,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-11"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.75,
		y0 = 0.125,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-12"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.5,
		y0 = 0.125,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-13"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.25,
		y0 = 0.125,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-14"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0,
		y0 = 0.125,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-15"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.75,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-16"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.5,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-17"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0.25,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-18"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-packagetarget-rock-01-rotate-front-19"] = {
		image = "caveexpress-packagetarget-rock-big",
		x0 = 0,
		y0 = 0.75,
		x1 = 0.25,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
}
