drr3d3rdrlddrurruu5lulddu3rddrruru5luld3rddruru4ldlldrll4ulurdrrddrdllru3rdd4rul3drrdrurr3u5l3rd4luru5lulddr5drdllr3ulluul3u3drr4ulluld3rdd3r3druuru4luldrdllru6rurrd7lulddr6d3ulluul3u3drruu6r4druurrurr3urr8dllddrrudlluu4r5ururrur3ulddrdd4l3urrlu5l3dld9lululluurdr3drdllru3rdd5ruru8lulddr5drddluluruulluul3u3drruu3rdd4ruru7lulddr5dllddurrdrr2(uull)uuruu6r4drr3uru8lulddu10rur3dllruru10luld6r3drruuru8ldlddldrurduul3ud4r4dr3uru5lul3dldr3u7r4d5rll3uru10lul3dlddrrulr3drrddll4ul4u11ruurr8dllddrrudlluu3rluu3luurdldrrl6urr8duu4l3uru9lul3duu6ru4r5d3r6ull5dldrrl6urr7dullu6ldrrurrddl4uru8lulddu4ru6r5d3r6ull5d7u4r4d4r4uldr3dlddruu3luulu3rurd4l9dlluu4ldl4uru8luld
