l5dllrrddlludrr9u6l4dlldl3drruulrddl3dlddrruldluruuru3ruruu4ldduu4rddld3l3uruulldlddldrr3dlldd3ru5ldlurrurullrd3ruu4ruruulu3(ld)uu4rddld3l3ululddldrr3dlddrrul4uluuruurrdrdlldduu4rddld3l3ululddldrr4drd5l3rur4ul3uluruuruurr5drdlldduu4rddld3l3ululddldrr3dlldd3ru5lruruld3r3uluurrdduu4rddld3luur3ullrr4ullddl5dldrr3dlddrrul4uluurrdduu4rddld3luur7u3l7dldrr4drd4lrrur4uluurrddur7u6r7dllrrddllulld3luur7u4rdru3ldrddldduurrd2(lrdl)lrr3ulddld3lulddldrr3dlldd3ru4lu3ruu4ruruu4ldduu4rddld3l3ululddldrr3dlddrru3lrr4ul4u3rdrdlldduu3ruurrd3lrr4ul4dr3dld3l3ululddldrr3dlddrrul3u4ruruu4ldduu4rddld3l3ululddldrr4drdllur4ul4u3rdrdlldduu4rddld3l3ululddldrr3dllrddrrulldluurruu4rur8urrdllul5drd4ldduu4rddld3l3ululddldrr3dlddrrullr4uluurrdduu4rddld3l3rurrdrruullrr5uru4lul5drd5lulddldrr3dlddrruldlur3u4ruruuluurrdluldrd4ldduu4rddld3l3ululddldrr3dlddrrul4uluurrdduu4rddld3lul4drdllu
