#pragma once

// these values are key=value,key=value pairs in the emitter definition of the lua map files
// an example is: map:addEmitter("npc-blowing", 12, 6, 1, 0, "right=false,strength=6,size=4")

namespace caveexpress {

#define EMITTER_ANGLE "angle"
#define EMITTER_RIGHT "right"
#define EMITTER_STRENGTH "strength"
#define EMITTER_WIND_MOD_SIZE "size"

}
