7(ur)u13l12rd6(dl)d7(dr)d12l11ru6(ul)l5(dl)ldlu3rdllrru5(ur)r5(dr)dd9lullrd3ruld8ruuldrdr2(ruul)d3(duuruuld)r4udldr11dllulu5(ul)l4(dl)ddrd7rurdr4lurlld4lulu5(ur)r3(ur)u3r3l3(dl)d3(dr)ddrdrrur7ullurdr7dldllulu3(ul)u6(ur)ddul5(ld)dru3l3(dr)3d3ululuu3rdrdrdululuurdrdrrur4d6ulddldr3lddl3rurllulu4ldl4(ld)drd4rurrurdrrururdlldllururldd4lu3rlurdlldd3luu3rdd5lulu3(ur)rdrduluurduurrdrlld4ldldlddrurdldruu4ld3rurd2(rruu)4ldldururruurd3u6(ld)ru3(ur)r3u5(ld)ururu3ruulu4(ld)ruurr3u3(ld)rur3uldldr3uldrdrrddrr4drruur3(ul)rdr7dlldd6lul11urruuldrdlurruddrdrddll3dllrrddlur4u4rdrl3drr3dlldd6lul3url3drdrrulld6ruurr4u3rulrulrrurur4ulu9ldllddrdrddlldllrrdrrudll5dlluluuruuldd3urdrr3ullddldr3urruruluuru3rdlu8rddlud3(dl)lddll4dlluurr5ul3uru4rdrrddrdr3dlrrddlluudld4l4dlldd5luur4ullrr3urul4uru6rldlull4dr3drr3ul3u3drdrruldl4d7rul5uluu4ldd3rlldd3lrddllullull4uru5rl3drdluurluull4drld3luurrlluururr3durluulldrurd3lddrruulurdlldllu3rlddrruu4lddrldd4rud4lddrllddrudrr4dldd3r4urruull3udrlddrrddll4d3luur7udrl6dlddr7u7drr4urruu3l3rddllu5dll4urlddll3udrl4d4ruulrddrruul3rdd4rurr5u7ldldduururuuldd3ruul3rdd3ruul3ullull3d3ul3rurdr4drdd3l5udlr4drr5dlld4l5udlr4dl3r5u2(dlrd)drrurr3ulludl3r4d5l3r3udlrdrrulr4uruullrd5uluu3ldu4r5dul
