rruul4druul5ulldrur5duulur3dluur3ulldrur3dlu3drrdrrullddll4u3drrll3urrddlruullddrddruurrdllulluurrduluurddl3ulldrurdrddllu3drrdrrullddll4u3drrll3urrddlruullddrddruurrdllulluurrdullddrrdrrullddllurr3ulldduurrdldr4uldd3ulldrurdrddlludrrddlluurdr3uldd3ulldrurdrddlludrruulduulldrurdr6dll5u5drr6ululldr
