ld10ldd8rdrdruldluu8luu7rdurdu8ldd6rud6lddldd9r3drdrull3urrdluldu8l4d6r3u3d6l4u4r3d3u3rlddlur3dluruullu4l4drruuludrddlud3rurruullull3d3urrdl3rddlludrruullulldllurlluu6rud5luu4rdrdlrrullu4luu4rduldu3lddrrudllddrudrull3urrdluld2(4rurrdll)rruurrddrdrrdd4rurd6luruulu5rddlldlruululldrdrluurdrrurdurrdl3drruluddludllurrd3rdd5l4drruld3ruld5l4u4rdlu3rdlduu5l4d3r3u3d3ruulldldr4l4u3r3d3u3lddrdrll3ulldru4rddluddlluurdlddlluurlddllurd3ruulldr3u3lddruddrruuldllurlur4dluru5rddlururrdlrdluu3rdlrdl4urd
