drrll4dllddrrurrddrdrrul3uruurdldrrdrruuldll4uluur5dld3rur3dulull4ulddllurrdrdd3lud3ruulldld4rddrr3uldlluuldld4rurddlu3l4ur3dldrrdrruul3dull6ull4d4uluu5l3drr3d3rd4rdrruulddll4u3ldrd4uld3u5l3d6r4l3d3rd4rdrruuldrdlulluulldld5rurd3l5ul4dld4rll4u3ldduu3l4dllddrrurrddrdr3uddlluull4udd3rd4rluulldld3r3l7u5l3d7rur5d4u9lddrulu8rur4d
