lddrrdruud3ldrurrdrlull3d3rdrru4l3ruu3l3rdd3ldlluruurr4uruul5dldll5urrllddrulurl5drruldl3uddr3d3rdrruluu3l3rdd3ldlluruurr4uruul5dldll3uruurlddl3drdd3rdrruluu3lulrd3rdd3ldlluruu4ruruul3dlluurldd3lurrl3d3rdrru4ldl3u4rduuruuldlldldllurrl3d3rdrruluu3l3ruruuldlldldr4uruul5d3ldrdd3rdrru4ldl3udd4r3uruuldll3ullddlddrluuruu2(rr3d)3ull3ullddlddr3d3rdrru4ldluud4r4ulldlr4u3l3d
