uu2(ruur)urrdr3(ddl)lddlldd4u4lurrllddrddrrudd3rd3(dl)lur3u3dllulurru4rddlludrr4ull6ull4r2(uull)dldlluldllddr3dllddrdrddldd3r3luurd3ululuu6r4d3lrulurddrrd3r3udlluldl4rddlluurr4d3rdrr3u3dlluruulrdd3ldldll3u3drr6urr3dulruu5l4ul3u3drruuldu5ruuldurrurrdll3rddlu3ld4l4rdrr3dll3d6urrdrrdrddld3lrdururruulull3d3ruullulduuludldrl3dld4luuld4urrurrdrrllddrurdll3ulldlldd5lddrdrlu3rduud4luu4rdrrdlrd4r3ulurluulld4lrdrduurrdrluurrdd3lr3uld3ururr3d3ull3du3lulldrrddurlu3lddrur
