npcblowing = {
	width = 3.4,
	height = 1.2,
}

npcgrandpa = {
	width = 0.39,
	height = 0.57,
}

npcmammut = {
	width = 1.4,
	height = 0.97,
}

npcman = {
	width = 0.42,
	height = 0.548,
}

npcwalking = {
	width = 1.95,
	height = 0.8,
}

npcwoman = {
	width = 0.32,
	height = 0.53,
}

itemegg = {
	width = 0.26,
	height = 0.31,
	friction = 0.2,
	restitution = 0.05,
}

itemapple = {
	width = 0.4,
	height = 0.4,
}

itemstone = {
	width = 0.71,
	height = 0.44,
}

itembanana = {
	width = 0.4,
	height = 0.4,
}

itempackageice = {
	width = 0.4,
	height = 0.4,
}

itempackage = {
	width = 0.4,
	height = 0.4,
}

player = {
	width = 0.94,
	height = 0.87,
}

tree = {
	width = 2.0,
	height = 2.0,
}

itembomb = {
	friction = 0.4,
	restitution = 0.2,
}

npcfish = {
}

npcflying = {
	width = 0.3,
	height = 0.3,
}
