textures = {
	["npc-walking-attack-DIR-middle-01"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-attack-DIR-middle-02"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.25,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-attack-DIR-middle-03"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.5,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-attack-DIR-middle-04"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.75,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-attack-init-DIR-middle-01"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0,
		y0 = 0.05029296875,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-attack-init-DIR-middle-02"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.25,
		y0 = 0.05029296875,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-attack-init-DIR-middle-03"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.5,
		y0 = 0.05029296875,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-dazed-DIR-middle-01"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.75,
		y0 = 0.05029296875,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-dazed-DIR-middle-02"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0,
		y0 = 0.1005859375,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-dazed-DIR-middle-03"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.25,
		y0 = 0.1005859375,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-dazed-DIR-middle-04"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.5,
		y0 = 0.1005859375,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-dazed-DIR-middle-05"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.75,
		y0 = 0.1005859375,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-dazed-DIR-middle-06"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0,
		y0 = 0.15087890625,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-dazed-DIR-middle-07"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.25,
		y0 = 0.15087890625,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-dazed-DIR-middle-08"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.5,
		y0 = 0.15087890625,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-dazed-DIR-middle-09"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.75,
		y0 = 0.15087890625,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-idle-DIR-middle-01"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0,
		y0 = 0.201171875,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-idle-DIR-middle-02"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.25,
		y0 = 0.201171875,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-idle-DIR-middle-03"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.5,
		y0 = 0.201171875,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-idle-DIR-middle-04"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.75,
		y0 = 0.201171875,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-idle-DIR-middle-05"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0,
		y0 = 0.25146484375,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-knockout-DIR-middle-01"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.25,
		y0 = 0.25146484375,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-knockout-DIR-middle-02"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.5,
		y0 = 0.25146484375,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-knockout-DIR-middle-03"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.75,
		y0 = 0.25146484375,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-turn-DIR-middle-01"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0,
		y0 = 0.3017578125,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-turn-DIR-middle-02"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.25,
		y0 = 0.3017578125,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-turn-DIR-middle-03"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.5,
		y0 = 0.3017578125,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-turn-DIR-middle-04"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.75,
		y0 = 0.3017578125,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-turn-DIR-middle-05"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0,
		y0 = 0.35205078125,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-turn-DIR-middle-06"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.25,
		y0 = 0.35205078125,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-turn-DIR-middle-07"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.5,
		y0 = 0.35205078125,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-wakeup-DIR-middle-01"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.75,
		y0 = 0.35205078125,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-wakeup-DIR-middle-02"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0,
		y0 = 0.40234375,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-wakeup-DIR-middle-03"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.25,
		y0 = 0.40234375,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-wakeup-DIR-middle-04"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.5,
		y0 = 0.40234375,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-wakeup-DIR-middle-05"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.75,
		y0 = 0.40234375,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-wakeup-DIR-middle-06"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0,
		y0 = 0.45263671875,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-walk-DIR-middle-01"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.25,
		y0 = 0.45263671875,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-walk-DIR-middle-02"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.5,
		y0 = 0.45263671875,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-walk-DIR-middle-03"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0.75,
		y0 = 0.45263671875,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
	["npc-walking-walk-DIR-middle-04"] = {
		image = "caveexpress-npc_walking-big",
		x0 = 0,
		y0 = 0.5029296875,
		x1 = 0.25,
		y1 = 0.05029296875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 103,
		untrimmedwidth = 256,
		untrimmedheight = 103,
	},
}
