#include "CavePackerAchievement.h"

namespace cavepacker {

namespace Achievements {
Achievement STARS_3("achievement_3_x_3_stars", true);
Achievement STARS_10("achievement_10_x_3_stars", true);
Achievement STARS_300("achievement_300_x_3_stars", true);
Achievement PUZZLES_10("achievement_10_puzzles", true);
Achievement PUZZLES_20("achievement_20_puzzles", true);
Achievement PUZZLES_30("achievement_30_puzzles", true);
Achievement PUZZLES_40("achievement_40_puzzles", true);
Achievement PUZZLES_50("achievement_50_puzzles", true);
Achievement PUZZLES_60("achievement_60_puzzles", true);
Achievement PUZZLES_70("achievement_70_puzzles", true);
Achievement PUZZLES_80("achievement_80_puzzles", true);
Achievement PUZZLES_90("achievement_90_puzzles", true);
Achievement PUZZLES_100("achievement_100_puzzles", true);
Achievement FINISHED_TUTORIALS("achievement_finished_tutorials");
Achievement FINISHED_XSOKOBAN("achievement_finished_xsokoban");
Achievement FINISHED_GRIGORUSHA("achievement_finished_the_grigorusha_campaign");
Achievement FINSIHED_KSOKOBAN("achievement_finsihed_the_ksokoban_campaign");
}

}
