3ulul4(ld)drurudld5(dr)r5(ur)uuldlluruulddrdd3luurrlld4ldld4(dr)ruluuruu3ruu4ld3ldldd3r3luuruulddu3ru5rddllurdll3drruld3lulluuluu3rdrr3d5ululddldl3drrdrr3urr5ululul3(ld)duruururrdlrrdr5dllulluuruulrruuldrddldlddrur3u5drr4ulr4dlluur3l3drd3rud3lululrurdrd
