5(ur)ulddrl4(ld)d3(rd)rrdr3uldduuruul3d3uruuld3ulldrurd3ldldlddrdrd3ruuldrr3ulluurdldrdrddllurlur3u3ldrlldlddrurrllddrudrddrrldr4ulldllull3(dr)rllululldrl3(ld)7rur7ulurdlldlldrddl3d3urr3dld4luurduururruulldldruuruuldldll3r3uldrd3rulurdrr3drr6ulu8lrddlulrru4r3dl4d3r3luurdldrl4urdldllddrulurlurl4d3luld4rdrddllruludlduluurdulluurrdluluurr2(drllddru)drdd4r5ulluulurululu3rlldlldl3dururuudrru5drr4dld3r2(ulru)u3l3r5u3dll3ururldl2(dlrd)urruuldrdluururrddllrrdlrddlr5d4lrruurlddrr4udl
