lu5luulluu6rdd4l3dluuru4rdrd4l3r4u6ldd5r5luu6r3drdlrdrruul4ulu8ldl4dldd3rdr3uru4rddlldlludrrul4rdrruul4ulu8ldl4dld3lddrrudlluurrd4rdrurru3r4u6ldd5r5luu6r3drdlld4luudd4rur4u6ldd5r5luu6r3drddrruul4ulu8ldl4dldld4rdr3udd4rur4u6lddr3drrurd3lurrlluu4r3ldldruulluu6r3d
