#pragma once

#define CMD_CL_CONNECT "cl_connect"
#define CMD_CL_DISCONNECT "cl_disconnect"
#define CMD_UI_PUSH "ui_push"
#define CMD_UI_RESTART "ui_restart"
#define CMD_UI_POP "ui_pop"
#define CMD_UI_FOCUS_PREV "ui_focus_prev"
#define CMD_UI_FOCUS_NEXT "ui_focus_next"
#define CMD_UI_PRINTSTACK "ui_printstack"
#define CMD_UI_EXECUTE "ui_execute"
#define CMD_QUIT "quit"
#define CMD_SCREENSHOT "screenshot"
#define CMD_CL_PINGSERVERS "cl_pingservers"
#define CMD_MAP_START "map"
#define CMD_STATUS "status"
#define CMD_LIST_MAPS "listmaps"
#define CMD_UNLOCK "unlock"
#define CMD_MOVE_UP "move_up"
#define CMD_MOVE_DOWN "move_down"
#define CMD_ZOOM "zoom"
#define CMD_MOVE_LEFT "move_left"
#define CMD_MOVE_RIGHT "move_right"
#define CMD_START "start"
#define CMD_FINISHMAP "finish"
#define CMD_MAP_RESTART "map_restart"
#define CMD_MAP_PAUSE "cl_triggerpause"
#define CMD_LOADMAP "loadmap"
