function getName()
	return "Wind 02"
end

function onMapLoaded()
end

function initMap()
	-- get the current map context
	local map = Map.get()
	map:addTile("tile-background-big-01", 0, 0)
	map:addTile("tile-ground-01", 0, 2)
	map:addTile("tile-background-04", 0, 3)
	map:addTile("tile-background-03", 0, 4)
	map:addTile("tile-background-03", 0, 5)
	map:addTile("tile-background-04", 0, 6)
	map:addTile("tile-rock-right-04", 0, 7)
	map:addTile("tile-rock-right-04", 0, 8)
	map:addTile("tile-background-04", 0, 9)
	map:addTile("tile-background-02", 0, 10)
	map:addTile("tile-background-02", 0, 11)
	map:addTile("tile-rock-slope-right-01", 1, 2)
	map:addTile("tile-rock-slope-left-02", 1, 3)
	map:addTile("tile-background-04", 1, 4)
	map:addTile("tile-background-04", 1, 5)
	map:addTile("tile-rock-slope-left-01", 1, 6)
	map:addTile("tile-rock-big-01", 1, 7)
	map:addTile("tile-rock-shim-01", 1, 9)
	map:addTile("tile-background-03", 1, 10)
	map:addTile("tile-background-01", 1, 11)
	map:addTile("tile-background-02", 2, 0)
	map:addTile("tile-background-02", 2, 1)
	map:addTile("tile-background-01", 2, 2)
	map:addTile("tile-ground-01", 2, 3)
	map:addTile("tile-rock-02", 2, 4)
	map:addTile("tile-rock-03", 2, 5)
	map:addTile("tile-rock-02", 2, 6)
	map:addTile("tile-background-02", 2, 9)
	map:addTile("tile-background-01", 2, 10)
	map:addTile("tile-background-04", 2, 11)
	map:addTile("tile-background-04", 3, 0)
	map:addTile("tile-background-03", 3, 1)
	map:addTile("tile-background-02", 3, 2)
	map:addTile("tile-background-02", 3, 3)
	map:addTile("tile-background-03", 3, 4)
	map:addTile("tile-background-04", 3, 5)
	map:addTile("tile-rock-slope-right-01", 3, 6)
	map:addTile("tile-rock-02", 3, 7)
	map:addTile("tile-rock-slope-right-02", 3, 8)
	map:addTile("tile-background-02", 3, 9)
	map:addTile("tile-background-02", 3, 10)
	map:addTile("tile-background-04", 3, 11)
	map:addTile("tile-rock-03", 4, 0)
	map:addTile("tile-rock-02", 4, 1)
	map:addTile("tile-rock-slope-left-02", 4, 2)
	map:addTile("tile-background-01", 4, 3)
	map:addTile("tile-background-02", 4, 4)
	map:addTile("tile-background-03", 4, 5)
	map:addTile("tile-background-02", 4, 6)
	map:addTile("tile-ground-01", 4, 7)
	map:addTile("tile-background-03", 4, 8)
	map:addTile("tile-background-02", 4, 9)
	map:addTile("tile-background-03", 4, 10)
	map:addTile("tile-background-02", 4, 11)
	map:addTile("tile-rock-02", 5, 0)
	map:addTile("tile-rock-03", 5, 1)
	map:addTile("tile-rock-02", 5, 2)
	map:addTile("tile-rock-03", 5, 3)
	map:addTile("tile-rock-shim-01", 5, 4)
	map:addTile("tile-background-02", 5, 5)
	map:addTile("tile-background-02", 5, 6)
	map:addTile("tile-ground-02", 5, 7)
	map:addTile("tile-background-04", 5, 8)
	map:addTile("tile-background-big-01", 5, 9)
	map:addTile("tile-background-04", 5, 11)
	map:addTile("tile-background-02", 6, 0)
	map:addTile("tile-background-04", 6, 1)
	map:addTile("tile-background-02", 6, 2)
	map:addTile("tile-background-01", 6, 3)
	map:addTile("tile-background-04", 6, 4)
	map:addTile("tile-background-02", 6, 5)
	map:addTile("tile-background-02", 6, 6)
	map:addTile("tile-ground-01", 6, 7)
	map:addTile("tile-background-04", 6, 8)
	map:addTile("tile-background-04", 6, 11)
	map:addTile("tile-background-02", 7, 0)
	map:addTile("tile-background-02", 7, 1)
	map:addTile("tile-background-04", 7, 2)
	map:addTile("tile-background-01", 7, 3)
	map:addTile("tile-background-01", 7, 4)
	map:addTile("tile-background-02", 7, 5)
	map:addTile("tile-rock-slope-left-01", 7, 6)
	map:addTile("tile-rock-03", 7, 7)
	map:addTile("tile-rock-slope-left-02", 7, 8)
	map:addTile("tile-background-01", 7, 9)
	map:addTile("tile-background-02", 7, 10)
	map:addTile("tile-background-04", 7, 11)
	map:addTile("tile-background-02", 8, 0)
	map:addTile("tile-background-03", 8, 1)
	map:addTile("tile-background-02", 8, 2)
	map:addTile("tile-ground-01", 8, 3)
	map:addTile("tile-rock-01", 8, 4)
	map:addTile("tile-rock-02", 8, 5)
	map:addTile("tile-rock-03", 8, 6)
	map:addTile("tile-rock-big-01", 8, 7)
	map:addTile("tile-background-01", 8, 9)
	map:addTile("tile-background-02", 8, 10)
	map:addTile("tile-background-01", 8, 11)
	map:addTile("tile-background-04", 9, 0)
	map:addTile("tile-background-01", 9, 1)
	map:addTile("tile-background-04", 9, 2)
	map:addTile("tile-packagetarget-rock-01-idle", 9, 3)
	map:addTile("tile-rock-big-01", 9, 4)
	map:addTile("tile-rock-02", 9, 6)
	map:addTile("tile-background-01", 9, 9)
	map:addTile("tile-background-01", 9, 10)
	map:addTile("tile-background-01", 9, 11)
	map:addTile("tile-background-04", 10, 0)
	map:addTile("tile-background-02", 10, 1)
	map:addTile("tile-background-04", 10, 2)
	map:addTile("tile-rock-slope-right-01", 10, 3)
	map:addTile("tile-rock-03", 10, 6)
	map:addTile("tile-rock-02", 10, 7)
	map:addTile("tile-rock-02", 10, 8)
	map:addTile("tile-background-04", 10, 9)
	map:addTile("tile-background-04", 10, 10)
	map:addTile("tile-background-02", 10, 11)
	map:addTile("tile-background-04", 11, 0)
	map:addTile("tile-background-04", 11, 1)
	map:addTile("tile-background-02", 11, 2)
	map:addTile("tile-background-03", 11, 3)
	map:addTile("tile-ground-01", 11, 4)
	map:addTile("tile-rock-03", 11, 5)
	map:addTile("tile-rock-02", 11, 6)
	map:addTile("tile-rock-big-01", 11, 7)
	map:addTile("tile-background-02", 11, 9)
	map:addTile("tile-background-big-01", 11, 10)
	map:addTile("tile-background-02", 12, 0)
	map:addTile("tile-background-03", 12, 1)
	map:addTile("tile-background-04", 12, 2)
	map:addTile("tile-background-02", 12, 3)
	map:addTile("tile-background-03", 12, 4)
	map:addTile("tile-rock-slope-right-01", 12, 5)
	map:addTile("tile-rock-03", 12, 6)
	map:addTile("tile-background-03", 12, 9)
	map:addTile("tile-background-01", 13, 0)
	map:addTile("tile-background-04", 13, 1)
	map:addTile("tile-background-big-01", 13, 2)
	map:addTile("tile-background-02", 13, 4)
	map:addTile("tile-background-04", 13, 5)
	map:addTile("tile-ground-01", 13, 6)
	map:addTile("tile-rock-02", 13, 7)
	map:addTile("tile-rock-03", 13, 8)
	map:addTile("tile-background-02", 13, 9)
	map:addTile("tile-background-04", 13, 10)
	map:addTile("tile-background-02", 13, 11)
	map:addTile("tile-background-04", 14, 0)
	map:addTile("tile-background-02", 14, 1)
	map:addTile("tile-background-03", 14, 4)
	map:addTile("tile-ground-01", 14, 5)
	map:addTile("tile-rock-02", 14, 6)
	map:addTile("tile-rock-03", 14, 7)
	map:addTile("tile-rock-02", 14, 8)
	map:addTile("tile-background-04", 14, 9)
	map:addTile("tile-background-01", 14, 10)
	map:addTile("tile-background-04", 14, 11)
	map:addTile("tile-rock-03", 15, 0)
	map:addTile("tile-rock-03", 15, 1)
	map:addTile("tile-rock-02", 15, 2)
	map:addTile("tile-rock-shim-01", 15, 3)
	map:addTile("tile-background-01", 15, 4)
	map:addTile("tile-background-02", 15, 5)
	map:addTile("tile-background-02", 15, 6)
	map:addTile("tile-ground-03", 15, 7)
	map:addTile("tile-rock-03", 15, 8)
	map:addTile("tile-background-04", 15, 9)
	map:addTile("tile-background-03", 15, 10)
	map:addTile("tile-background-02", 15, 11)
	map:addTile("tile-background-01", 16, 0)
	map:addTile("tile-background-04", 16, 1)
	map:addTile("tile-background-02", 16, 2)
	map:addTile("tile-background-big-01", 16, 3)
	map:addTile("tile-background-02", 16, 5)
	map:addTile("tile-background-04", 16, 6)
	map:addTile("tile-ground-01", 16, 7)
	map:addTile("tile-rock-02", 16, 8)
	map:addTile("tile-rock-slope-left-02", 16, 9)
	map:addTile("tile-background-cave-art-01", 16, 10)
	map:addTile("tile-background-01", 16, 11)
	map:addTile("tile-background-04", 17, 0)
	map:addTile("tile-background-02", 17, 1)
	map:addTile("tile-background-02", 17, 2)
	map:addTile("tile-background-03", 17, 5)
	map:addTile("tile-background-02", 17, 6)
	map:addTile("tile-ground-04", 17, 7)
	map:addTile("tile-rock-big-01", 17, 8)
	map:addTile("tile-rock-03", 17, 10)
	map:addTile("tile-rock-03", 17, 11)
	map:addTile("tile-background-big-01", 18, 0)
	map:addTile("tile-ground-04", 18, 2)
	map:addTile("tile-rock-big-01", 18, 3)
	map:addTile("tile-background-03", 18, 5)
	map:addTile("tile-background-01", 18, 6)
	map:addTile("tile-ground-03", 18, 7)
	map:addTile("tile-rock-03", 18, 10)
	map:addTile("tile-rock-02", 18, 11)
	map:addTile("tile-ground-03", 19, 2)
	map:addTile("tile-background-02", 19, 5)
	map:addTile("tile-background-03", 19, 6)
	map:addTile("tile-background-02", 19, 7)
	map:addTile("tile-rock-slope-right-01", 19, 8)
	map:addTile("tile-rock-02", 19, 9)
	map:addTile("tile-rock-03", 19, 10)
	map:addTile("tile-rock-02", 19, 11)
	map:addTile("tile-background-02", 20, 0)
	map:addTile("tile-background-04", 20, 1)
	map:addTile("tile-background-big-01", 20, 2)
	map:addTile("tile-rock-slope-right-01", 20, 4)
	map:addTile("tile-rock-slope-left-02", 20, 5)
	map:addTile("tile-background-03", 20, 6)
	map:addTile("tile-background-02", 20, 7)
	map:addTile("tile-background-big-01", 20, 8)
	map:addTile("tile-rock-slope-right-01", 20, 10)
	map:addTile("tile-rock-03", 20, 11)
	map:addTile("tile-rock-slope-left-02", 21, 0)
	map:addTile("tile-background-02", 21, 1)
	map:addTile("tile-background-01", 21, 4)
	map:addTile("tile-rock-slope-right-01", 21, 5)
	map:addTile("tile-rock-slope-left-02", 21, 6)
	map:addTile("tile-background-03", 21, 7)
	map:addTile("tile-background-02", 21, 10)
	map:addTile("tile-ground-03", 21, 11)
	map:addTile("tile-rock-big-01", 22, 0)
	map:addTile("tile-rock-01", 22, 2)
	map:addTile("tile-rock-shim-01", 22, 3)
	map:addTile("tile-background-02", 22, 4)
	map:addTile("tile-background-04", 22, 5)
	map:addTile("tile-ground-03", 22, 6)
	map:addTile("tile-rock-big-01", 22, 7)
	map:addTile("tile-background-03", 22, 9)
	map:addTile("tile-background-02", 22, 10)
	map:addTile("tile-ground-02", 22, 11)
	map:addTile("tile-rock-slope-right-02", 23, 2)
	map:addTile("tile-background-03", 23, 3)
	map:addTile("tile-background-04", 23, 4)
	map:addTile("tile-background-02", 23, 5)
	map:addTile("tile-ground-02", 23, 6)
	map:addTile("tile-background-04", 23, 9)
	map:addTile("tile-background-02", 23, 10)
	map:addTile("tile-ground-03", 23, 11)
	map:addTile("tile-background-03", 24, 0)
	map:addTile("tile-background-02", 24, 1)
	map:addTile("tile-background-02", 24, 2)
	map:addTile("tile-background-02", 24, 3)
	map:addTile("tile-background-02", 24, 4)
	map:addTile("tile-background-01", 24, 5)
	map:addTile("tile-ground-06", 24, 6)
	map:addTile("tile-background-03", 24, 7)
	map:addTile("tile-background-02", 24, 8)
	map:addTile("tile-background-01", 24, 9)
	map:addTile("tile-background-02", 24, 10)
	map:addTile("tile-ground-02", 24, 11)
	map:addTile("tile-background-02", 25, 0)
	map:addTile("tile-background-03", 25, 1)
	map:addTile("tile-background-04", 25, 2)
	map:addTile("tile-background-02", 25, 3)
	map:addTile("tile-ground-03", 25, 4)
	map:addTile("tile-rock-big-01", 25, 5)
	map:addTile("tile-rock-slope-left-02", 25, 7)
	map:addTile("tile-background-02", 25, 8)
	map:addTile("tile-background-big-01", 25, 9)
	map:addTile("tile-ground-03", 25, 11)
	map:addTile("tile-background-big-01", 26, 0)
	map:addTile("tile-background-02", 26, 2)
	map:addTile("tile-background-02", 26, 3)
	map:addTile("tile-ground-03", 26, 4)
	map:addTile("tile-rock-big-01", 26, 7)
	map:addTile("tile-ground-03", 26, 11)
	map:addTile("tile-background-03", 27, 2)
	map:addTile("tile-ground-03", 27, 3)
	map:addTile("tile-rock-01", 27, 4)
	map:addTile("tile-rock-02", 27, 5)
	map:addTile("tile-rock-02", 27, 6)
	map:addTile("tile-background-02", 27, 9)
	map:addTile("tile-background-02", 27, 10)
	map:addTile("tile-ground-04", 27, 11)
	map:addTile("tile-background-02", 28, 0)
	map:addTile("tile-background-02", 28, 1)
	map:addTile("tile-background-02", 28, 2)
	map:addTile("tile-ground-02", 28, 3)
	map:addTile("tile-rock-03", 28, 4)
	map:addTile("tile-rock-03", 28, 5)
	map:addTile("tile-rock-01", 28, 6)
	map:addTile("tile-rock-03", 28, 7)
	map:addTile("tile-rock-slope-right-02", 28, 8)
	map:addTile("tile-background-03", 28, 9)
	map:addTile("tile-background-01", 28, 10)
	map:addTile("tile-ground-01", 28, 11)
	map:addTile("tile-background-01", 29, 0)
	map:addTile("tile-background-03", 29, 1)
	map:addTile("tile-background-04", 29, 2)
	map:addTile("tile-ground-03", 29, 3)
	map:addTile("tile-rock-02", 29, 4)
	map:addTile("tile-rock-big-01", 29, 5)
	map:addTile("tile-rock-01", 29, 7)
	map:addTile("tile-background-02", 29, 8)
	map:addTile("tile-background-01", 29, 9)
	map:addTile("tile-background-03", 29, 10)
	map:addTile("tile-ground-ledge-right-01", 29, 11)
	map:addTile("tile-background-04", 30, 0)
	map:addTile("tile-background-01", 30, 1)
	map:addTile("tile-rock-slope-left-01", 30, 2)
	map:addTile("tile-rock-02", 30, 3)
	map:addTile("tile-rock-03", 30, 4)
	map:addTile("tile-rock-03", 30, 7)
	map:addTile("tile-background-02", 30, 8)
	map:addTile("tile-background-02", 30, 9)
	map:addTile("tile-background-03", 30, 10)
	map:addTile("tile-ground-ledge-right-02", 30, 11)
	map:addTile("tile-background-04", 31, 0)
	map:addTile("tile-background-04", 31, 1)
	map:addTile("tile-packagetarget-rock-01-idle", 31, 2)
	map:addTile("tile-rock-big-01", 31, 3)
	map:addTile("tile-rock-02", 31, 5)
	map:addTile("tile-rock-slope-right-02", 31, 6)
	map:addTile("tile-background-03", 31, 7)
	map:addTile("tile-background-01", 31, 8)
	map:addTile("tile-background-01", 31, 9)
	map:addTile("tile-background-02", 31, 10)
	map:addTile("tile-ground-05", 31, 11)
	map:addTile("tile-background-01", 32, 0)
	map:addTile("tile-background-04", 32, 1)
	map:addTile("tile-ground-01", 32, 2)
	map:addTile("tile-rock-slope-right-02", 32, 5)
	map:addTile("tile-background-03", 32, 6)
	map:addTile("tile-background-01", 32, 7)
	map:addTile("tile-background-04", 32, 8)
	map:addTile("tile-rock-slope-left-01", 32, 9)
	map:addTile("tile-rock-03", 32, 10)
	map:addTile("tile-ground-ledge-left-01", 32, 11)
	map:addTile("tile-background-03", 33, 0)
	map:addTile("tile-background-03", 33, 1)
	map:addTile("tile-background-03", 33, 2)
	map:addTile("tile-ground-02", 33, 3)
	map:addTile("tile-background-04", 33, 4)
	map:addTile("tile-background-02", 33, 5)
	map:addTile("tile-background-03", 33, 6)
	map:addTile("tile-background-01", 33, 7)
	map:addTile("tile-background-01", 33, 8)
	map:addTile("tile-packagetarget-rock-01-idle", 33, 9)
	map:addTile("tile-rock-big-01", 33, 10)
	map:addTile("tile-background-01", 34, 0)
	map:addTile("tile-background-04", 34, 1)
	map:addTile("tile-background-02", 34, 2)
	map:addTile("tile-background-03", 34, 3)
	map:addTile("bridge-wall-left-01", 34, 3)
	map:addTile("tile-background-02", 34, 4)
	map:addTile("tile-background-01", 34, 5)
	map:addTile("tile-rock-slope-left-01", 34, 6)
	map:addTile("tile-rock-big-01", 34, 7)
	map:addTile("tile-rock-02", 34, 9)
	map:addTile("tile-background-02", 35, 0)
	map:addTile("tile-background-04", 35, 1)
	map:addTile("tile-background-03", 35, 2)
	map:addTile("tile-background-03", 35, 3)
	map:addTile("bridge-plank-01", 35, 3)
	map:addTile("tile-background-02", 35, 4)
	map:addTile("tile-background-01", 35, 5)
	map:addTile("tile-ground-01", 35, 6)
	map:addTile("tile-rock-03", 35, 9)
	map:addTile("tile-rock-02", 35, 10)
	map:addTile("tile-rock-03", 35, 11)
	map:addTile("tile-background-04", 36, 0)
	map:addTile("tile-background-03", 36, 1)
	map:addTile("tile-background-03", 36, 2)
	map:addTile("tile-background-02", 36, 3)
	map:addTile("bridge-plank-01", 36, 3)
	map:addTile("tile-background-02", 36, 4)
	map:addTile("tile-background-03", 36, 5)
	map:addTile("tile-background-01", 36, 6)
	map:addTile("tile-rock-slope-right-01", 36, 7)
	map:addTile("tile-rock-02", 36, 8)
	map:addTile("tile-rock-02", 36, 9)
	map:addTile("tile-rock-03", 36, 10)
	map:addTile("tile-rock-02", 36, 11)
	map:addTile("tile-background-04", 37, 0)
	map:addTile("tile-background-04", 37, 1)
	map:addTile("tile-background-03", 37, 2)
	map:addTile("tile-background-02", 37, 3)
	map:addTile("bridge-wall-right-01", 37, 3)
	map:addTile("tile-background-01", 37, 4)
	map:addTile("tile-background-03", 37, 5)
	map:addTile("tile-background-01", 37, 6)
	map:addTile("tile-background-01", 37, 7)
	map:addTile("tile-background-01", 37, 8)
	map:addTile("tile-ground-04", 37, 9)
	map:addTile("tile-rock-big-01", 37, 10)
	map:addTile("tile-background-02", 38, 0)
	map:addTile("tile-background-01", 38, 1)
	map:addTile("tile-background-02", 38, 2)
	map:addTile("tile-ground-01", 38, 3)
	map:addTile("tile-rock-big-01", 38, 4)
	map:addTile("tile-rock-slope-left-02", 38, 6)
	map:addTile("tile-background-03", 38, 7)
	map:addTile("tile-background-02", 38, 8)
	map:addTile("tile-rock-slope-right-01", 38, 9)
	map:addTile("tile-background-01", 39, 0)
	map:addTile("tile-background-02", 39, 1)
	map:addTile("tile-background-02", 39, 2)
	map:addTile("tile-ground-02", 39, 3)
	map:addTile("tile-rock-02", 39, 6)
	map:addTile("tile-background-big-01", 39, 7)
	map:addTile("tile-background-03", 39, 9)
	map:addTile("tile-ground-04", 39, 10)
	map:addTile("tile-rock-03", 39, 11)
	map:addTile("tile-background-big-01", 40, 0)
	map:addTile("tile-background-02", 40, 2)
	map:addTile("tile-rock-left-04", 40, 3)
	map:addTile("tile-rock-left-04", 40, 4)
	map:addTile("tile-ground-05", 40, 5)
	map:addTile("tile-background-02", 40, 6)
	map:addTile("tile-rock-slope-left-01", 40, 9)
	map:addTile("tile-rock-03", 40, 10)
	map:addTile("tile-rock-02", 40, 11)
	map:addTile("tile-background-03", 41, 2)
	map:addTile("tile-background-02", 41, 3)
	map:addTile("tile-background-01", 41, 4)
	map:addTile("tile-background-03", 41, 5)
	map:addTile("tile-background-01", 41, 6)
	map:addTile("tile-background-01", 41, 7)
	map:addTile("tile-background-01", 41, 8)
	map:addTile("tile-ground-04", 41, 9)
	map:addTile("tile-rock-big-01", 41, 10)
	map:addTile("tile-rock-big-01", 42, 0)
	map:addTile("tile-rock-slope-left-02", 42, 2)
	map:addTile("tile-background-04", 42, 3)
	map:addTile("tile-background-03", 42, 4)
	map:addTile("tile-background-03", 42, 5)
	map:addTile("tile-background-02", 42, 6)
	map:addTile("tile-background-04", 42, 7)
	map:addTile("tile-rock-slope-left-01", 42, 8)
	map:addTile("tile-rock-03", 42, 9)
	map:addTile("tile-rock-big-01", 43, 2)
	map:addTile("tile-rock-slope-left-02", 43, 4)
	map:addTile("tile-background-03", 43, 5)
	map:addTile("tile-background-03", 43, 6)
	map:addTile("tile-background-02", 43, 7)
	map:addTile("tile-ground-04", 43, 8)
	map:addTile("tile-rock-02", 43, 9)
	map:addTile("tile-rock-03", 43, 10)
	map:addTile("tile-rock-02", 43, 11)
	map:addTile("tile-background-01", 44, 0)
	map:addTile("tile-ground-02", 44, 1)
	map:addTile("tile-rock-slope-right-02", 44, 4)
	map:addTile("tile-background-01", 44, 5)
	map:addTile("tile-background-02", 44, 6)
	map:addTile("tile-background-03", 44, 7)
	map:addTile("tile-ground-02", 44, 8)
	map:addTile("tile-rock-03", 44, 9)
	map:addTile("tile-rock-02", 44, 10)
	map:addTile("tile-rock-03", 44, 11)
	map:addTile("tile-background-01", 45, 0)
	map:addTile("tile-ground-ledge-right-01", 45, 1)
	map:addTile("tile-background-02", 45, 2)
	map:addTile("tile-background-03", 45, 3)
	map:addTile("tile-background-04", 45, 4)
	map:addTile("tile-background-01", 45, 5)
	map:addTile("tile-background-03", 45, 6)
	map:addTile("tile-rock-slope-left-01", 45, 7)
	map:addTile("tile-rock-02", 45, 8)
	map:addTile("tile-rock-big-01", 45, 9)
	map:addTile("tile-rock-03", 45, 11)
	map:addTile("tile-background-01", 46, 0)
	map:addTile("tile-ground-ledge-right-02", 46, 1)
	map:addTile("tile-background-01", 46, 2)
	map:addTile("tile-background-03", 46, 3)
	map:addTile("tile-background-03", 46, 4)
	map:addTile("tile-background-02", 46, 5)
	map:addTile("tile-rock-slope-left-01", 46, 6)
	map:addTile("tile-rock-big-01", 46, 7)
	map:addTile("tile-rock-02", 46, 11)
	map:addTile("tile-background-01", 47, 0)
	map:addTile("tile-ground-06", 47, 1)
	map:addTile("tile-background-03", 47, 2)
	map:addTile("tile-background-04", 47, 3)
	map:addTile("tile-background-01", 47, 4)
	map:addTile("tile-rock-right-04", 47, 5)
	map:addTile("tile-ground-02", 47, 6)
	map:addTile("tile-rock-03", 47, 9)
	map:addTile("tile-rock-02", 47, 10)
	map:addTile("tile-rock-03", 47, 11)
	map:addTile("tile-background-02", 48, 0)
	map:addTile("tile-background-big-01", 48, 1)
	map:addTile("tile-background-03", 48, 3)
	map:addTile("tile-background-03", 48, 4)
	map:addTile("tile-ground-02", 48, 5)
	map:addTile("tile-rock-01", 48, 6)
	map:addTile("tile-rock-big-01", 48, 7)
	map:addTile("tile-rock-02", 48, 9)
	map:addTile("tile-rock-02", 48, 10)
	map:addTile("tile-rock-02", 48, 11)
	map:addTile("tile-background-02", 49, 0)
	map:addTile("tile-background-03", 49, 3)
	map:addTile("tile-background-01", 49, 4)
	map:addTile("tile-packagetarget-rock-01-idle", 49, 5)
	map:addTile("tile-rock-01", 49, 6)
	map:addTile("tile-rock-03", 49, 9)
	map:addTile("tile-rock-big-01", 49, 10)
	map:addTile("tile-background-01", 50, 0)
	map:addTile("tile-background-01", 50, 1)
	map:addTile("tile-background-02", 50, 2)
	map:addTile("tile-background-04", 50, 3)
	map:addTile("tile-background-01", 50, 4)
	map:addTile("tile-ground-02", 50, 5)
	map:addTile("tile-rock-01", 50, 6)
	map:addTile("tile-rock-03", 50, 7)
	map:addTile("tile-rock-03", 50, 8)
	map:addTile("tile-rock-01", 50, 9)
	map:addTile("tile-background-cave-art-01", 51, 0)
	map:addTile("tile-background-02", 51, 1)
	map:addTile("tile-ground-02", 51, 2)
	map:addTile("tile-background-01", 51, 3)
	map:addTile("tile-background-02", 51, 4)
	map:addTile("tile-background-02", 51, 5)
	map:addTile("tile-background-02", 51, 6)
	map:addTile("tile-background-01", 51, 7)
	map:addTile("bridge-wall-left-01", 51, 7)
	map:addTile("tile-background-03", 51, 8)
	map:addTile("tile-background-04", 51, 9)
	map:addTile("tile-background-big-01", 51, 10)
	map:addTile("tile-background-01", 52, 0)
	map:addTile("tile-background-03", 52, 1)
	map:addTile("tile-ground-04", 52, 2)
	map:addTile("tile-rock-slope-left-02", 52, 3)
	map:addTile("tile-background-03", 52, 4)
	map:addTile("tile-background-01", 52, 5)
	map:addTile("tile-background-big-01", 52, 6)
	map:addTile("bridge-plank-01", 52, 7)
	map:addTile("tile-background-big-01", 52, 8)
	map:addTile("tile-rock-03", 53, 0)
	map:addTile("tile-rock-big-01", 53, 1)
	map:addTile("tile-rock-01", 53, 3)
	map:addTile("tile-rock-02", 53, 4)
	map:addTile("tile-rock-shim-01", 53, 5)
	map:addTile("bridge-plank-01", 53, 7)
	map:addTile("tile-background-03", 53, 10)
	map:addTile("tile-background-04", 53, 11)
	map:addTile("tile-rock-03", 54, 0)
	map:addTile("tile-rock-03", 54, 3)
	map:addTile("tile-rock-slope-right-02", 54, 4)
	map:addTile("tile-background-big-01", 54, 5)
	map:addTile("tile-background-02", 54, 7)
	map:addTile("bridge-wall-right-01", 54, 7)
	map:addTile("tile-background-03", 54, 8)
	map:addTile("tile-background-04", 54, 9)
	map:addTile("tile-background-03", 54, 10)
	map:addTile("tile-background-01", 54, 11)
	map:addTile("tile-rock-big-01", 55, 0)
	map:addTile("tile-rock-slope-right-02", 55, 2)
	map:addTile("tile-background-03", 55, 3)
	map:addTile("tile-background-04", 55, 4)
	map:addTile("tile-ground-02", 55, 7)
	map:addTile("tile-rock-01", 55, 8)
	map:addTile("tile-rock-02", 55, 9)
	map:addTile("tile-rock-02", 55, 10)
	map:addTile("tile-rock-01", 55, 11)
	map:addTile("tile-background-03", 56, 2)
	map:addTile("tile-background-02", 56, 3)
	map:addTile("tile-background-04", 56, 4)
	map:addTile("tile-rock-slope-left-01", 56, 5)
	map:addTile("tile-rock-big-01", 56, 6)
	map:addTile("tile-rock-03", 56, 8)
	map:addTile("tile-rock-01", 56, 9)
	map:addTile("tile-rock-02", 56, 10)
	map:addTile("tile-rock-02", 56, 11)
	map:addTile("tile-rock-03", 57, 0)
	map:addTile("tile-rock-slope-right-02", 57, 1)
	map:addTile("tile-background-03", 57, 2)
	map:addTile("tile-background-03", 57, 3)
	map:addTile("tile-rock-right-04", 57, 4)
	map:addTile("tile-ground-04", 57, 5)
	map:addTile("tile-rock-01", 57, 8)
	map:addTile("tile-rock-01", 57, 9)
	map:addTile("tile-rock-03", 57, 10)
	map:addTile("tile-rock-01", 57, 11)

	map:addEmitter("item-package", 1, 1, 1, 0, "")
	map:addEmitter("tree", 4, 5, 1, 0, "")
	map:addEmitter("item-banana", 11, 3, 1, 0, "")
	map:addEmitter("item-package", 13, 5, 1, 0, "")
	map:addEmitter("tree", 16, 5, 1, 0, "")
	map:addEmitter("item-apple", 18, 6, 1, 0, "")
	map:addEmitter("item-apple", 19, 1, 1, 0, "")
	map:addEmitter("tree", 23, 9, 1, 0, "")
	map:addEmitter("tree", 25, 2, 1, 0, "")
	map:addEmitter("npc-walking", 26, 10, 1, 0, "right=false")
	map:addEmitter("npc-blowing", 27, 2, 1, 0, "right=false")
	map:addEmitter("tree", 30, 9, 1, 0, "")
	map:addEmitter("item-package", 35.3, 5, 1, 0, "")
	map:addEmitter("npc-walking", 37, 2, 1, 0, "right=false")
	map:addEmitter("item-package", 39.5, 2, 1, 0, "")
	map:addEmitter("item-apple", 41, 8, 1, 0, "")
	map:addEmitter("npc-walking", 44, 7, 1, 0, "right=false")
	map:addEmitter("tree", 54, 5, 1, 0, "")

	map:setSetting("width", "58")
	map:setSetting("height", "12")
	map:setSetting("fishnpc", "false")
	map:setSetting("flyingnpc", "true")
	map:setSetting("gravity", "9.81")
	map:setSetting("packagetransfercount", "3")
	map:addStartPosition("1", "1")
	map:setSetting("points", "100")
	map:setSetting("referencetime", "50")
	map:setSetting("sideborderfail", "true")
	map:setSetting("theme", "rock")
	map:setSetting("waterchangespeed", "0")
	map:setSetting("waterfallingdelay", "0")
	map:setSetting("waterheight", "0.9")
	map:setSetting("waterrisingdelay", "0")
	map:setSetting("wind", "4.0")
end
