llddrdrddlddlld3lullrrddllul3uru3lrr4drdrruulldl3urullr3drddrurulldl5uru3ld4l3drrdd4rurrd4ruuld4lrddlul3urul4drruldl5urull3u3r4d4urrddr4d7lrrdd4rudrrulu4l4rdrdd4ldlul5urul3d5ruuldrd5l3drruldl4u3d4ruru4l3rdd4lu2(ulur)drr4urrdlul3duurr4drd4l3rdd4rd6ldlul3urul4drruldl3uluruuldr4d8ru3l3ruu3luldrd5ldd4ruru4l3rdd4l4udd4ru3rdrd3ldluru4l3rdd4l3ud4ru4ruuldrd3luldrd4l3rdd4luu4ru3r4ur3drd4luldrd4l3ru3ruullul3drd3lrru3r3ullrull4drdllr5ululdduu3lddu3l3drr4l3drruuddll3u3rl5d3rulldl4uddll3urr
