ldrrduruurrddrddluuddrrddllullu3lrdrurdrruruu3lul4drd3lu5ruuru3lul4drdllr4uruurrdur3du3lul4d3ullurrd3ruullulluldd3ull3drl3urrdd3rddurrddllul3duu3lurrdrr3u3lddldrrl5ull3drl3urr4drrddu3r3d3lrulld4l3uluu3r3lddr4dldlddruruuddllururu5r4u3lu3lddrddldr3uluu3rd3r4dl3drddllulull3u3r3lddllddrulu3(rdr)ruuluuruulddu4r5ulldurrddllulddu3r3d4lurd3rdrruulrddll3uru3lul3duu3r3d3ldlu4ru4rdlu3lddrrurullrddll3uru3lul4d4u3ldrrur3d2(uu3l)ddrddlddru6rl3ur3u3lddldrrur3duulluu4lddrddlddru5r3ur4uluur5durrddllul3duull4urrur4durrddlluldd2(ullu)urur4dldrrurdlluu4lddrddld4r3l3uluur4dld3rl3(ld)druruulurrl3dllurdruulur3drdrrdrruuludrddluu
