textures = {
	["bones"] = {
		image = "cavepacker-ui-small",
		x0 = 0.494140625,
		y0 = 0.244140625,
		x1 = 0.2392578125,
		y1 = 0.0400390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 245,
		trimmedheight = 41,
		untrimmedwidth = 245,
		untrimmedheight = 41,
	},
	["gri-campaign"] = {
		image = "cavepacker-ui-small",
		x0 = 0.1953125,
		y0 = 0.75,
		x1 = 0.1953125,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 200,
		trimmedheight = 256,
		untrimmedwidth = 200,
		untrimmedheight = 256,
	},
	["icon-arrow-left"] = {
		image = "cavepacker-ui-small",
		x0 = 0.779296875,
		y0 = 0.5625,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-back-to-root"] = {
		image = "cavepacker-ui-small",
		x0 = 0.841796875,
		y0 = 0.5546875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-campaign"] = {
		image = "cavepacker-ui-small",
		x0 = 0.1953125,
		y0 = 0.5,
		x1 = 0.1953125,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 200,
		trimmedheight = 256,
		untrimmedwidth = 200,
		untrimmedheight = 256,
	},
	["icon-close"] = {
		image = "cavepacker-ui-small",
		x0 = 0.947265625,
		y0 = 0.3974609375,
		x1 = 0.033203125,
		y1 = 0.0283203125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 34,
		trimmedheight = 29,
		untrimmedwidth = 34,
		untrimmedheight = 29,
	},
	["icon-cursor-down"] = {
		image = "cavepacker-ui-small",
		x0 = 0.390625,
		y0 = 0.48828125,
		x1 = 0.09765625,
		y1 = 0.09765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 100,
		trimmedheight = 100,
		untrimmedwidth = 100,
		untrimmedheight = 100,
	},
	["icon-cursor-left"] = {
		image = "cavepacker-ui-small",
		x0 = 0.494140625,
		y0 = 0.4091796875,
		x1 = 0.09765625,
		y1 = 0.09765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 100,
		trimmedheight = 100,
		untrimmedwidth = 100,
		untrimmedheight = 100,
	},
	["icon-cursor-right"] = {
		image = "cavepacker-ui-small",
		x0 = 0.619140625,
		y0 = 0.3818359375,
		x1 = 0.09765625,
		y1 = 0.09765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 100,
		trimmedheight = 100,
		untrimmedwidth = 100,
		untrimmedheight = 100,
	},
	["icon-cursor-up"] = {
		image = "cavepacker-ui-small",
		x0 = 0.716796875,
		y0 = 0.3671875,
		x1 = 0.09765625,
		y1 = 0.09765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 100,
		trimmedheight = 100,
		untrimmedwidth = 100,
		untrimmedheight = 100,
	},
	["icon-google-login"] = {
		image = "cavepacker-ui-small",
		x0 = 0.814453125,
		y0 = 0.3671875,
		x1 = 0.0703125,
		y1 = 0.0703125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 72,
		trimmedheight = 72,
		untrimmedwidth = 72,
		untrimmedheight = 72,
	},
	["icon-reload"] = {
		image = "cavepacker-ui-small",
		x0 = 0.48828125,
		y0 = 0.5068359375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-scroll-page-DIR"] = {
		image = "cavepacker-ui-small",
		x0 = 0.947265625,
		y0 = 0.3671875,
		x1 = 0.0341796875,
		y1 = 0.0302734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 31,
		untrimmedwidth = 35,
		untrimmedheight = 31,
	},
	["icon-settings"] = {
		image = "cavepacker-ui-small",
		x0 = 0.947265625,
		y0 = 0.42578125,
		x1 = 0.03125,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 32,
		trimmedheight = 32,
		untrimmedwidth = 32,
		untrimmedheight = 32,
	},
	["icon-solve"] = {
		image = "cavepacker-ui-small",
		x0 = 0.716796875,
		y0 = 0.52734375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-sound-off"] = {
		image = "cavepacker-ui-small",
		x0 = 0.654296875,
		y0 = 0.4794921875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-sound-on"] = {
		image = "cavepacker-ui-small",
		x0 = 0.591796875,
		y0 = 0.4794921875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["icon-star-disabled"] = {
		image = "cavepacker-ui-small",
		x0 = 0.861328125,
		y0 = 0.244140625,
		x1 = 0.1279296875,
		y1 = 0.123046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 131,
		trimmedheight = 126,
		untrimmedwidth = 131,
		untrimmedheight = 126,
	},
	["icon-star-enabled"] = {
		image = "cavepacker-ui-small",
		x0 = 0.7333984375,
		y0 = 0.244140625,
		x1 = 0.1279296875,
		y1 = 0.123046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 131,
		trimmedheight = 126,
		untrimmedwidth = 131,
		untrimmedheight = 126,
	},
	["icon-undo"] = {
		image = "cavepacker-ui-small",
		x0 = 0.619140625,
		y0 = 0.2841796875,
		x1 = 0.09765625,
		y1 = 0.09765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 100,
		trimmedheight = 100,
		untrimmedwidth = 100,
		untrimmedheight = 100,
	},
	["ksokoban-campaign"] = {
		image = "cavepacker-ui-small",
		x0 = 0,
		y0 = 0.75,
		x1 = 0.1953125,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 200,
		trimmedheight = 256,
		untrimmedwidth = 200,
		untrimmedheight = 256,
	},
	["map-icon-locked"] = {
		image = "cavepacker-ui-small",
		x0 = 0.779296875,
		y0 = 0.5,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["map-icon-unlocked-0"] = {
		image = "cavepacker-ui-small",
		x0 = 0.876953125,
		y0 = 0.4921875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["map-icon-unlocked-1"] = {
		image = "cavepacker-ui-small",
		x0 = 0.716796875,
		y0 = 0.46484375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["map-icon-unlocked-2"] = {
		image = "cavepacker-ui-small",
		x0 = 0.814453125,
		y0 = 0.4375,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["map-icon-unlocked-3"] = {
		image = "cavepacker-ui-small",
		x0 = 0.884765625,
		y0 = 0.4296875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["map-icon-unlocked"] = {
		image = "cavepacker-ui-small",
		x0 = 0.884765625,
		y0 = 0.3671875,
		x1 = 0.0625,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["mouse"] = {
		image = "cavepacker-ui-small",
		x0 = 0.591796875,
		y0 = 0.4091796875,
		x1 = 0.0244140625,
		y1 = 0.0341796875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 25,
		trimmedheight = 35,
		untrimmedwidth = 25,
		untrimmedheight = 35,
	},
	["ui-button-start"] = {
		image = "cavepacker-ui-small",
		x0 = 0.494140625,
		y0 = 0.2841796875,
		x1 = 0.125,
		y1 = 0.125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["ui-scene-cave-ice"] = {
		image = "cavepacker-ui-small",
		x0 = 0.73828125,
		y0 = 0,
		x1 = 0.244140625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 250,
		trimmedheight = 250,
		untrimmedwidth = 250,
		untrimmedheight = 250,
	},
	["ui-scene-caveart-ice"] = {
		image = "cavepacker-ui-small",
		x0 = 0.494140625,
		y0 = 0,
		x1 = 0.244140625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 250,
		trimmedheight = 250,
		untrimmedwidth = 250,
		untrimmedheight = 250,
	},
	["ui-scene-ground1-ice"] = {
		image = "cavepacker-ui-small",
		x0 = 0,
		y0 = 0.25,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 256,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
	["ui-scene-ground2-ice"] = {
		image = "cavepacker-ui-small",
		x0 = 0,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 256,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
	["ui-scene-tile1-ice"] = {
		image = "cavepacker-ui-small",
		x0 = 0.25,
		y0 = 0.244140625,
		x1 = 0.244140625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 250,
		trimmedheight = 250,
		untrimmedwidth = 250,
		untrimmedheight = 250,
	},
	["ui-scene-tile2-ice"] = {
		image = "cavepacker-ui-small",
		x0 = 0.25,
		y0 = 0,
		x1 = 0.244140625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 250,
		trimmedheight = 250,
		untrimmedwidth = 250,
		untrimmedheight = 250,
	},
	["xsokoban-campaign"] = {
		image = "cavepacker-ui-small",
		x0 = 0,
		y0 = 0.5,
		x1 = 0.1953125,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 200,
		trimmedheight = 256,
		untrimmedwidth = 200,
		untrimmedheight = 256,
	},
}
