d3rur6d5ulldrur4d3u3ruuruuluull10dldrrldllrr12urrdlul10d4urruuruullul8d7ullddulddrur6drrldllrdrrl6urruulrruu3l8d8urrdrdllruull7d4u4ldrrur5drdldr12ull4d3ul4dldrrlurr5d6ur6dldrdl6ul7ul6dldrrur6dr11u4rdrd3rddlldlld3l3rurrurr3ullu7lrdd3l3ur6dldrur5d5ur6d5u4rurrd5l5ruurruu3luru7lrdd3l3ur6dldrur4d4ur5d4u6ruurrdd7l7r6u9lrdd3l3ur6dldrur3d3ur4dlluld
