rruurrurrdluldllddlluurrdd4luurrldl3dlldllurdruurd3l3urrurrdrr3d4l4ruurrddllrr4urrurr4dlld2(lluu)rrld3lulldrurrdr3dllullu3dllurdruurrdlldllurdru4rulruurr3drrul3r4ull3d3urrdlulddlrurr3dlld7l3r3ururrlldl3d4rurr4ulld3ldllu4r3l4drrurd3lur
