rddldr3uldllururdr3dlluurdullururdldd4ruu3ldu3rddllu3lururdl5drr3urruu3lulddu4rddllululldrurr5dll4ul3(ur)3dlulldr4drr3urruu3lruuldl3drr3dlluururd3uldllururdr3dlluul3(ur)ddrr3dlluululldr4drruurr3u3lruuldl4drr3urr3dlr3ullddrdru3ldr3uldllururdr3dlluuruuldrddr3dlluuddrr3uluurdl3urdldlldr
