3(dr)r3dld5luld3ruld4rur3ullulu3ldldd3lul5urul3drul4drd3ruu3(rd)ull3urduru3(ul)l3uru5rdru3ldru4ldl3drr3(dl)ruu3rdl4ruruu3rdr5dldr3uldr4ulu3ldd3(lu)drr3dludlddrdrrururldld3ldrurrdrddldd4luuddllur3urur3ulldldrrddluuddlldllul4urrlluurd3rdrruruldd3rdrdrdluulu5lurrlluuluuru4rdduurrdl3dldurrddlluu3rurrd2(r4dllr)dlurruululldrru4ludldrru4rd6ull3drdrd4l3ruuldrdl5urrdlduuldd3ulluluurdduurrddur2(dlul)u5ldd6r3lu3rlurdd6luurdrlldrr3lddldll3urrlurdllddrrdrudrdrruulld4l5drr4ulr4dll6urdr4dldluurdru3drrdrdd3luudlurddrruurulruruullddr4d5ruu4ldu4rdd6lruu4rdrdllurul
