3ldl5d5uruul5d4u5rdrrulldrrdd6r4ull3d3urr6d6luu5r5ldd6r5u3dll3ulldduurrurrur3dl4d6luu5r5ldd6r5u3dll4urrurddu3ld4ldllu5rl3d4r4ull3duull3d3r5ldd6r5u3dll4urrurdl4d6luulu3ld3ru4rl3d4r4ull3duull3d3r5ldd6r5u3dll4urr4d6luulu4rl3d4r4ull3d3urr4d4l3ull4dlluluulu7rl3d4r4ull3duu10ldl3dr2(rul3d)rudrruld3ruluul4ulu7r3l5d6r6ulldll3d3r3l3ull5d6r5u5d3lud3l4u3l3drrl4dllurdr3ul5u5r3d3rlldd3r4u4d6lulldl3udd3ru5rlldd3r3ud4l3u6ldrddr5d4lu3rdr3ulurrl3d4lulld5rdr3ul4uru6rdduull3d3rlldd3ruu6ldllul3u3l6dld4rdr3ul3u3drdd4l7u8r3dlldlldluur4d4luurdld3rdr3udd4l7u8r3dlldlluldr3d4l4ur3dld3rdr3udd4l7u8r3dlldll3d3l3ullddld5rdr4urrurr3ull3d3ulldru3ldrduu3rddulluldu3lddl4dld5rdr3udd4l8ul7dld5rdruu
