duulldrlldld3(dr)rul3urrdl3d4uldduuluu3rdrruru4(ul)ldrdrdduululldrdruud3l3(dl)ddrdrd3ruuluurudrdl4ruruulu4lrddrudlld2(drru)ruu3l3rddlddrddluuruulld3lddrrurrluurrdrldllurdlldllddrrudlluurdl3urdurlluurdldd4ruu2(lldd)3lululuurdrd3r5urrddlulddld3luuru3r6dlluuluuddrddrruululrull3ruulldurrdrruldl3drruurr4d3l3r4ulldlluuru3rdu3ldlddruru4dur
