ldlu4lr3urruull4dld3rdrdrr4dl2(ullu)uddrrdd3ruuluullullrrdrrullrddrr3d3ruurruuruuldlldldll3d3ruurruu4d4ldl3u3(ru)3rl3ulluurr4d4u4lulldrd4(dr)r5d8luulldd4rdrru4r10u4l4r5dl3(lu)l3u3d3(rd)dluddldlluluu5rlddll3d3rurur6ululu3lddldduurrddlruulldru3(rd)dldll3d3lulul6urururrur3duu3rdrru4l4r8dlddr4u4d5l3urruru3(ul)uu3ldllu4r4l8drddl4u4d5r3urruru3(ul)ldr6duurruruululrdrddldll5udlldlddrdrluluururr5dullurlluurdldr3u4rdlrrddlurul
