3drr3ururll4dll6u3rdu3l6drr4url4d4l5u3luludd4r3drr4uruurrddllu2(lluulld)d3rd4r5dllu6l3url3d6ruu4luudd4r4d5l3dldlrr4u3ruu4lulluu3rlddl2(ddllddr)r3ur4u5rddl6d3lud3r6ull4dllrr4u4r5d3rdrduu4l3ull4dlddll3udrrd2(rrddrru)u3lu4l5urrd6r3dlr3u6ldd4rddurruurrdd3lruur2(uurruul)l3dl4d5luu3r4urrll4dll6u3rdu3l6drr4ur4ulldurrddllu2(lluulld)d3rd4r6d5u3rddl4d5ldluurr4u4luudd4r3drr4u3ruulldurrddllu2(lluulld)d3rd4r6d5u3rddl4dllullddruur5u3ruulldurrddllulluulldld4r6d5u3rddl4dlluld3r3ur5ulldurrddllul6d5u3rddl4d5luldr3u5l3ullddrluurrddl2(ddllddr)r3ur4u6r5l3urrd4r4drdllu4l4dllrr4u4ruu5l3ullddrluurrddl2(ddllddr)r3ur4u6r5l3urrd4r5d5u3lu5lddrluurrddlddllddrdr4u6r5l3urrd4r4dldr5u3lu5lddrluurrddld6rdd4l3dl5drrudlluurrd2(rrddrru)u3lu4l6u5d3luur4u4rurdl5d4rddu4ruulrddlluur2(uurruul)l3dl4d6l5r3dllu4l5u3rdrr4urrluullu4lu3l3d4rdd7l3dl3drr4drrudlluurrd2(rrddrru)u3lu4l6u5d3luur4u5r5l3dl5drrudlluurrdrrddrruru4l6u5d3lddrrudlluurrlluur4u4r5d3rd5ruulrddlluur2(uurruul)l3dl4d6l5r3dllu4l4u4d3rd5ruulrddlluuruurruulul4d6l5r3dllu4l3u3d3rd5ruulrddlluuru6l5r3dllu4luudd4r3dllu4l6u5d3luur4urr
