rdrud3rdrrul5ulld3ldrrururr5d3luludrd3r5ulld3ldru5lu3lddrrdrulu4rl3u5rlululd3u4(rd)r6d4ulldlluldll3urrll3d5rull4dlddr4u3d3rdrru4l3r7uldu3(ul)l3dll3d4rurrur5d4u4l4dlddr4u3d3rdrru4l3r5ul3ululullddrrdrluurdrdduu4ldll3d3ru3rur5d4u4l4dlddruud3rdrrul5u4ld5ld3luurrurdld4rl3urrurrdrurddrd3lrr3u4ld3rurddrdllruull3ulddld3rurddrdlr5d3luluuddlddr3u
