3dludlu4luurrdullddrruu4ldru3rddlldlu3rdlddrd4l3r4ulldrur3drdllullddrurr3ur3ul5drd3ldllururdrr6uldulldrrur5drd3luldllurrd3r3ullurur4drd4lullddru4r4u3rdrru4lul4drd5ldlu5r4u5ruuldrd4lul4drd4l3r4u4ruuldrd3lul4drd3l
