textures = {
	["package-deadlock-front-01"] = {
		image = "cavepacker-entity-small",
		x0 = 0,
		y0 = 0,
		x1 = 0.515625,
		y1 = 0.24609375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 63,
		untrimmedwidth = 66,
		untrimmedheight = 63,
	},
	["package-delivered-front-01"] = {
		image = "cavepacker-entity-small",
		x0 = 0,
		y0 = 0.24609375,
		x1 = 0.515625,
		y1 = 0.24609375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 63,
		untrimmedwidth = 66,
		untrimmedheight = 63,
	},
	["package-front-01"] = {
		image = "cavepacker-entity-small",
		x0 = 0,
		y0 = 0.4921875,
		x1 = 0.515625,
		y1 = 0.24609375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 66,
		trimmedheight = 63,
		untrimmedwidth = 66,
		untrimmedheight = 63,
	},
	["player-middle-01"] = {
		image = "cavepacker-entity-small",
		x0 = 0,
		y0 = 0.73828125,
		x1 = 0.5,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
}
