d3lu3dlddr4u3rdllu4rd3l4rdrru4luluurrdd3uruul3dllurd3lulldrrurr3d3lu3dlddr4urrdlu3rdll4rdrru4lul3ulldru3ldrrurrdrrdd5lu3dlddr4urrdlu4r2(uulld)ru3ldrrurrdrrddldllullu3dlddr4urrdl5rdrru4lr4uruul3dllurd2(ru4ldr)ru4r3dldllullu3dlddr4urrdluld4rull3r3ulldduulldru3ldrru4r3dld4luuddrrurdrr4ulldduulldrurdu4ld3rll4dlddr5udd6rdrru7l4r4u6ldru6ruuldrd5l
