lddldldrd3rurd4l4u4rdrurr3uluullu4ldllddl3d3rdrul4drruruuruldlull3dr3lddlluu3r3(ur)r3druuruldlu4dllurlluurduu6rdllrddrrddll3uluulldrurrdr3uld4ullu3ld3lddrdrruuddllurd5r4lu4ldrrllddrudrrddlurulullddrrll4urr3drdul3urrdlulduluurdurdll3ullddrrdrruurrdd3lruu4rddldlrururrdlu3ruullddldluulldrrlduu3lddrrddllurdrudrrulu
