3(uurr)4u8luudd8r4dlluu6luudd6r4dlluu4luudd4r4d2(lluu)ddrr4dll3urrd12rdrd13luurruu11rdrdrddllulu10luurruu10r3(dr)3dlluululu9luurruu9r4(dr)4dll3u3(lu)8luurruu8r5(dr)5dll4u4(lu)7luurruu7r6(dr)6drr7u7(lu)6ldu6r7(dr)7d4l5u5(lu)8ldd7r4(dr)4d4r4l4u4(lu)9ldd8r3(dr)3drrll3u3(lu)10ldd9rdrdrddrrlluululu11ldd10rdrdrrllulu12ldd12r12l3ull3drruurr4u4ldduu4rddrr4u6ldduu6rddrr4u8ldduu8rddrr4u10ldduu10rddrr4u12ldd10rdd8r5(dr)5drr6u6(lu)6l6r6(dr)6dll5u5(lu)8luu10luu11rdrdd3u12ldd10r4d7r4(dr)4drr5u5(lu)7l7r5(dr)5dll4u4(lu)9luu8luu9rdrdd3u10ldd8r4d8r3(dr)3drr4u4(lu)8l8r4(dr)4dll3u3(lu)10luu6luu7rdrdd3u8ldd6r4d9rdrdrddrr3u3(lu)9l9r3(dr)3dlluululu11luu4luu5rdrdd3u6ldd4r4d10rdd3ruululu10l10rdrdrdd3luu12luulluu3rdrdd3u4lddrr4d13rluu11l11rdd14l4udrrddu12rdd13l
