uld3lulldr4dldrrul4u3rurrd4lul5duu4rud4lddrul3u3rurrdldd3l3ruu3lulldrddr3drrdrrul3u3l3drrdru3lulldrr3uld3u3rurrd4lul3d4rud4luu3rurrdldd3l3dllurdruluu3d3rdrru4luluu4rdduu4lddrulurrl3drrdrrul5u3lulldrddr3drrdr3udd3lulld4rll3uldrddllurdruulur3drrdrru4lul4u3rurrd4lul3dr3d3r4u4d3lulld4rdr4u3d3l3uld3u3rurrd4lul3dr3d3r4u4d3l3uluu3rurrd4l3r5d5lurdrud3r5u3lulld4r3l3d3u3rurrd4lul3duu4r5d3luld4r5u4l3durd
