ddrd4ruu3lud3rddlludrruull3ruruuldlldlrurruullddu3lu6lddrrud3ldlddrurrudllddrruud3rdrru4lrrd3rdr3uddrruururullruulld3lu3lulldrddrdduuluullddrlldlddrurrururdlldllddrru3rd6ruur4ulld3lulldrru3lulldlddldldrddrru4r3u3d4ldll4urrdrrdullull4drrurr3ulr3dlldll4uruururrd3rdlu3lddr3drd6ruur4ulldllrrurr4dldd5l4u3d4ldll4urrdrluluururrdlddrdduu4l4drru3rdr3udd4luururddulldd3rdruud4ldl2(luur)uurur3duullddrdrluluurrddrdduu4l4drru3rdru4luururddulldd3r3lul2(luurr)ddldrurddullddrr
