rurrd3ruuldrdrruul4ulu7r6l5drddl6ulu6r5l6dllurdr5ulu5r4l5dllurdr4ulu4rdruud4l5dr4dl8ulu4ruu3rdrddluulddlu4l9dluudlullulld5rdr7ulu7r6l5dlldrdr6ulu6r5l7d4lulld5rdr7ulu5r4l6d3rulldl5ulu4ru3rddluuld4l5drruldl4ulu4rd3rllu4l6d3rdlldl7ulu4rurrld4l7d5rurrd6ldl7ulu4rdrrlu4l9d3rulldl8ulu4rurd4l7d5rurrd6ldl7ulu5rldr
