luururrurrdldllu3(rd)dlldlludrruluur3urd3lulld4rddlu3d3ruulluldduruullulldr3d2(rluu)rdrrddlud3rddlldlluruu3rddllrruull3urrdlulddullulldr3drddrrurru3(ul)lulldlddrluururrdl3rurrd3lrrddrddlldllurullulld3r
