textures = {
	["gri-campaign"] = {
		image = "cavepacker-ui-scene-small",
		x0 = 0,
		y0 = 0.5,
		x1 = 0.1953125,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 200,
		trimmedheight = 256,
		untrimmedwidth = 200,
		untrimmedheight = 256,
	},
	["icon-campaign"] = {
		image = "cavepacker-ui-scene-small",
		x0 = 0,
		y0 = 0.75,
		x1 = 0.1953125,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 200,
		trimmedheight = 256,
		untrimmedwidth = 200,
		untrimmedheight = 256,
	},
	["ksokoban-campaign"] = {
		image = "cavepacker-ui-scene-small",
		x0 = 0.1953125,
		y0 = 0.5,
		x1 = 0.1953125,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 200,
		trimmedheight = 256,
		untrimmedwidth = 200,
		untrimmedheight = 256,
	},
	["mgerhardy-campaign"] = {
		image = "cavepacker-ui-scene-small",
		x0 = 0.1953125,
		y0 = 0.75,
		x1 = 0.1953125,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 200,
		trimmedheight = 256,
		untrimmedwidth = 200,
		untrimmedheight = 256,
	},
	["ui-scene-cave-ice"] = {
		image = "cavepacker-ui-scene-small",
		x0 = 0.25,
		y0 = 0.25,
		x1 = 0.244140625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 250,
		trimmedheight = 250,
		untrimmedwidth = 250,
		untrimmedheight = 250,
	},
	["ui-scene-caveart-ice"] = {
		image = "cavepacker-ui-scene-small",
		x0 = 0.4453125,
		y0 = 0,
		x1 = 0.244140625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 250,
		trimmedheight = 250,
		untrimmedwidth = 250,
		untrimmedheight = 250,
	},
	["ui-scene-ground1-ice"] = {
		image = "cavepacker-ui-scene-small",
		x0 = 0,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 256,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
	["ui-scene-ground2-ice"] = {
		image = "cavepacker-ui-scene-small",
		x0 = 0,
		y0 = 0.25,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 256,
		trimmedheight = 256,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
	["ui-scene-tile1-ice"] = {
		image = "cavepacker-ui-scene-small",
		x0 = 0.689453125,
		y0 = 0,
		x1 = 0.244140625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 250,
		trimmedheight = 250,
		untrimmedwidth = 250,
		untrimmedheight = 250,
	},
	["ui-scene-tile2-ice"] = {
		image = "cavepacker-ui-scene-small",
		x0 = 0.390625,
		y0 = 0.494140625,
		x1 = 0.244140625,
		y1 = 0.244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 250,
		trimmedheight = 250,
		untrimmedwidth = 250,
		untrimmedheight = 250,
	},
	["xsokoban-campaign"] = {
		image = "cavepacker-ui-scene-small",
		x0 = 0.25,
		y0 = 0,
		x1 = 0.1953125,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 200,
		trimmedheight = 256,
		untrimmedwidth = 200,
		untrimmedheight = 256,
	},
}
