3dlrrl3urllr3ulrru3rddludr3(rul3d)rululdldll3d5ruuluulldll7urr3lu3l6drdrddlruull5urururr8drrdlruurrddrdd5l6u3drrurrddlluu3rddl4urdl3urdrr5d3l3urul3druddrr5ulluldduluddu4r5dll4u4drr5u3l3urddlddr4drr5ulldluuruuluur4dlddrdd3ldll3uluur6u5r4d4u5l6dlddr6d5ruurr5ulluluuddrddluur4d3ldll3uluur6u5r6dldr3dldd3r10ulr10d3luulldr3l3uluur6u5r6dlddlduruur6u5l6dlddr3drr3(uru)ulddr4ulddllurdrrddlluuddrur5u5l6dlddr3drruldluud3ruuruur6u5l3dlldll6d4r4ldrdrru4r3uruur4urr10dlldd5luulurulrdrrdlruulrruuruur4urr10dlldd5luulurrl3d5ruu4l4rdd5luu3lul6u3(lur3d)lurrddrrulld3rdd5luu4r4ldd10ruu4luldululrdrrurruuruur6u5l3dlldll5drddurrdd6rdd10luu6rlluu4ldduur3ur3dl6urrurr3dldllrrurrdld5ulldll3d3r3ldldduuruuldll5d6ruu4luudd4rdd4luuddll5urrdruudrudrrur3ulld3lddrr4dllddll5urr3uruuldd3rulruld3ru2(lrdd)ldllulldrdrddlluurdl3dll5urrurddrddrrdrrurruuruur4urr10dlldd10l6urul2(drrd)rrurruur3(uul)rddrddrr6u5lddlddrddld3l3rurrdllr3ulull3d3urrurdduurrddlruulld3lu3(rrd)drr6u5lddrdllullddlluu4rdlrdllru3rdrrddrr6u5lddrdlldllddlddl4dll10u6rdru2(rddr)r6u10ldu10r6dlddlddlldlld6l10u6rdrrdrrddrddlddlldd5l5ruurruuruur4urr10d6lullulluuluul3u3drruurrurru3r3lddrrddrddr3d
