dl3d3rd4rud4r4ulddulldllrr5u3lu4l3u2(ld3ru)lld3luurdld3ruldlluurdldrddlud3rd4rur4dllullddu3l3rurrdrdrrldldd4r4uld3l3d4lu3l3u5r5l3drd8rlluur5u4lddrdrrlulluu4r3dldrl3d4lu3l3u4r3luurdldl3dld7rdr3uruullulldlldlruuldldduu4rurrdrrddldd8lurrl3urrdluldduu4rurrdrrddldd6luld3ruldll3ur3ul4duu7rdu3l3u4r4dr
