#pragma once

namespace caveexpress {

namespace protocol {
enum {
	PROTO_DROP,
	PROTO_REMOVEROPE,
	PROTO_WATERHEIGHT,
	PROTO_WATERIMPACT,
	PROTO_UPDATECOLLECTEDTYPE,
	PROTO_ADDROPE,
	PROTO_ADDCAVE,
	PROTO_LIGHTSTATE,
	PROTO_TARGETCAVE,
	PROTO_ANNOUNCETARGETCAVE
};
}

}
