l3dll5dllulldllu3lr3ul3(ur)ululldldl4dl3drru4rdrddldr3uru4r4urr4u4l3dldldd3r3luurur3urrdlu3r4dllurl3d4luururuuru3r3drdllr4ulld3lu4rur4d3u4l3dldldd4rdd4ldllull5uruu4r4lddldd3(ru)dldll4drrdrru4ruu4luururuulurdrrurrdrrdr3d5(ld)dlddld5lul8u3dlldll3ur4urururrd3r3lulld3r4ldl4dl3drrurr3ur3u3dllurdrul4drrdl3ru4r3dlddld3l4u4dllul8u8drd5ruruur3u4ldllrddrrdluluulull5drdrr4u4dllul5urrdlrr5d3ruruur5u4luururuurrurrdrrdr3d3(ld)4ludlrdru3r3(ur)3ulullddll4d4u3rdllul3d3l3ruurr4ulldllu3rur4drdlluldd
