3r3(dr)rululu3l3(rd)dluluurdrddldl3u6drddl6urrurr3(dl)ruruulduul3ulldrurdrddlluruulldru3(rd)rrul3d4l3u7drddl6u5rdld3l3rurrdll5rurrd5luluurdrdlull3urrdrddul3urdd5uluur5dldllururddll3d4luurruururrlldllulldrrurrdr4d4l3u7drddl8udd4rdd3l3ruu4l4drddl6u6rdd5l8rurrd7luu3rdld3rurrd5luull3urrdr3d3uluur4d7uluur7du3lururlddrr4uluur6dllullulld3rlu4ld4rlddlludrr3u3ld3rld3r3d4l3uruulldr8drddl9u4r5d3l3ruu4l4drddl7ud6rdd5l8rurrd5luurdldllurd4rurrd6luu5l4drddl6u4ruurdluulldrldrurddrl3ur3d3l5uldulldrr3ldllu4r3lu5r
