rdrr4d3luurrlldd3r3uruuldllu4ldl3dld3ruurrdd3r3urul4d3luurr4lddll4uru4rdduu4ldl4drruu3r3u4lul5dldr5ulldrur4dlddr5uru4r3d3lddlruu3r3ulldduu3l4dlddr5uru4r3dldd3lruur3urrddldr3ulldduulldl3dlddrurruur3ulldl3dldr4uruulddllu6r3ldl3dlddr5ulu4r3dlddlruururrdluluu3l4dlddru4ruudd3ruullulrdrrdd3luu3ruruuldlrdd3lddlluururldlddll4ururrdulldllu3rll5d4ruudd3r3urul
