rddrrurrdrrdrduluurdrr5lulldll7u10r7d3l3ururldlluruu6d3lulldll7u7r3d3luludrddlull6r4d3lulldll4u7d7r4ud6lrrdduu4r3d4l3u7r4u4lr3u4lddrddlddldrrl3uruulddu3l4duu4ldldd2(ldllul)ldlrurrdldduu3rurrdrruruururr7d11l3u3rurrdrrdrduluurdrr5lulld3l3d8ruuluuruururr7u14l11drrur2(uuruul)udrddlullrr3drddldd2(rdrrur)uururr7u11lddrd2(rrdrru)rldlluruudd3ldllull2(dlddrd)rrurrdrruruururr4ullrr8d4ulldllu3rll3dlddruud3lulldrrldduu3lulldll8u8d4rl3uruulddullrr3uruuluu8r8l4du3rdrrullruudd3rdrrull
