function getName()
	return "Wind 04"
end

function onMapLoaded()
end

function initMap()
	-- get the current map context
	local map = Map.get()
	map:addTile("tile-rock-ice-left-05", 0, 0)
	map:addTile("tile-rock-ice-left-04", 0, 1)
	map:addTile("tile-rock-ice-left-05", 0, 2)
	map:addTile("tile-rock-ice-left-04", 0, 3)
	map:addTile("tile-ground-ice-02", 0, 4)
	map:addTile("tile-background-ice-02", 0, 5)
	map:addTile("tile-background-ice-04", 0, 6)
	map:addTile("tile-background-ice-07", 0, 7)
	map:addTile("tile-background-ice-07", 0, 8)
	map:addTile("tile-background-ice-02", 0, 9)
	map:addTile("tile-background-ice-01", 0, 10)
	map:addTile("tile-background-ice-07", 0, 11)
	map:addTile("tile-background-ice-big-01", 1, 0)
	map:addTile("tile-background-ice-big-01", 1, 2)
	map:addTile("tile-ground-ice-02", 1, 4)
	map:addTile("tile-rock-slope-ice-left-02", 1, 5)
	map:addTile("tile-background-ice-08", 1, 6)
	map:addTile("tile-background-ice-03", 1, 7)
	map:addTile("tile-background-ice-08", 1, 8)
	map:addTile("tile-background-ice-03", 1, 9)
	map:addTile("tile-background-ice-big-01", 1, 10)
	map:addTile("tile-ground-ice-02", 2, 4)
	map:addTile("tile-rock-ice-03", 2, 5)
	map:addTile("tile-rock-ice-01", 2, 6)
	map:addTile("tile-rock-slope-ice-left-02", 2, 7)
	map:addTile("tile-background-ice-03", 2, 8)
	map:addTile("tile-background-ice-08", 2, 9)
	map:addTile("tile-background-ice-08", 3, 0)
	map:addTile("tile-background-ice-big-01", 3, 1)
	map:addTile("tile-background-ice-08", 3, 3)
	map:addTile("tile-rock-slope-ice-right-01", 3, 4)
	map:addTile("tile-rock-ice-02", 3, 5)
	map:addTile("tile-rock-ice-03", 3, 6)
	map:addTile("tile-rock-ice-02", 3, 7)
	map:addTile("tile-rock-ice-01", 3, 8)
	map:addTile("tile-background-ice-08", 3, 9)
	map:addTile("tile-background-ice-03", 3, 10)
	map:addTile("tile-background-ice-cave-art-02", 3, 11)
	map:addTile("tile-background-ice-02", 4, 0)
	map:addTile("tile-background-ice-cave-art-02", 4, 3)
	map:addTile("tile-background-ice-08", 4, 4)
	map:addTile("tile-rock-slope-ice-right-01", 4, 5)
	map:addTile("tile-rock-ice-02", 4, 6)
	map:addTile("tile-rock-ice-03", 4, 7)
	map:addTile("tile-rock-ice-03", 4, 8)
	map:addTile("tile-background-ice-03", 4, 9)
	map:addTile("tile-background-ice-06", 4, 10)
	map:addTile("tile-background-ice-05", 4, 11)
	map:addTile("tile-background-ice-cave-art-01", 5, 0)
	map:addTile("tile-background-ice-01", 5, 1)
	map:addTile("tile-ground-ice-02", 5, 2)
	map:addTile("tile-rock-slope-ice-left-02", 5, 3)
	map:addTile("tile-background-ice-06", 5, 4)
	map:addTile("tile-background-ice-06", 5, 5)
	map:addTile("tile-rock-slope-ice-right-01", 5, 6)
	map:addTile("tile-rock-ice-02", 5, 7)
	map:addTile("tile-rock-ice-01", 5, 8)
	map:addTile("tile-background-ice-01", 5, 9)
	map:addTile("tile-background-ice-03", 5, 10)
	map:addTile("tile-background-ice-02", 5, 11)
	map:addTile("tile-background-ice-big-01", 6, 0)
	map:addTile("tile-ground-ice-06", 6, 2)
	map:addTile("tile-rock-ice-02", 6, 3)
	map:addTile("tile-rock-slope-ice-left-02", 6, 4)
	map:addTile("tile-background-ice-04", 6, 5)
	map:addTile("tile-background-ice-06", 6, 6)
	map:addTile("tile-ground-ice-01", 6, 7)
	map:addTile("tile-rock-ice-02", 6, 8)
	map:addTile("tile-background-ice-big-01", 6, 9)
	map:addTile("tile-background-ice-08", 6, 11)
	map:addTile("tile-ground-ice-02", 7, 2)
	map:addTile("tile-rock-ice-big-01", 7, 3)
	map:addTile("tile-background-ice-06", 7, 5)
	map:addTile("tile-background-ice-02", 7, 6)
	map:addTile("tile-ground-ice-01", 7, 7)
	map:addTile("tile-rock-ice-03", 7, 8)
	map:addTile("tile-background-ice-01", 7, 11)
	map:addTile("tile-background-ice-big-01", 8, 0)
	map:addTile("tile-ground-ice-06", 8, 2)
	map:addTile("tile-background-ice-02", 8, 5)
	map:addTile("tile-background-ice-07", 8, 6)
	map:addTile("tile-ground-ice-01", 8, 7)
	map:addTile("tile-rock-ice-01", 8, 8)
	map:addTile("tile-background-ice-07", 8, 9)
	map:addTile("tile-background-ice-08", 8, 10)
	map:addTile("tile-background-ice-cave-art-02", 8, 11)
	map:addTile("tile-ground-ice-02", 9, 2)
	map:addTile("tile-rock-ice-01", 9, 3)
	map:addTile("tile-rock-slope-ice-right-02", 9, 4)
	map:addTile("tile-background-ice-03", 9, 5)
	map:addTile("tile-background-ice-cave-art-02", 9, 6)
	map:addTile("tile-ground-ice-01", 9, 7)
	map:addTile("tile-rock-ice-02", 9, 8)
	map:addTile("tile-background-ice-01", 9, 9)
	map:addTile("tile-background-ice-05", 9, 10)
	map:addTile("tile-background-ice-01", 9, 11)
	map:addTile("tile-background-ice-cave-art-02", 10, 0)
	map:addTile("tile-background-ice-06", 10, 1)
	map:addTile("tile-ground-ice-06", 10, 2)
	map:addTile("tile-rock-ice-03", 10, 3)
	map:addTile("tile-background-ice-cave-art-02", 10, 4)
	map:addTile("tile-background-ice-07", 10, 5)
	map:addTile("tile-rock-slope-ice-left-01", 10, 6)
	map:addTile("tile-rock-ice-03", 10, 7)
	map:addTile("tile-rock-ice-01", 10, 8)
	map:addTile("tile-background-ice-08", 10, 9)
	map:addTile("tile-background-ice-cave-art-01", 10, 10)
	map:addTile("tile-background-ice-05", 10, 11)
	map:addTile("tile-background-ice-cave-art-02", 11, 0)
	map:addTile("tile-background-ice-06", 11, 1)
	map:addTile("tile-ground-ice-02", 11, 2)
	map:addTile("tile-rock-ice-03", 11, 3)
	map:addTile("tile-rock-shim-ice-01", 11, 4)
	map:addTile("tile-background-ice-03", 11, 5)
	map:addTile("tile-ground-ice-01", 11, 6)
	map:addTile("tile-rock-ice-03", 11, 7)
	map:addTile("tile-rock-ice-02", 11, 8)
	map:addTile("tile-rock-ice-big-01", 11, 9)
	map:addTile("tile-rock-ice-02", 11, 11)
	map:addTile("tile-background-ice-06", 12, 0)
	map:addTile("tile-background-ice-07", 12, 1)
	map:addTile("tile-background-ice-06", 12, 2)
	map:addTile("tile-ground-ice-02", 12, 3)
	map:addTile("tile-background-ice-07", 12, 4)
	map:addTile("tile-background-ice-cave-art-02", 12, 5)
	map:addTile("tile-ground-ice-01", 12, 6)
	map:addTile("tile-rock-ice-02", 12, 7)
	map:addTile("tile-rock-ice-01", 12, 8)
	map:addTile("tile-rock-ice-02", 12, 11)
	map:addTile("tile-background-ice-02", 13, 0)
	map:addTile("tile-background-ice-cave-art-02", 13, 1)
	map:addTile("tile-background-ice-cave-art-02", 13, 2)
	map:addTile("tile-ground-ice-06", 13, 3)
	map:addTile("tile-background-ice-05", 13, 4)
	map:addTile("tile-background-ice-04", 13, 5)
	map:addTile("tile-ground-ice-03", 13, 6)
	map:addTile("tile-rock-ice-big-01", 13, 7)
	map:addTile("tile-rock-ice-02", 13, 9)
	map:addTile("tile-rock-ice-01", 13, 10)
	map:addTile("tile-rock-ice-02", 13, 11)
	map:addTile("tile-rock-shim-ice-01", 14, 0)
	map:addTile("tile-background-ice-cave-art-02", 14, 1)
	map:addTile("tile-background-ice-01", 14, 2)
	map:addTile("tile-ground-ice-02", 14, 3)
	map:addTile("tile-background-ice-08", 14, 4)
	map:addTile("tile-waterfall-ice-01", 14, 5)
	map:addTile("tile-rock-ice-01", 14, 9)
	map:addTile("tile-rock-ice-02", 14, 10)
	map:addTile("tile-rock-ice-01", 14, 11)
	map:addTile("tile-background-ice-05", 15, 0)
	map:addTile("tile-background-ice-01", 15, 1)
	map:addTile("tile-background-ice-04", 15, 2)
	map:addTile("tile-ground-ice-06", 15, 3)
	map:addTile("tile-rock-shim-ice-01", 15, 4)
	map:addTile("tile-background-ice-08", 15, 5)
	map:addTile("tile-ground-ice-03", 15, 6)
	map:addTile("tile-rock-ice-01", 15, 7)
	map:addTile("tile-rock-ice-big-01", 15, 8)
	map:addTile("tile-rock-ice-01", 15, 10)
	map:addTile("tile-rock-ice-02", 15, 11)
	map:addTile("tile-background-ice-02", 16, 0)
	map:addTile("tile-background-ice-06", 16, 1)
	map:addTile("tile-background-ice-03", 16, 2)
	map:addTile("tile-ground-ice-02", 16, 3)
	map:addTile("tile-background-ice-06", 16, 4)
	map:addTile("tile-background-ice-cave-art-02", 16, 5)
	map:addTile("tile-ground-ice-01", 16, 6)
	map:addTile("tile-rock-ice-02", 16, 7)
	map:addTile("tile-rock-ice-big-01", 16, 10)
	map:addTile("tile-background-ice-03", 17, 0)
	map:addTile("tile-background-ice-03", 17, 1)
	map:addTile("tile-background-ice-cave-art-02", 17, 2)
	map:addTile("tile-ground-ice-06", 17, 3)
	map:addTile("tile-background-ice-07", 17, 4)
	map:addTile("tile-background-ice-05", 17, 5)
	map:addTile("tile-ground-ice-03", 17, 6)
	map:addTile("tile-rock-ice-01", 17, 7)
	map:addTile("tile-rock-ice-01", 17, 8)
	map:addTile("tile-rock-ice-02", 17, 9)
	map:addTile("tile-rock-shim-ice-01", 18, 0)
	map:addTile("tile-background-ice-03", 18, 1)
	map:addTile("tile-background-ice-07", 18, 2)
	map:addTile("tile-ground-ice-02", 18, 3)
	map:addTile("tile-background-ice-05", 18, 4)
	map:addTile("tile-background-ice-04", 18, 5)
	map:addTile("tile-ground-ice-01", 18, 6)
	map:addTile("tile-rock-ice-02", 18, 7)
	map:addTile("tile-rock-ice-01", 18, 8)
	map:addTile("tile-rock-ice-01", 18, 9)
	map:addTile("tile-rock-ice-02", 18, 10)
	map:addTile("tile-rock-ice-02", 18, 11)
	map:addTile("tile-background-ice-05", 19, 0)
	map:addTile("tile-background-ice-02", 19, 1)
	map:addTile("tile-background-ice-06", 19, 2)
	map:addTile("tile-ground-ice-06", 19, 3)
	map:addTile("tile-background-ice-04", 19, 4)
	map:addTile("tile-background-ice-01", 19, 5)
	map:addTile("tile-rock-slope-ice-right-01", 19, 6)
	map:addTile("tile-rock-ice-01", 19, 7)
	map:addTile("tile-rock-ice-02", 19, 8)
	map:addTile("tile-rock-slope-ice-right-02", 19, 9)
	map:addTile("tile-background-ice-04", 19, 10)
	map:addTile("tile-background-ice-07", 19, 11)
	map:addTile("tile-background-ice-cave-art-02", 20, 0)
	map:addTile("tile-background-ice-01", 20, 1)
	map:addTile("tile-background-ice-cave-art-02", 20, 2)
	map:addTile("tile-ground-ice-02", 20, 3)
	map:addTile("tile-rock-slope-ice-left-02", 20, 4)
	map:addTile("tile-background-ice-cave-art-02", 20, 5)
	map:addTile("tile-background-ice-04", 20, 6)
	map:addTile("tile-background-ice-cave-art-02", 20, 7)
	map:addTile("tile-background-ice-06", 20, 8)
	map:addTile("tile-background-ice-08", 20, 9)
	map:addTile("tile-background-ice-02", 20, 10)
	map:addTile("tile-background-ice-cave-art-01", 20, 11)
	map:addTile("tile-background-ice-04", 21, 0)
	map:addTile("tile-background-ice-03", 21, 1)
	map:addTile("tile-background-ice-01", 21, 2)
	map:addTile("tile-background-ice-04", 21, 3)
	map:addTile("tile-ground-ice-02", 21, 4)
	map:addTile("tile-rock-slope-ice-left-02", 21, 5)
	map:addTile("tile-background-ice-cave-art-02", 21, 6)
	map:addTile("tile-background-ice-06", 21, 7)
	map:addTile("tile-background-ice-02", 21, 8)
	map:addTile("tile-background-ice-cave-art-02", 21, 9)
	map:addTile("tile-background-ice-cave-art-02", 21, 10)
	map:addTile("tile-background-ice-01", 21, 11)
	map:addTile("tile-rock-slope-ice-left-02", 22, 0)
	map:addTile("tile-background-ice-03", 22, 1)
	map:addTile("tile-background-ice-01", 22, 2)
	map:addTile("tile-background-ice-08", 22, 3)
	map:addTile("tile-ground-ice-02", 22, 4)
	map:addTile("tile-rock-ice-big-01", 22, 5)
	map:addTile("tile-rock-ice-02", 22, 7)
	map:addTile("tile-rock-slope-ice-left-02", 22, 8)
	map:addTile("tile-background-ice-04", 22, 9)
	map:addTile("tile-background-ice-cave-art-01", 22, 10)
	map:addTile("tile-background-ice-04", 22, 11)
	map:addTile("tile-rock-ice-02", 23, 0)
	map:addTile("tile-rock-shim-ice-01", 23, 1)
	map:addTile("tile-background-ice-big-01", 23, 2)
	map:addTile("tile-ground-ice-03", 23, 4)
	map:addTile("tile-rock-ice-big-01", 23, 7)
	map:addTile("tile-rock-shim-ice-01", 23, 9)
	map:addTile("tile-background-ice-03", 23, 10)
	map:addTile("tile-background-ice-cave-art-02", 23, 11)
	map:addTile("tile-ground-ledge-ice-right-01", 24, 0)
	map:addTile("tile-background-ice-04", 24, 1)
	map:addTile("tile-ground-ice-02", 24, 4)
	map:addTile("tile-rock-ice-03", 24, 5)
	map:addTile("tile-rock-ice-02", 24, 6)
	map:addTile("tile-rock-slope-ice-left-02", 24, 9)
	map:addTile("tile-background-ice-cave-art-01", 24, 10)
	map:addTile("tile-background-ice-cave-art-02", 24, 11)
	map:addTile("tile-ground-ledge-ice-right-02", 25, 0)
	map:addTile("tile-background-ice-04", 25, 1)
	map:addTile("tile-background-ice-04", 25, 2)
	map:addTile("tile-waterfall-ice-01", 25, 3)
	map:addTile("tile-rock-ice-big-01", 25, 5)
	map:addTile("tile-rock-ice-01", 25, 7)
	map:addTile("tile-rock-ice-02", 25, 8)
	map:addTile("tile-rock-ice-02", 25, 9)
	map:addTile("tile-background-ice-01", 25, 10)
	map:addTile("tile-background-ice-04", 25, 11)
	map:addTile("tile-background-ice-07", 26, 0)
	map:addTile("tile-background-ice-04", 26, 1)
	map:addTile("tile-background-ice-01", 26, 2)
	map:addTile("tile-background-ice-07", 26, 3)
	map:addTile("tile-ground-ice-02", 26, 4)
	map:addTile("tile-rock-ice-02", 26, 7)
	map:addTile("tile-rock-ice-01", 26, 8)
	map:addTile("tile-rock-slope-ice-right-02", 26, 9)
	map:addTile("tile-background-ice-04", 26, 10)
	map:addTile("tile-background-ice-04", 26, 11)
	map:addTile("tile-background-ice-03", 27, 0)
	map:addTile("tile-background-ice-01", 27, 1)
	map:addTile("tile-background-ice-02", 27, 2)
	map:addTile("tile-background-ice-04", 27, 3)
	map:addTile("tile-ground-ice-01", 27, 4)
	map:addTile("tile-rock-slope-ice-right-02", 27, 5)
	map:addTile("tile-background-ice-06", 27, 6)
	map:addTile("tile-rock-slope-ice-right-01", 27, 7)
	map:addTile("tile-rock-ice-02", 27, 8)
	map:addTile("tile-background-ice-05", 27, 9)
	map:addTile("tile-background-ice-cave-art-01", 27, 10)
	map:addTile("tile-background-ice-cave-art-01", 27, 11)
	map:addTile("tile-background-ice-06", 28, 0)
	map:addTile("tile-background-ice-08", 28, 1)
	map:addTile("tile-background-ice-04", 28, 2)
	map:addTile("tile-background-ice-04", 28, 3)
	map:addTile("tile-background-ice-08", 28, 4)
	map:addTile("tile-background-ice-07", 28, 5)
	map:addTile("tile-background-ice-06", 28, 6)
	map:addTile("tile-background-ice-08", 28, 7)
	map:addTile("tile-background-ice-02", 28, 8)
	map:addTile("tile-background-ice-03", 28, 9)
	map:addTile("tile-background-ice-02", 28, 10)
	map:addTile("tile-background-ice-03", 28, 11)
	map:addTile("tile-background-ice-07", 29, 0)
	map:addTile("tile-background-ice-03", 29, 1)
	map:addTile("tile-background-ice-03", 29, 2)
	map:addTile("tile-background-ice-04", 29, 3)
	map:addTile("tile-background-ice-01", 29, 4)
	map:addTile("tile-background-ice-03", 29, 5)
	map:addTile("tile-background-ice-01", 29, 6)
	map:addTile("tile-background-ice-06", 29, 7)
	map:addTile("tile-background-ice-02", 29, 8)
	map:addTile("tile-background-ice-04", 29, 9)
	map:addTile("tile-background-ice-01", 29, 10)
	map:addTile("tile-background-ice-03", 29, 11)
	map:addTile("tile-background-ice-04", 30, 0)
	map:addTile("tile-background-ice-04", 30, 1)
	map:addTile("tile-ground-ice-02", 30, 2)
	map:addTile("tile-rock-ice-big-01", 30, 3)
	map:addTile("tile-rock-ice-02", 30, 5)
	map:addTile("tile-rock-ice-01", 30, 6)
	map:addTile("tile-rock-ice-big-01", 30, 7)
	map:addTile("tile-rock-ice-02", 30, 9)
	map:addTile("tile-rock-ice-big-01", 30, 10)
	map:addTile("tile-background-ice-02", 31, 0)
	map:addTile("tile-background-ice-04", 31, 1)
	map:addTile("tile-ground-ice-03", 31, 2)
	map:addTile("tile-rock-ice-01", 31, 5)
	map:addTile("tile-rock-ice-02", 31, 6)
	map:addTile("tile-rock-ice-01", 31, 9)
	map:addTile("tile-background-ice-07", 32, 0)
	map:addTile("tile-background-ice-05", 32, 1)
	map:addTile("tile-ground-ice-02", 32, 2)
	map:addTile("tile-rock-ice-big-01", 32, 3)
	map:addTile("tile-rock-slope-ice-right-02", 32, 5)
	map:addTile("tile-background-ice-01", 32, 6)
	map:addTile("tile-background-ice-cave-art-01", 32, 7)
	map:addTile("tile-background-ice-08", 32, 8)
	map:addTile("tile-background-ice-01", 32, 9)
	map:addTile("tile-background-ice-02", 32, 10)
	map:addTile("tile-background-ice-01", 32, 11)
	map:addTile("tile-background-ice-cave-art-02", 33, 0)
	map:addTile("tile-background-ice-03", 33, 1)
	map:addTile("tile-ground-ice-03", 33, 2)
	map:addTile("tile-background-ice-04", 33, 5)
	map:addTile("tile-background-ice-05", 33, 6)
	map:addTile("tile-background-ice-06", 33, 7)
	map:addTile("tile-background-ice-04", 33, 8)
	map:addTile("tile-background-ice-05", 33, 9)
	map:addTile("tile-background-ice-01", 33, 10)
	map:addTile("tile-background-ice-05", 33, 11)
	map:addTile("tile-background-ice-06", 34, 0)
	map:addTile("tile-background-ice-05", 34, 1)
	map:addTile("tile-ground-ice-06", 34, 2)
	map:addTile("tile-rock-slope-ice-right-02", 34, 3)
	map:addTile("tile-background-ice-04", 34, 4)
	map:addTile("tile-background-ice-cave-art-01", 34, 5)
	map:addTile("tile-background-ice-07", 34, 6)
	map:addTile("tile-background-ice-03", 34, 7)
	map:addTile("tile-background-ice-02", 34, 8)
	map:addTile("tile-background-ice-07", 34, 9)
	map:addTile("tile-background-ice-07", 34, 10)
	map:addTile("tile-background-ice-04", 34, 11)
	map:addTile("tile-background-ice-07", 35, 0)
	map:addTile("tile-background-ice-02", 35, 1)
	map:addTile("tile-background-ice-big-01", 35, 2)
	map:addTile("tile-background-ice-03", 35, 4)
	map:addTile("tile-background-ice-01", 35, 5)
	map:addTile("tile-background-ice-cave-art-02", 35, 6)
	map:addTile("tile-background-ice-07", 35, 7)
	map:addTile("tile-background-ice-08", 35, 8)
	map:addTile("tile-background-ice-04", 35, 9)
	map:addTile("tile-background-ice-04", 35, 10)
	map:addTile("tile-background-ice-06", 35, 11)
	map:addTile("tile-background-ice-04", 36, 0)
	map:addTile("tile-background-ice-05", 36, 1)
	map:addTile("tile-background-ice-01", 36, 4)
	map:addTile("tile-background-ice-07", 36, 5)
	map:addTile("tile-background-ice-01", 36, 6)
	map:addTile("tile-background-ice-07", 36, 7)
	map:addTile("tile-background-ice-06", 36, 8)
	map:addTile("tile-background-ice-05", 36, 9)
	map:addTile("tile-background-ice-05", 36, 10)
	map:addTile("tile-background-ice-07", 36, 11)
	map:addTile("tile-background-ice-big-01", 37, 0)
	map:addTile("tile-background-ice-cave-art-01", 37, 2)
	map:addTile("tile-background-ice-01", 37, 3)
	map:addTile("tile-background-ice-07", 37, 4)
	map:addTile("tile-background-ice-cave-art-01", 37, 5)
	map:addTile("tile-background-ice-cave-art-02", 37, 6)
	map:addTile("tile-background-ice-big-01", 37, 7)
	map:addTile("tile-background-ice-01", 37, 9)
	map:addTile("tile-background-ice-04", 37, 10)
	map:addTile("tile-rock-slope-ice-left-01", 37, 11)
	map:addTile("tile-background-ice-02", 38, 2)
	map:addTile("tile-background-ice-cave-art-01", 38, 3)
	map:addTile("tile-background-ice-02", 38, 4)
	map:addTile("tile-background-ice-05", 38, 5)
	map:addTile("tile-background-ice-03", 38, 6)
	map:addTile("tile-background-ice-04", 38, 9)
	map:addTile("tile-rock-slope-ice-left-01", 38, 10)
	map:addTile("tile-rock-ice-02", 38, 11)
	map:addTile("tile-background-ice-cave-art-02", 39, 0)
	map:addTile("tile-background-ice-08", 39, 1)
	map:addTile("tile-background-ice-01", 39, 2)
	map:addTile("tile-background-ice-cave-art-01", 39, 3)
	map:addTile("tile-ground-ice-01", 39, 4)
	map:addTile("tile-rock-ice-02", 39, 5)
	map:addTile("tile-rock-ice-01", 39, 6)
	map:addTile("tile-background-ice-03", 39, 7)
	map:addTile("tile-background-ice-03", 39, 8)
	map:addTile("tile-rock-slope-ice-left-01", 39, 9)
	map:addTile("tile-rock-ice-02", 39, 10)
	map:addTile("tile-rock-ice-01", 39, 11)
	map:addTile("tile-background-ice-03", 40, 0)
	map:addTile("tile-background-ice-06", 40, 1)
	map:addTile("tile-background-ice-cave-art-02", 40, 2)
	map:addTile("tile-background-ice-06", 40, 3)
	map:addTile("tile-ground-ice-03", 40, 4)
	map:addTile("tile-rock-ice-big-01", 40, 5)
	map:addTile("tile-background-ice-cave-art-01", 40, 7)
	map:addTile("tile-background-ice-02", 40, 8)
	map:addTile("tile-rock-ice-03", 40, 9)
	map:addTile("tile-rock-ice-big-01", 40, 10)
	map:addTile("tile-background-ice-05", 41, 0)
	map:addTile("tile-background-ice-big-01", 41, 1)
	map:addTile("tile-waterfall-ice-01", 41, 3)
	map:addTile("tile-background-ice-06", 41, 7)
	map:addTile("tile-background-ice-05", 41, 8)
	map:addTile("tile-rock-ice-03", 41, 9)
	map:addTile("tile-background-ice-06", 42, 0)
	map:addTile("tile-background-ice-08", 42, 3)
	map:addTile("tile-ground-ice-01", 42, 4)
	map:addTile("tile-rock-ice-02", 42, 5)
	map:addTile("tile-rock-ice-01", 42, 6)
	map:addTile("tile-background-ice-06", 42, 7)
	map:addTile("tile-background-ice-07", 42, 8)
	map:addTile("tile-background-ice-cave-art-02", 42, 9)
	map:addTile("tile-rock-ice-03", 42, 10)
	map:addTile("tile-rock-ice-02", 42, 11)
	map:addTile("tile-background-ice-06", 43, 0)
	map:addTile("tile-background-ice-big-01", 43, 1)
	map:addTile("tile-background-ice-08", 43, 3)
	map:addTile("tile-ground-ice-02", 43, 4)
	map:addTile("tile-rock-ice-big-01", 43, 5)
	map:addTile("tile-rock-slope-ice-left-02", 43, 7)
	map:addTile("tile-background-ice-cave-art-02", 43, 8)
	map:addTile("tile-background-ice-06", 43, 9)
	map:addTile("tile-rock-ice-03", 43, 10)
	map:addTile("tile-rock-ice-01", 43, 11)
	map:addTile("tile-background-ice-cave-art-02", 44, 0)
	map:addTile("tile-background-ice-08", 44, 3)
	map:addTile("tile-ground-ice-01", 44, 4)
	map:addTile("tile-rock-ice-01", 44, 7)
	map:addTile("tile-background-ice-08", 44, 8)
	map:addTile("tile-background-ice-01", 44, 9)
	map:addTile("tile-rock-ice-03", 44, 10)
	map:addTile("tile-rock-ice-01", 44, 11)
	map:addTile("tile-background-ice-03", 45, 0)
	map:addTile("tile-background-ice-05", 45, 1)
	map:addTile("tile-background-ice-01", 45, 2)
	map:addTile("tile-background-ice-05", 45, 3)
	map:addTile("tile-ground-ice-03", 45, 4)
	map:addTile("tile-rock-ice-02", 45, 5)
	map:addTile("tile-rock-ice-01", 45, 6)
	map:addTile("tile-rock-ice-02", 45, 7)
	map:addTile("tile-background-ice-08", 45, 8)
	map:addTile("tile-background-ice-08", 45, 9)
	map:addTile("tile-background-ice-cave-art-01", 45, 10)
	map:addTile("bridge-wall-ice-left-01", 45, 10)
	map:addTile("tile-background-ice-04", 45, 11)
	map:addTile("tile-background-ice-04", 46, 0)
	map:addTile("tile-background-ice-03", 46, 1)
	map:addTile("tile-background-ice-big-01", 46, 2)
	map:addTile("tile-ground-ice-big-01", 46, 4)
	map:addTile("tile-rock-ice-01", 46, 6)
	map:addTile("tile-rock-slope-ice-right-02", 46, 7)
	map:addTile("tile-background-ice-01", 46, 8)
	map:addTile("tile-background-ice-06", 46, 9)
	map:addTile("tile-background-ice-03", 46, 10)
	map:addTile("bridge-plank-ice-01", 46, 10)
	map:addTile("tile-background-ice-05", 46, 11)
	map:addTile("tile-background-ice-05", 47, 0)
	map:addTile("tile-background-ice-03", 47, 1)
	map:addTile("tile-rock-ice-03", 47, 6)
	map:addTile("tile-background-ice-cave-art-02", 47, 7)
	map:addTile("tile-background-ice-01", 47, 8)
	map:addTile("tile-background-ice-06", 47, 9)
	map:addTile("tile-background-ice-02", 47, 10)
	map:addTile("bridge-wall-ice-right-01", 47, 10)
	map:addTile("tile-background-ice-06", 47, 11)
	map:addTile("tile-background-ice-cave-art-02", 48, 0)
	map:addTile("tile-background-ice-02", 48, 1)
	map:addTile("tile-background-ice-01", 48, 2)
	map:addTile("tile-geyser-ice-01-active", 48, 3)
	map:addTile("tile-rock-ice-01", 48, 5)
	map:addTile("tile-rock-ice-01", 48, 6)
	map:addTile("tile-background-ice-05", 48, 7)
	map:addTile("tile-waterfall-ice-01", 48, 8)
	map:addTile("tile-rock-ice-02", 48, 10)
	map:addTile("tile-rock-ice-02", 48, 11)
	map:addTile("tile-background-ice-06", 49, 0)
	map:addTile("tile-background-ice-cave-art-02", 49, 1)
	map:addTile("tile-background-ice-07", 49, 2)
	map:addTile("tile-background-ice-02", 49, 3)
	map:addTile("tile-ground-ice-big-01", 49, 4)
	map:addTile("tile-rock-ice-03", 49, 6)
	map:addTile("tile-background-ice-04", 49, 7)
	map:addTile("tile-background-ice-08", 49, 8)
	map:addTile("tile-ground-ice-02", 49, 9)
	map:addTile("tile-rock-ice-01", 49, 10)
	map:addTile("tile-rock-ice-02", 49, 11)
	map:addTile("tile-background-ice-07", 50, 0)
	map:addTile("tile-background-ice-05", 50, 1)
	map:addTile("tile-background-ice-05", 50, 2)
	map:addTile("tile-background-ice-08", 50, 3)
	map:addTile("tile-rock-ice-01", 50, 6)
	map:addTile("tile-background-ice-06", 50, 7)
	map:addTile("tile-background-ice-01", 50, 8)
	map:addTile("tile-ground-ice-04", 50, 9)
	map:addTile("tile-rock-ice-02", 50, 10)
	map:addTile("tile-rock-ice-02", 50, 11)
	map:addTile("tile-rock-slope-ice-left-02", 51, 0)
	map:addTile("tile-background-ice-05", 51, 1)
	map:addTile("tile-background-ice-cave-art-02", 51, 2)
	map:addTile("tile-background-ice-cave-art-01", 51, 3)
	map:addTile("tile-background-ice-cave-art-02", 51, 4)
	map:addTile("tile-ground-ice-big-01", 51, 5)
	map:addTile("tile-background-ice-cave-art-02", 51, 7)
	map:addTile("tile-background-ice-03", 51, 8)
	map:addTile("tile-ground-ice-03", 51, 9)
	map:addTile("tile-rock-ice-03", 51, 10)
	map:addTile("tile-rock-ice-01", 51, 11)
	map:addTile("tile-rock-ice-01", 52, 0)
	map:addTile("tile-rock-slope-ice-left-02", 52, 1)
	map:addTile("tile-background-ice-05", 52, 2)
	map:addTile("tile-background-ice-08", 52, 3)
	map:addTile("tile-background-ice-08", 52, 4)
	map:addTile("tile-background-ice-05", 52, 7)
	map:addTile("tile-background-ice-07", 52, 8)
	map:addTile("tile-ground-ice-01", 52, 9)
	map:addTile("tile-rock-ice-01", 52, 10)
	map:addTile("tile-rock-ice-02", 52, 11)
	map:addTile("tile-ground-ice-big-01", 53, 0)
	map:addTile("tile-background-ice-cave-art-01", 53, 2)
	map:addTile("tile-background-ice-big-01", 53, 3)
	map:addTile("tile-ground-ice-03", 53, 5)
	map:addTile("tile-rock-slope-ice-right-02", 53, 6)
	map:addTile("tile-background-ice-01", 53, 7)
	map:addTile("tile-background-ice-04", 53, 8)
	map:addTile("tile-ground-ice-02", 53, 9)
	map:addTile("tile-rock-slope-ice-right-02", 53, 10)
	map:addTile("tile-background-ice-04", 53, 11)
	map:addTile("tile-background-ice-01", 54, 2)
	map:addTile("tile-rock-ice-03", 54, 5)
	map:addTile("tile-background-ice-02", 54, 6)
	map:addTile("tile-background-ice-05", 54, 7)
	map:addTile("tile-background-ice-06", 54, 8)
	map:addTile("tile-rock-ice-left-04", 54, 9)
	map:addTile("tile-background-ice-04", 54, 10)
	map:addTile("tile-background-ice-02", 54, 11)
	map:addTile("tile-rock-ice-02", 55, 0)
	map:addTile("tile-rock-ice-01", 55, 1)
	map:addTile("tile-rock-slope-ice-left-02", 55, 2)
	map:addTile("tile-background-ice-08", 55, 3)
	map:addTile("tile-background-ice-03", 55, 4)
	map:addTile("tile-ground-ice-03", 55, 5)
	map:addTile("tile-background-ice-cave-art-02", 55, 6)
	map:addTile("tile-background-ice-04", 55, 7)
	map:addTile("tile-background-ice-big-01", 55, 8)
	map:addTile("tile-background-ice-06", 55, 10)
	map:addTile("tile-background-ice-04", 55, 11)
	map:addTile("tile-rock-ice-01", 56, 0)
	map:addTile("tile-ground-ice-big-01", 56, 1)
	map:addTile("tile-background-ice-03", 56, 3)
	map:addTile("tile-background-ice-03", 56, 4)
	map:addTile("tile-rock-ice-left-04", 56, 5)
	map:addTile("tile-background-ice-06", 56, 6)
	map:addTile("tile-background-ice-01", 56, 7)
	map:addTile("tile-background-ice-02", 56, 10)
	map:addTile("tile-background-ice-08", 56, 11)
	map:addTile("tile-rock-ice-02", 57, 0)
	map:addTile("tile-background-ice-02", 57, 3)
	map:addTile("tile-background-ice-cave-art-02", 57, 4)
	map:addTile("tile-background-ice-cave-art-02", 57, 5)
	map:addTile("tile-background-ice-big-01", 57, 6)
	map:addTile("tile-background-ice-01", 57, 8)
	map:addTile("tile-ground-ice-02", 57, 9)
	map:addTile("tile-rock-ice-big-01", 57, 10)
	map:addTile("tile-rock-ice-02", 58, 0)
	map:addTile("tile-rock-ice-01", 58, 1)
	map:addTile("tile-rock-slope-ice-right-02", 58, 2)
	map:addTile("tile-background-ice-big-01", 58, 3)
	map:addTile("tile-background-ice-02", 58, 5)
	map:addTile("tile-background-ice-01", 58, 8)
	map:addTile("tile-ground-ice-01", 58, 9)
	map:addTile("tile-rock-ice-01", 59, 0)
	map:addTile("tile-rock-slope-ice-right-02", 59, 1)
	map:addTile("tile-background-ice-05", 59, 2)
	map:addTile("tile-background-ice-cave-art-02", 59, 5)
	map:addTile("tile-background-ice-02", 59, 6)
	map:addTile("tile-ground-ice-01", 59, 7)
	map:addTile("tile-rock-ice-01", 59, 8)
	map:addTile("tile-rock-ice-01", 59, 9)
	map:addTile("tile-rock-ice-big-01", 59, 10)
	map:addTile("tile-rock-slope-ice-right-02", 60, 0)
	map:addTile("tile-background-ice-02", 60, 1)
	map:addTile("tile-background-ice-05", 60, 2)
	map:addTile("tile-background-ice-05", 60, 3)
	map:addTile("tile-background-ice-07", 60, 4)
	map:addTile("tile-background-ice-cave-art-02", 60, 5)
	map:addTile("tile-ground-ice-03", 60, 6)
	map:addTile("tile-rock-ice-big-01", 60, 7)
	map:addTile("tile-rock-ice-01", 60, 9)
	map:addTile("tile-background-ice-02", 61, 0)
	map:addTile("tile-background-ice-02", 61, 1)
	map:addTile("tile-background-ice-05", 61, 2)
	map:addTile("tile-background-ice-04", 61, 3)
	map:addTile("tile-background-ice-01", 61, 4)
	map:addTile("tile-background-ice-04", 61, 5)
	map:addTile("tile-ground-ice-03", 61, 6)
	map:addTile("tile-rock-ice-03", 61, 9)
	map:addTile("tile-rock-slope-ice-right-02", 61, 10)
	map:addTile("tile-background-ice-03", 61, 11)
	map:addTile("tile-background-ice-06", 62, 0)
	map:addTile("tile-background-ice-big-01", 62, 1)
	map:addTile("tile-background-ice-04", 62, 3)
	map:addTile("tile-background-ice-01", 62, 4)
	map:addTile("tile-background-ice-01", 62, 5)
	map:addTile("tile-ground-ice-03", 62, 6)
	map:addTile("tile-rock-ice-01", 62, 7)
	map:addTile("tile-rock-ice-01", 62, 8)
	map:addTile("tile-rock-slope-ice-right-02", 62, 9)
	map:addTile("tile-background-ice-02", 62, 10)
	map:addTile("tile-background-ice-08", 62, 11)
	map:addTile("tile-background-ice-05", 63, 0)
	map:addTile("tile-background-ice-05", 63, 3)
	map:addTile("tile-background-ice-07", 63, 4)
	map:addTile("tile-background-ice-05", 63, 5)
	map:addTile("tile-ground-ice-02", 63, 6)
	map:addTile("tile-rock-ice-03", 63, 7)
	map:addTile("tile-rock-slope-ice-right-02", 63, 8)
	map:addTile("tile-background-ice-06", 63, 9)
	map:addTile("tile-background-ice-big-01", 63, 10)
	map:addTile("tile-background-ice-cave-art-02", 64, 0)
	map:addTile("tile-background-ice-cave-art-01", 64, 1)
	map:addTile("tile-background-ice-07", 64, 2)
	map:addTile("tile-background-ice-03", 64, 3)
	map:addTile("tile-background-ice-cave-art-02", 64, 4)
	map:addTile("tile-waterfall-ice-01", 64, 5)
	map:addTile("tile-rock-ice-01", 64, 7)
	map:addTile("tile-background-ice-05", 64, 8)
	map:addTile("tile-background-ice-03", 64, 9)
	map:addTile("tile-background-ice-06", 65, 0)
	map:addTile("tile-background-ice-01", 65, 1)
	map:addTile("tile-background-ice-06", 65, 2)
	map:addTile("tile-background-ice-07", 65, 3)
	map:addTile("tile-background-ice-01", 65, 4)
	map:addTile("tile-background-ice-big-01", 65, 5)
	map:addTile("tile-background-ice-02", 65, 7)
	map:addTile("tile-background-ice-05", 65, 8)
	map:addTile("tile-background-ice-07", 65, 9)
	map:addTile("tile-ground-ice-02", 65, 10)
	map:addTile("tile-rock-ice-02", 65, 11)
	map:addTile("tile-background-ice-04", 66, 0)
	map:addTile("tile-background-ice-02", 66, 1)
	map:addTile("tile-background-ice-01", 66, 2)
	map:addTile("tile-background-ice-02", 66, 3)
	map:addTile("tile-background-ice-06", 66, 4)
	map:addTile("tile-background-ice-06", 66, 7)
	map:addTile("tile-background-ice-05", 66, 8)
	map:addTile("tile-background-ice-cave-art-01", 66, 9)
	map:addTile("tile-background-ice-big-01", 66, 10)
	map:addTile("bridge-wall-ice-left-01", 66, 10)
	map:addTile("tile-background-ice-08", 67, 0)
	map:addTile("tile-background-ice-07", 67, 1)
	map:addTile("tile-background-ice-08", 67, 2)
	map:addTile("tile-ground-ice-06", 67, 3)
	map:addTile("tile-rock-ice-big-01", 67, 4)
	map:addTile("tile-background-ice-cave-art-02", 67, 6)
	map:addTile("tile-background-ice-big-01", 67, 7)
	map:addTile("tile-background-ice-04", 67, 9)
	map:addTile("bridge-plank-ice-01", 67, 10)
	map:addTile("tile-background-ice-08", 68, 0)
	map:addTile("tile-background-ice-cave-art-02", 68, 1)
	map:addTile("tile-background-ice-06", 68, 2)
	map:addTile("tile-ground-ice-03", 68, 3)
	map:addTile("tile-background-ice-cave-art-02", 68, 6)
	map:addTile("tile-background-ice-01", 68, 9)
	map:addTile("tile-background-ice-03", 68, 10)
	map:addTile("bridge-wall-ice-right-01", 68, 10)
	map:addTile("tile-background-ice-04", 68, 11)
	map:addTile("tile-background-ice-07", 69, 0)
	map:addTile("tile-background-ice-04", 69, 1)
	map:addTile("tile-waterfall-ice-01", 69, 2)
	map:addTile("tile-rock-ice-01", 69, 4)
	map:addTile("tile-rock-ice-03", 69, 5)
	map:addTile("tile-background-ice-08", 69, 6)
	map:addTile("tile-background-ice-06", 69, 7)
	map:addTile("tile-background-ice-04", 69, 8)
	map:addTile("tile-geyser-ice-01-active", 69, 9)
	map:addTile("tile-rock-ice-02", 69, 11)
	map:addTile("tile-background-ice-big-01", 70, 0)
	map:addTile("tile-background-ice-01", 70, 2)
	map:addTile("tile-ground-ice-03", 70, 3)
	map:addTile("tile-rock-ice-01", 70, 4)
	map:addTile("tile-rock-ice-03", 70, 5)
	map:addTile("tile-background-ice-cave-art-02", 70, 6)
	map:addTile("tile-background-ice-cave-art-02", 70, 7)
	map:addTile("tile-background-ice-cave-art-01", 70, 8)
	map:addTile("tile-background-ice-08", 70, 9)
	map:addTile("tile-ground-ice-02", 70, 10)
	map:addTile("tile-rock-ice-02", 70, 11)
	map:addTile("tile-background-ice-01", 71, 2)
	map:addTile("tile-ground-ice-big-01", 71, 3)
	map:addTile("tile-rock-slope-ice-right-02", 71, 5)
	map:addTile("tile-background-ice-cave-art-01", 71, 6)
	map:addTile("tile-background-ice-04", 71, 7)
	map:addTile("tile-ground-ice-06", 71, 8)
	map:addTile("tile-rock-ice-02", 71, 9)
	map:addTile("tile-rock-ice-02", 71, 10)
	map:addTile("tile-rock-ice-02", 71, 11)
	map:addTile("tile-background-ice-07", 72, 0)
	map:addTile("tile-background-ice-cave-art-01", 72, 1)
	map:addTile("tile-background-ice-cave-art-01", 72, 2)
	map:addTile("tile-rock-slope-ice-left-02", 72, 5)
	map:addTile("tile-background-ice-cave-art-01", 72, 6)
	map:addTile("tile-background-ice-cave-art-02", 72, 7)
	map:addTile("tile-ground-ice-02", 72, 8)
	map:addTile("tile-rock-slope-ice-right-02", 72, 9)
	map:addTile("tile-background-ice-03", 72, 10)
	map:addTile("tile-background-ice-01", 72, 11)
	map:addTile("tile-background-ice-04", 73, 0)
	map:addTile("tile-background-ice-08", 73, 1)
	map:addTile("tile-ground-ice-06", 73, 2)
	map:addTile("tile-rock-ice-01", 73, 3)
	map:addTile("tile-rock-ice-02", 73, 4)
	map:addTile("tile-rock-ice-02", 73, 5)
	map:addTile("tile-background-ice-04", 73, 6)
	map:addTile("tile-background-ice-07", 73, 7)
	map:addTile("tile-background-ice-04", 73, 8)
	map:addTile("tile-background-ice-02", 73, 9)
	map:addTile("tile-background-ice-02", 73, 10)
	map:addTile("tile-background-ice-cave-art-01", 73, 11)
	map:addTile("tile-background-ice-08", 74, 0)
	map:addTile("tile-background-ice-cave-art-02", 74, 1)
	map:addTile("tile-ground-ice-02", 74, 2)
	map:addTile("tile-rock-ice-03", 74, 3)
	map:addTile("tile-rock-ice-01", 74, 4)
	map:addTile("tile-rock-slope-ice-right-02", 74, 5)
	map:addTile("tile-background-ice-07", 74, 6)
	map:addTile("tile-background-ice-04", 74, 7)
	map:addTile("tile-background-ice-04", 74, 8)
	map:addTile("tile-background-ice-big-01", 74, 9)
	map:addTile("tile-background-ice-07", 74, 11)
	map:addTile("tile-background-ice-04", 75, 0)
	map:addTile("tile-background-ice-01", 75, 1)
	map:addTile("tile-ground-ice-06", 75, 2)
	map:addTile("tile-rock-ice-big-01", 75, 3)
	map:addTile("tile-background-ice-03", 75, 5)
	map:addTile("tile-background-ice-05", 75, 6)
	map:addTile("tile-background-ice-05", 75, 7)
	map:addTile("tile-background-ice-03", 75, 8)
	map:addTile("tile-background-ice-02", 75, 11)
	map:addTile("tile-background-ice-01", 76, 0)
	map:addTile("tile-background-ice-08", 76, 1)
	map:addTile("tile-ground-ice-02", 76, 2)
	map:addTile("tile-rock-slope-ice-left-02", 76, 5)
	map:addTile("tile-background-ice-01", 76, 6)
	map:addTile("tile-background-ice-06", 76, 7)
	map:addTile("tile-background-ice-01", 76, 8)
	map:addTile("tile-background-ice-07", 76, 9)
	map:addTile("tile-background-ice-big-01", 76, 10)
	map:addTile("tile-background-ice-07", 77, 0)
	map:addTile("tile-background-ice-02", 77, 1)
	map:addTile("tile-ground-ice-04", 77, 2)
	map:addTile("tile-rock-ice-02", 77, 3)
	map:addTile("tile-rock-ice-02", 77, 4)
	map:addTile("tile-rock-ice-02", 77, 5)
	map:addTile("tile-background-ice-02", 77, 6)
	map:addTile("tile-background-ice-07", 77, 7)
	map:addTile("tile-background-ice-01", 77, 8)
	map:addTile("tile-background-ice-01", 77, 9)
	map:addTile("tile-background-ice-07", 78, 0)
	map:addTile("tile-background-ice-cave-art-02", 78, 1)
	map:addTile("tile-ground-ice-01", 78, 2)
	map:addTile("tile-rock-ice-big-01", 78, 3)
	map:addTile("tile-rock-ice-01", 78, 5)
	map:addTile("tile-rock-slope-ice-left-02", 78, 6)
	map:addTile("tile-background-ice-06", 78, 7)
	map:addTile("tile-background-ice-06", 78, 8)
	map:addTile("tile-background-ice-01", 78, 9)
	map:addTile("tile-background-ice-07", 78, 10)
	map:addTile("tile-background-ice-07", 78, 11)
	map:addTile("tile-background-ice-cave-art-01", 79, 0)
	map:addTile("tile-background-ice-cave-art-01", 79, 1)
	map:addTile("tile-rock-slope-ice-right-01", 79, 2)
	map:addTile("tile-rock-ice-03", 79, 5)
	map:addTile("tile-rock-ice-01", 79, 6)
	map:addTile("tile-background-ice-05", 79, 7)
	map:addTile("tile-background-ice-01", 79, 8)
	map:addTile("tile-background-ice-02", 79, 9)
	map:addTile("tile-background-ice-04", 79, 10)
	map:addTile("tile-background-ice-cave-art-01", 79, 11)
	map:addTile("tile-background-ice-cave-art-02", 80, 0)
	map:addTile("tile-background-ice-04", 80, 1)
	map:addTile("tile-rock-slope-ice-left-01", 80, 2)
	map:addTile("tile-rock-ice-02", 80, 3)
	map:addTile("tile-rock-ice-01", 80, 4)
	map:addTile("tile-rock-ice-big-01", 80, 5)
	map:addTile("tile-background-ice-02", 80, 7)
	map:addTile("tile-background-ice-07", 80, 8)
	map:addTile("tile-background-ice-05", 80, 9)
	map:addTile("tile-background-ice-cave-art-02", 80, 10)
	map:addTile("tile-background-ice-cave-art-02", 80, 11)
	map:addTile("tile-background-ice-05", 81, 0)
	map:addTile("tile-background-ice-04", 81, 1)
	map:addTile("tile-ground-ice-04", 81, 2)
	map:addTile("tile-rock-ice-01", 81, 3)
	map:addTile("tile-rock-ice-02", 81, 4)
	map:addTile("tile-rock-slope-ice-left-02", 81, 7)
	map:addTile("tile-background-ice-05", 81, 8)
	map:addTile("tile-background-ice-08", 81, 9)
	map:addTile("tile-background-ice-07", 81, 10)
	map:addTile("tile-background-ice-cave-art-01", 81, 11)
	map:addTile("tile-background-ice-02", 82, 0)
	map:addTile("tile-background-ice-07", 82, 1)
	map:addTile("tile-ground-ice-04", 82, 2)
	map:addTile("tile-rock-ice-big-01", 82, 3)
	map:addTile("tile-rock-ice-02", 82, 5)
	map:addTile("tile-rock-ice-01", 82, 6)
	map:addTile("tile-rock-ice-02", 82, 7)
	map:addTile("tile-background-ice-06", 82, 8)
	map:addTile("tile-background-ice-03", 82, 9)
	map:addTile("tile-background-ice-03", 82, 10)
	map:addTile("tile-background-ice-03", 82, 11)
	map:addTile("tile-background-ice-06", 83, 0)
	map:addTile("tile-background-ice-08", 83, 1)
	map:addTile("tile-rock-slope-ice-right-01", 83, 2)
	map:addTile("tile-rock-ice-03", 83, 5)
	map:addTile("tile-rock-ice-03", 83, 6)
	map:addTile("tile-rock-ice-01", 83, 7)
	map:addTile("tile-background-ice-cave-art-02", 83, 8)
	map:addTile("tile-background-ice-cave-art-02", 83, 9)
	map:addTile("tile-background-ice-05", 83, 10)
	map:addTile("tile-background-ice-06", 83, 11)
	map:addTile("tile-background-ice-06", 84, 0)
	map:addTile("tile-background-ice-02", 84, 1)
	map:addTile("tile-background-ice-07", 84, 2)
	map:addTile("tile-background-ice-04", 84, 3)
	map:addTile("tile-rock-slope-ice-right-01", 84, 4)
	map:addTile("tile-rock-ice-01", 84, 5)
	map:addTile("tile-rock-ice-big-01", 84, 6)
	map:addTile("tile-rock-slope-ice-left-02", 84, 8)
	map:addTile("tile-background-ice-07", 84, 9)
	map:addTile("tile-background-ice-02", 84, 10)
	map:addTile("tile-background-ice-04", 84, 11)
	map:addTile("tile-background-ice-07", 85, 0)
	map:addTile("tile-background-ice-04", 85, 1)
	map:addTile("tile-background-ice-03", 85, 2)
	map:addTile("tile-background-ice-05", 85, 3)
	map:addTile("tile-background-ice-07", 85, 4)
	map:addTile("tile-ground-ice-01", 85, 5)
	map:addTile("tile-rock-ice-03", 85, 8)
	map:addTile("tile-background-ice-01", 85, 9)
	map:addTile("tile-background-ice-08", 85, 10)
	map:addTile("tile-background-ice-cave-art-02", 85, 11)
	map:addTile("tile-background-ice-08", 86, 0)
	map:addTile("tile-background-ice-07", 86, 1)
	map:addTile("tile-ground-ledge-ice-left-01", 86, 2)
	map:addTile("tile-background-ice-07", 86, 3)
	map:addTile("tile-background-ice-08", 86, 4)
	map:addTile("tile-rock-slope-ice-right-01", 86, 5)
	map:addTile("tile-rock-ice-01", 86, 6)
	map:addTile("tile-rock-ice-03", 86, 7)
	map:addTile("tile-rock-ice-01", 86, 8)
	map:addTile("tile-rock-slope-ice-left-02", 86, 9)
	map:addTile("tile-background-ice-03", 86, 10)
	map:addTile("tile-background-ice-cave-art-01", 86, 11)
	map:addTile("tile-background-ice-cave-art-02", 87, 0)
	map:addTile("tile-background-ice-01", 87, 1)
	map:addTile("tile-ground-ice-01", 87, 2)
	map:addTile("tile-rock-slope-ice-left-02", 87, 3)
	map:addTile("tile-background-ice-04", 87, 4)
	map:addTile("tile-background-ice-03", 87, 5)
	map:addTile("tile-rock-slope-ice-right-01", 87, 6)
	map:addTile("tile-rock-ice-01", 87, 7)
	map:addTile("tile-rock-ice-big-01", 87, 8)
	map:addTile("tile-background-ice-06", 87, 10)
	map:addTile("tile-background-ice-07", 87, 11)
	map:addTile("tile-background-ice-cave-art-01", 88, 0)
	map:addTile("tile-waterfall-ice-01", 88, 1)
	map:addTile("tile-rock-ice-03", 88, 3)
	map:addTile("tile-background-ice-01", 88, 4)
	map:addTile("tile-background-ice-05", 88, 5)
	map:addTile("tile-background-ice-07", 88, 6)
	map:addTile("tile-rock-slope-ice-right-01", 88, 7)
	map:addTile("tile-background-ice-01", 88, 10)
	map:addTile("tile-background-ice-05", 88, 11)
	map:addTile("tile-background-ice-05", 89, 0)
	map:addTile("tile-background-ice-02", 89, 1)
	map:addTile("tile-ground-ice-02", 89, 2)
	map:addTile("tile-rock-slope-ice-right-02", 89, 3)
	map:addTile("tile-background-ice-04", 89, 4)
	map:addTile("tile-background-ice-cave-art-02", 89, 5)
	map:addTile("tile-background-ice-07", 89, 6)
	map:addTile("tile-background-ice-07", 89, 7)
	map:addTile("tile-background-ice-05", 89, 8)
	map:addTile("bridge-wall-ice-left-01", 89, 8)
	map:addTile("tile-background-ice-04", 89, 9)
	map:addTile("tile-background-ice-big-01", 89, 10)
	map:addTile("tile-background-ice-07", 90, 0)
	map:addTile("tile-background-ice-03", 90, 1)
	map:addTile("tile-ground-ice-03", 90, 2)
	map:addTile("tile-rock-slope-ice-left-02", 90, 3)
	map:addTile("tile-background-ice-04", 90, 4)
	map:addTile("tile-background-ice-07", 90, 5)
	map:addTile("tile-background-ice-08", 90, 6)
	map:addTile("tile-background-ice-cave-art-02", 90, 7)
	map:addTile("tile-background-ice-07", 90, 8)
	map:addTile("bridge-plank-ice-01", 90, 8)
	map:addTile("tile-background-ice-01", 90, 9)
	map:addTile("tile-background-ice-01", 91, 0)
	map:addTile("tile-background-ice-04", 91, 1)
	map:addTile("tile-rock-ice-left-04", 91, 2)
	map:addTile("tile-rock-ice-left-05", 91, 3)
	map:addTile("tile-background-ice-07", 91, 4)
	map:addTile("tile-background-ice-08", 91, 5)
	map:addTile("tile-background-ice-02", 91, 6)
	map:addTile("tile-background-ice-big-01", 91, 7)
	map:addTile("bridge-plank-ice-01", 91, 8)
	map:addTile("tile-background-ice-05", 91, 9)
	map:addTile("tile-background-ice-04", 91, 10)
	map:addTile("tile-background-ice-06", 91, 11)
	map:addTile("tile-rock-ice-right-05", 92, 0)
	map:addTile("tile-rock-ice-right-04", 92, 1)
	map:addTile("tile-rock-ice-right-05", 92, 2)
	map:addTile("tile-rock-ice-right-05", 92, 3)
	map:addTile("tile-rock-ice-right-04", 92, 4)
	map:addTile("tile-background-ice-01", 92, 5)
	map:addTile("tile-background-ice-08", 92, 6)
	map:addTile("bridge-wall-ice-right-01", 92, 8)
	map:addTile("tile-background-ice-05", 92, 9)
	map:addTile("tile-background-ice-07", 92, 10)
	map:addTile("tile-background-ice-cave-art-02", 92, 11)
	map:addTile("tile-rock-ice-03", 93, 0)
	map:addTile("tile-rock-ice-01", 93, 1)
	map:addTile("tile-rock-ice-03", 93, 2)
	map:addTile("tile-rock-ice-big-01", 93, 3)
	map:addTile("tile-background-ice-01", 93, 5)
	map:addTile("tile-background-ice-08", 93, 6)
	map:addTile("tile-background-ice-07", 93, 7)
	map:addTile("tile-rock-slope-ice-right-01", 93, 8)
	map:addTile("tile-rock-shim-ice-01", 93, 9)
	map:addTile("tile-background-ice-04", 93, 10)
	map:addTile("tile-background-ice-02", 93, 11)
	map:addTile("tile-background-ice-big-01", 94, 0)
	map:addTile("tile-ground-ice-03", 94, 2)
	map:addTile("tile-rock-slope-ice-left-02", 94, 5)
	map:addTile("tile-background-ice-02", 94, 6)
	map:addTile("tile-background-ice-03", 94, 7)
	map:addTile("tile-background-ice-04", 94, 8)
	map:addTile("tile-background-ice-04", 94, 9)
	map:addTile("tile-background-ice-big-01", 94, 10)
	map:addTile("tile-ground-ice-03", 95, 2)
	map:addTile("tile-rock-ice-01", 95, 3)
	map:addTile("tile-rock-ice-03", 95, 4)
	map:addTile("tile-rock-ice-02", 95, 5)
	map:addTile("tile-background-ice-08", 95, 6)
	map:addTile("tile-background-ice-07", 95, 7)
	map:addTile("tile-background-ice-02", 95, 8)
	map:addTile("tile-background-ice-02", 95, 9)
	map:addTile("tile-background-ice-05", 96, 0)
	map:addTile("tile-background-ice-02", 96, 1)
	map:addTile("tile-background-ice-08", 96, 2)
	map:addTile("tile-ground-ice-06", 96, 3)
	map:addTile("tile-rock-ice-01", 96, 4)
	map:addTile("tile-rock-slope-ice-right-02", 96, 5)
	map:addTile("tile-background-ice-05", 96, 6)
	map:addTile("tile-background-ice-05", 96, 7)
	map:addTile("tile-background-ice-07", 96, 8)
	map:addTile("tile-background-ice-04", 96, 9)
	map:addTile("tile-background-ice-06", 96, 10)
	map:addTile("tile-background-ice-08", 96, 11)
	map:addTile("tile-background-ice-cave-art-01", 97, 0)
	map:addTile("tile-background-ice-02", 97, 1)
	map:addTile("tile-background-ice-04", 97, 2)
	map:addTile("tile-ground-ice-01", 97, 3)
	map:addTile("tile-rock-ice-03", 97, 4)
	map:addTile("tile-background-ice-05", 97, 5)
	map:addTile("tile-background-ice-07", 97, 6)
	map:addTile("tile-background-ice-03", 97, 7)
	map:addTile("tile-background-ice-cave-art-02", 97, 8)
	map:addTile("tile-background-ice-07", 97, 9)
	map:addTile("tile-background-ice-01", 97, 10)
	map:addTile("tile-background-ice-03", 97, 11)
	map:addTile("tile-background-ice-03", 98, 0)
	map:addTile("tile-background-ice-big-01", 98, 1)
	map:addTile("tile-ground-ice-06", 98, 3)
	map:addTile("tile-rock-ice-left-04", 98, 4)
	map:addTile("tile-background-ice-04", 98, 5)
	map:addTile("tile-background-ice-04", 98, 6)
	map:addTile("tile-background-ice-cave-art-02", 98, 7)
	map:addTile("tile-background-ice-08", 98, 8)
	map:addTile("tile-background-ice-05", 98, 9)
	map:addTile("tile-background-ice-07", 98, 10)
	map:addTile("tile-background-ice-01", 98, 11)
	map:addTile("tile-background-ice-05", 99, 0)
	map:addTile("tile-ground-ice-01", 99, 3)
	map:addTile("tile-background-ice-big-01", 99, 4)
	map:addTile("tile-background-ice-07", 99, 6)
	map:addTile("tile-background-ice-cave-art-02", 99, 7)
	map:addTile("tile-background-ice-04", 99, 8)
	map:addTile("tile-background-ice-08", 99, 9)
	map:addTile("tile-background-ice-03", 99, 10)
	map:addTile("tile-rock-slope-ice-left-01", 99, 11)
	map:addTile("tile-background-ice-06", 100, 0)
	map:addTile("tile-background-ice-04", 100, 1)
	map:addTile("tile-background-ice-01", 100, 2)
	map:addTile("tile-rock-ice-left-04", 100, 3)
	map:addTile("tile-background-ice-07", 100, 6)
	map:addTile("tile-background-ice-cave-art-02", 100, 7)
	map:addTile("tile-background-ice-08", 100, 8)
	map:addTile("tile-background-ice-06", 100, 9)
	map:addTile("tile-rock-slope-ice-left-01", 100, 10)
	map:addTile("tile-rock-ice-02", 100, 11)
	map:addTile("tile-background-ice-01", 101, 0)
	map:addTile("tile-background-ice-06", 101, 1)
	map:addTile("tile-background-ice-08", 101, 2)
	map:addTile("tile-background-ice-07", 101, 3)
	map:addTile("tile-background-ice-03", 101, 4)
	map:addTile("tile-background-ice-07", 101, 5)
	map:addTile("tile-background-ice-big-01", 101, 6)
	map:addTile("tile-ground-ice-03", 101, 8)
	map:addTile("tile-rock-ice-01", 101, 9)
	map:addTile("tile-rock-ice-02", 101, 10)
	map:addTile("tile-rock-ice-01", 101, 11)
	map:addTile("tile-background-ice-05", 102, 0)
	map:addTile("tile-background-ice-06", 102, 1)
	map:addTile("tile-background-ice-04", 102, 2)
	map:addTile("tile-background-ice-03", 102, 3)
	map:addTile("tile-background-ice-07", 102, 4)
	map:addTile("tile-background-ice-03", 102, 5)
	map:addTile("tile-packagetarget-ice-01-idle", 102, 8)
	map:addTile("tile-rock-ice-big-01", 102, 9)
	map:addTile("tile-rock-ice-02", 102, 11)
	map:addTile("tile-background-ice-06", 103, 0)
	map:addTile("tile-background-ice-06", 103, 1)
	map:addTile("tile-background-ice-01", 103, 2)
	map:addTile("tile-background-ice-01", 103, 3)
	map:addTile("tile-background-ice-06", 103, 4)
	map:addTile("tile-background-ice-06", 103, 5)
	map:addTile("tile-ground-ice-04", 103, 6)
	map:addTile("tile-rock-ice-03", 103, 7)
	map:addTile("tile-rock-ice-02", 103, 8)
	map:addTile("tile-rock-ice-02", 103, 11)
	map:addTile("tile-background-ice-06", 104, 0)
	map:addTile("tile-background-ice-big-01", 104, 1)
	map:addTile("tile-background-ice-07", 104, 3)
	map:addTile("tile-background-ice-05", 104, 4)
	map:addTile("tile-background-ice-01", 104, 5)
	map:addTile("tile-ground-ice-04", 104, 6)
	map:addTile("tile-rock-ice-01", 104, 7)
	map:addTile("tile-rock-ice-02", 104, 8)
	map:addTile("tile-rock-ice-01", 104, 9)
	map:addTile("tile-rock-ice-02", 104, 10)
	map:addTile("tile-rock-ice-02", 104, 11)
	map:addTile("tile-background-ice-cave-art-02", 105, 0)
	map:addTile("tile-background-ice-08", 105, 3)
	map:addTile("tile-background-ice-03", 105, 4)
	map:addTile("tile-background-ice-08", 105, 5)
	map:addTile("tile-ground-ice-03", 105, 6)
	map:addTile("tile-rock-ice-02", 105, 7)
	map:addTile("tile-rock-ice-03", 105, 8)
	map:addTile("tile-rock-ice-03", 105, 9)
	map:addTile("tile-rock-ice-02", 105, 10)
	map:addTile("tile-rock-ice-02", 105, 11)
	map:addTile("tile-background-ice-08", 106, 0)
	map:addTile("tile-background-ice-01", 106, 1)
	map:addTile("tile-background-ice-05", 106, 2)
	map:addTile("tile-background-ice-02", 106, 3)
	map:addTile("tile-background-ice-cave-art-02", 106, 4)
	map:addTile("tile-waterfall-ice-01", 106, 5)
	map:addTile("tile-ground-ice-01", 106, 7)
	map:addTile("tile-rock-ice-03", 106, 8)
	map:addTile("tile-rock-ice-03", 106, 9)
	map:addTile("tile-rock-ice-02", 106, 10)
	map:addTile("tile-rock-slope-ice-right-02", 106, 11)
	map:addTile("tile-background-ice-04", 107, 0)
	map:addTile("tile-background-ice-07", 107, 1)
	map:addTile("tile-background-ice-03", 107, 2)
	map:addTile("tile-background-ice-01", 107, 3)
	map:addTile("tile-background-ice-01", 107, 4)
	map:addTile("tile-background-ice-01", 107, 5)
	map:addTile("tile-rock-ice-left-04", 107, 6)
	map:addTile("tile-rock-ice-left-05", 107, 7)
	map:addTile("tile-rock-ice-left-04", 107, 8)
	map:addTile("tile-rock-ice-left-05", 107, 9)
	map:addTile("tile-ground-ledge-ice-right-01", 107, 10)
	map:addTile("tile-background-ice-03", 107, 11)
	map:addTile("tile-background-ice-cave-art-02", 108, 0)
	map:addTile("tile-background-ice-02", 108, 1)
	map:addTile("tile-background-ice-01", 108, 2)
	map:addTile("tile-background-ice-04", 108, 3)
	map:addTile("tile-background-ice-03", 108, 4)
	map:addTile("tile-background-ice-cave-art-02", 108, 5)
	map:addTile("tile-background-ice-02", 108, 6)
	map:addTile("tile-background-ice-08", 108, 7)
	map:addTile("tile-background-ice-cave-art-02", 108, 8)
	map:addTile("tile-background-ice-01", 108, 9)
	map:addTile("tile-ground-ledge-ice-right-02", 108, 10)
	map:addTile("tile-background-ice-08", 108, 11)
	map:addTile("tile-background-ice-07", 109, 0)
	map:addTile("tile-background-ice-05", 109, 1)
	map:addTile("tile-background-ice-01", 109, 2)
	map:addTile("tile-background-ice-06", 109, 3)
	map:addTile("tile-background-ice-03", 109, 4)
	map:addTile("tile-background-ice-01", 109, 5)
	map:addTile("tile-background-ice-07", 109, 6)
	map:addTile("tile-background-ice-01", 109, 7)
	map:addTile("tile-background-ice-01", 109, 8)
	map:addTile("tile-background-ice-01", 109, 9)
	map:addTile("tile-ground-ice-05", 109, 10)
	map:addTile("tile-background-ice-03", 109, 11)
	map:addTile("tile-background-ice-cave-art-01", 110, 0)
	map:addTile("tile-background-ice-08", 110, 1)
	map:addTile("tile-background-ice-01", 110, 2)
	map:addTile("tile-waterfall-ice-01", 110, 3)
	map:addTile("tile-rock-ice-big-01", 110, 5)
	map:addTile("tile-background-ice-05", 110, 7)
	map:addTile("tile-background-ice-01", 110, 8)
	map:addTile("tile-background-ice-01", 110, 9)
	map:addTile("tile-ground-ice-05", 110, 10)
	map:addTile("tile-background-ice-05", 110, 11)
	map:addTile("tile-background-ice-01", 111, 0)
	map:addTile("tile-background-ice-01", 111, 1)
	map:addTile("tile-background-ice-big-01", 111, 2)
	map:addTile("tile-ground-ice-06", 111, 4)
	map:addTile("tile-background-ice-04", 111, 7)
	map:addTile("tile-background-ice-01", 111, 8)
	map:addTile("tile-background-ice-big-01", 111, 9)
	map:addTile("tile-background-ice-06", 111, 11)
	map:addTile("tile-background-ice-cave-art-02", 112, 0)
	map:addTile("tile-background-ice-07", 112, 1)
	map:addTile("tile-ground-ice-03", 112, 4)
	map:addTile("tile-rock-ice-01", 112, 5)
	map:addTile("tile-rock-ice-02", 112, 6)
	map:addTile("tile-background-ice-big-01", 112, 7)
	map:addTile("tile-background-ice-01", 112, 11)
	map:addTile("tile-background-ice-cave-art-02", 113, 0)
	map:addTile("tile-background-ice-03", 113, 1)
	map:addTile("tile-background-ice-cave-art-02", 113, 2)
	map:addTile("tile-background-ice-cave-art-02", 113, 3)
	map:addTile("tile-ground-ice-01", 113, 4)
	map:addTile("tile-rock-ice-big-01", 113, 5)
	map:addTile("tile-background-ice-01", 113, 9)
	map:addTile("tile-background-ice-big-01", 113, 10)
	map:addTile("tile-background-ice-01", 114, 0)
	map:addTile("tile-background-ice-03", 114, 1)
	map:addTile("tile-background-ice-07", 114, 2)
	map:addTile("tile-background-ice-07", 114, 3)
	map:addTile("tile-ground-ice-06", 114, 4)
	map:addTile("tile-background-ice-02", 114, 7)
	map:addTile("tile-background-ice-06", 114, 8)
	map:addTile("tile-background-ice-01", 114, 9)
	map:addTile("tile-background-ice-02", 115, 0)
	map:addTile("tile-background-ice-04", 115, 1)
	map:addTile("tile-background-ice-06", 115, 2)
	map:addTile("tile-background-ice-04", 115, 3)
	map:addTile("tile-rock-ice-left-05", 115, 4)
	map:addTile("tile-rock-ice-left-04", 115, 5)
	map:addTile("tile-rock-ice-left-05", 115, 6)
	map:addTile("tile-background-ice-cave-art-02", 115, 7)
	map:addTile("tile-background-ice-03", 115, 8)
	map:addTile("tile-background-ice-big-01", 115, 9)
	map:addTile("tile-background-ice-cave-art-01", 115, 11)
	map:addTile("tile-background-ice-08", 116, 0)
	map:addTile("tile-background-ice-02", 116, 1)
	map:addTile("tile-background-ice-06", 116, 2)
	map:addTile("tile-background-ice-03", 116, 3)
	map:addTile("tile-background-ice-01", 116, 4)
	map:addTile("tile-background-ice-06", 116, 5)
	map:addTile("tile-background-ice-cave-art-02", 116, 6)
	map:addTile("tile-background-ice-01", 116, 7)
	map:addTile("tile-background-ice-05", 116, 8)
	map:addTile("tile-background-ice-03", 116, 11)
	map:addTile("tile-background-ice-05", 117, 0)
	map:addTile("tile-background-ice-01", 117, 1)
	map:addTile("tile-background-ice-02", 117, 2)
	map:addTile("tile-background-ice-05", 117, 3)
	map:addTile("tile-background-ice-07", 117, 4)
	map:addTile("tile-background-ice-02", 117, 5)
	map:addTile("tile-background-ice-03", 117, 6)
	map:addTile("tile-background-ice-08", 117, 7)
	map:addTile("tile-background-ice-01", 117, 8)
	map:addTile("tile-rock-slope-ice-left-01", 117, 9)
	map:addTile("tile-rock-ice-big-01", 117, 10)
	map:addTile("tile-background-ice-01", 118, 0)
	map:addTile("tile-background-ice-02", 118, 1)
	map:addTile("tile-background-ice-04", 118, 2)
	map:addTile("tile-background-ice-05", 118, 3)
	map:addTile("tile-background-ice-05", 118, 4)
	map:addTile("tile-background-ice-03", 118, 5)
	map:addTile("tile-background-ice-06", 118, 6)
	map:addTile("tile-rock-slope-ice-left-01", 118, 7)
	map:addTile("tile-rock-ice-02", 118, 8)
	map:addTile("tile-rock-ice-01", 118, 9)
	map:addTile("tile-background-ice-03", 119, 0)
	map:addTile("tile-background-ice-03", 119, 1)
	map:addTile("tile-background-ice-02", 119, 2)
	map:addTile("tile-background-ice-01", 119, 3)
	map:addTile("tile-background-ice-08", 119, 4)
	map:addTile("tile-background-ice-01", 119, 5)
	map:addTile("tile-background-ice-cave-art-02", 119, 6)
	map:addTile("tile-ground-ice-03", 119, 7)
	map:addTile("tile-rock-ice-01", 119, 8)
	map:addTile("tile-rock-ice-03", 119, 9)
	map:addTile("tile-rock-ice-03", 119, 10)
	map:addTile("tile-rock-ice-02", 119, 11)
	map:addTile("tile-background-ice-07", 120, 0)
	map:addTile("tile-background-ice-06", 120, 1)
	map:addTile("tile-background-ice-02", 120, 2)
	map:addTile("tile-background-ice-07", 120, 3)
	map:addTile("tile-background-ice-02", 120, 4)
	map:addTile("tile-background-ice-03", 120, 5)
	map:addTile("tile-waterfall-ice-01", 120, 6)
	map:addTile("tile-rock-ice-big-01", 120, 8)
	map:addTile("tile-rock-ice-02", 120, 10)
	map:addTile("tile-rock-ice-01", 120, 11)
	map:addTile("tile-background-ice-06", 121, 0)
	map:addTile("tile-background-ice-07", 121, 1)
	map:addTile("tile-background-ice-01", 121, 2)
	map:addTile("tile-background-ice-07", 121, 3)
	map:addTile("tile-background-ice-01", 121, 4)
	map:addTile("tile-background-ice-02", 121, 5)
	map:addTile("tile-background-ice-06", 121, 6)
	map:addTile("tile-ground-ice-03", 121, 7)
	map:addTile("tile-rock-ice-03", 121, 10)
	map:addTile("tile-rock-ice-02", 121, 11)
	map:addTile("tile-background-ice-03", 122, 0)
	map:addTile("tile-background-ice-cave-art-02", 122, 1)
	map:addTile("tile-background-ice-02", 122, 2)
	map:addTile("tile-background-ice-02", 122, 3)
	map:addTile("tile-background-ice-08", 122, 4)
	map:addTile("tile-background-ice-01", 122, 5)
	map:addTile("tile-geyser-ice-01-active", 122, 6)
	map:addTile("tile-rock-ice-02", 122, 8)
	map:addTile("tile-rock-ice-01", 122, 9)
	map:addTile("tile-rock-ice-02", 122, 10)
	map:addTile("tile-rock-ice-01", 122, 11)
	map:addTile("tile-background-ice-06", 123, 0)
	map:addTile("tile-background-ice-07", 123, 1)
	map:addTile("tile-background-ice-05", 123, 2)
	map:addTile("tile-background-ice-08", 123, 3)
	map:addTile("tile-background-ice-cave-art-02", 123, 4)
	map:addTile("tile-ground-ice-06", 123, 5)
	map:addTile("tile-rock-ice-big-01", 123, 6)
	map:addTile("tile-rock-ice-03", 123, 8)
	map:addTile("tile-rock-ice-big-01", 123, 9)
	map:addTile("tile-rock-ice-02", 123, 11)
	map:addTile("tile-background-ice-08", 124, 0)
	map:addTile("tile-background-ice-05", 124, 1)
	map:addTile("tile-background-ice-big-01", 124, 2)
	map:addTile("tile-background-ice-04", 124, 4)
	map:addTile("tile-packagetarget-ice-01-idle", 124, 5)
	map:addTile("tile-rock-ice-02", 124, 8)
	map:addTile("tile-rock-ice-03", 124, 11)
	map:addTile("tile-background-ice-03", 125, 0)
	map:addTile("tile-background-ice-07", 125, 1)
	map:addTile("tile-background-ice-01", 125, 4)
	map:addTile("tile-ground-ice-06", 125, 5)
	map:addTile("tile-rock-ice-01", 125, 6)
	map:addTile("tile-rock-ice-02", 125, 7)
	map:addTile("tile-rock-ice-03", 125, 8)
	map:addTile("tile-rock-ice-01", 125, 9)
	map:addTile("tile-rock-ice-02", 125, 10)
	map:addTile("tile-rock-ice-01", 125, 11)
	map:addTile("tile-background-ice-04", 126, 0)
	map:addTile("tile-background-ice-05", 126, 1)
	map:addTile("tile-background-ice-05", 126, 2)
	map:addTile("tile-background-ice-04", 126, 3)
	map:addTile("tile-waterfall-ice-01", 126, 4)
	map:addTile("tile-rock-ice-03", 126, 6)
	map:addTile("tile-rock-slope-ice-right-02", 126, 7)
	map:addTile("tile-background-ice-cave-art-02", 126, 8)
	map:addTile("tile-background-ice-cave-art-02", 126, 9)
	map:addTile("tile-background-ice-05", 126, 10)
	map:addTile("tile-background-ice-08", 126, 11)
	map:addTile("tile-background-ice-08", 127, 0)
	map:addTile("tile-background-ice-01", 127, 1)
	map:addTile("tile-background-ice-07", 127, 2)
	map:addTile("tile-background-ice-02", 127, 3)
	map:addTile("tile-background-ice-03", 127, 4)
	map:addTile("tile-background-ice-03", 127, 5)
	map:addTile("tile-background-ice-06", 127, 6)
	map:addTile("tile-background-ice-cave-art-02", 127, 7)
	map:addTile("tile-background-ice-big-01", 127, 8)
	map:addTile("tile-background-ice-01", 127, 10)
	map:addTile("tile-background-ice-cave-art-02", 127, 11)
	map:addTile("tile-background-ice-04", 128, 0)
	map:addTile("tile-background-ice-01", 128, 1)
	map:addTile("tile-background-ice-05", 128, 2)
	map:addTile("tile-background-ice-01", 128, 3)
	map:addTile("tile-background-ice-03", 128, 4)
	map:addTile("tile-background-ice-01", 128, 5)
	map:addTile("tile-background-ice-01", 128, 6)
	map:addTile("tile-background-ice-06", 128, 7)
	map:addTile("tile-background-ice-01", 128, 10)
	map:addTile("tile-background-ice-01", 128, 11)
	map:addTile("tile-background-ice-01", 129, 0)
	map:addTile("tile-background-ice-01", 129, 1)
	map:addTile("tile-background-ice-05", 129, 2)
	map:addTile("tile-background-ice-05", 129, 3)
	map:addTile("tile-background-ice-08", 129, 4)
	map:addTile("tile-background-ice-02", 129, 5)
	map:addTile("tile-background-ice-02", 129, 6)
	map:addTile("tile-rock-slope-ice-left-01", 129, 7)
	map:addTile("tile-rock-ice-big-01", 129, 8)
	map:addTile("tile-rock-ice-big-01", 129, 10)
	map:addTile("tile-background-ice-cave-art-02", 130, 0)
	map:addTile("tile-background-ice-04", 130, 1)
	map:addTile("tile-background-ice-01", 130, 2)
	map:addTile("tile-background-ice-02", 130, 3)
	map:addTile("tile-background-ice-04", 130, 4)
	map:addTile("tile-background-ice-03", 130, 5)
	map:addTile("tile-background-ice-cave-art-02", 130, 6)
	map:addTile("tile-rock-slope-ice-right-01", 130, 7)
	map:addTile("tile-background-ice-01", 131, 0)
	map:addTile("tile-background-ice-01", 131, 1)
	map:addTile("tile-background-ice-03", 131, 2)
	map:addTile("tile-background-ice-01", 131, 3)
	map:addTile("tile-background-ice-04", 131, 4)
	map:addTile("tile-background-ice-03", 131, 5)
	map:addTile("tile-background-ice-02", 131, 6)
	map:addTile("tile-background-ice-02", 131, 7)
	map:addTile("tile-background-ice-01", 131, 8)
	map:addTile("tile-background-ice-01", 131, 9)
	map:addTile("tile-background-ice-07", 131, 10)
	map:addTile("tile-background-ice-08", 131, 11)
	map:addTile("tile-background-ice-08", 132, 0)
	map:addTile("tile-background-ice-05", 132, 1)
	map:addTile("tile-background-ice-08", 132, 2)
	map:addTile("tile-background-ice-01", 132, 3)
	map:addTile("tile-background-ice-07", 132, 4)
	map:addTile("tile-ground-ice-06", 132, 5)
	map:addTile("tile-rock-slope-ice-left-02", 132, 6)
	map:addTile("tile-background-ice-cave-art-02", 132, 7)
	map:addTile("tile-background-ice-08", 132, 8)
	map:addTile("tile-background-ice-01", 132, 9)
	map:addTile("tile-background-ice-06", 132, 10)
	map:addTile("tile-background-ice-06", 132, 11)
	map:addTile("tile-rock-slope-ice-left-02", 133, 0)
	map:addTile("tile-background-ice-02", 133, 1)
	map:addTile("tile-background-ice-03", 133, 2)
	map:addTile("tile-background-ice-02", 133, 3)
	map:addTile("tile-waterfall-ice-01", 133, 4)
	map:addTile("tile-rock-ice-big-01", 133, 6)
	map:addTile("tile-background-ice-04", 133, 8)
	map:addTile("tile-background-ice-07", 133, 9)
	map:addTile("tile-background-ice-01", 133, 10)
	map:addTile("tile-background-ice-02", 133, 11)
	map:addTile("tile-rock-ice-01", 134, 0)
	map:addTile("tile-rock-slope-ice-left-02", 134, 1)
	map:addTile("tile-background-ice-02", 134, 2)
	map:addTile("tile-background-ice-01", 134, 3)
	map:addTile("tile-background-ice-01", 134, 4)
	map:addTile("tile-ground-ice-01", 134, 5)
	map:addTile("tile-rock-slope-ice-left-02", 134, 8)
	map:addTile("tile-background-ice-01", 134, 9)
	map:addTile("tile-background-ice-02", 134, 10)
	map:addTile("tile-background-ice-06", 134, 11)
	map:addTile("tile-rock-ice-02", 135, 0)
	map:addTile("tile-rock-ice-big-01", 135, 1)
	map:addTile("tile-background-ice-01", 135, 3)
	map:addTile("tile-background-ice-01", 135, 4)
	map:addTile("tile-ground-ice-06", 135, 5)
	map:addTile("tile-rock-ice-03", 135, 6)
	map:addTile("tile-rock-ice-02", 135, 7)
	map:addTile("tile-rock-ice-02", 135, 8)
	map:addTile("tile-background-ice-06", 135, 9)
	map:addTile("tile-background-ice-05", 135, 10)
	map:addTile("tile-background-ice-03", 135, 11)
	map:addTile("tile-rock-ice-03", 136, 0)
	map:addTile("tile-background-ice-02", 136, 3)
	map:addTile("tile-background-ice-01", 136, 4)
	map:addTile("tile-ground-ice-03", 136, 5)
	map:addTile("tile-rock-ice-03", 136, 6)
	map:addTile("tile-rock-slope-ice-right-02", 136, 7)
	map:addTile("tile-background-ice-04", 136, 8)
	map:addTile("tile-background-ice-01", 136, 9)
	map:addTile("tile-background-ice-07", 136, 10)
	map:addTile("tile-background-ice-07", 136, 11)
	map:addTile("tile-rock-ice-big-01", 137, 0)
	map:addTile("tile-rock-slope-ice-right-02", 137, 2)
	map:addTile("tile-background-ice-big-01", 137, 3)
	map:addTile("tile-ground-ice-06", 137, 5)
	map:addTile("tile-rock-slope-ice-right-02", 137, 6)
	map:addTile("tile-background-ice-01", 137, 7)
	map:addTile("tile-background-ice-01", 137, 8)
	map:addTile("tile-background-ice-01", 137, 9)
	map:addTile("tile-background-ice-08", 137, 10)
	map:addTile("tile-background-ice-01", 137, 11)
	map:addTile("tile-background-ice-04", 138, 2)
	map:addTile("tile-rock-ice-left-04", 138, 5)
	map:addTile("tile-background-ice-01", 138, 6)
	map:addTile("tile-background-ice-08", 138, 7)
	map:addTile("tile-background-ice-06", 138, 8)
	map:addTile("tile-background-ice-02", 138, 9)
	map:addTile("tile-background-ice-02", 138, 10)
	map:addTile("tile-background-ice-04", 138, 11)
	map:addTile("tile-rock-slope-ice-right-02", 139, 0)
	map:addTile("tile-background-ice-cave-art-02", 139, 1)
	map:addTile("tile-background-ice-big-01", 139, 2)
	map:addTile("tile-background-ice-01", 139, 4)
	map:addTile("tile-background-ice-01", 139, 5)
	map:addTile("tile-background-ice-08", 139, 6)
	map:addTile("tile-background-ice-cave-art-02", 139, 7)
	map:addTile("tile-background-ice-01", 139, 8)
	map:addTile("tile-background-ice-big-01", 139, 9)
	map:addTile("tile-background-ice-cave-art-01", 139, 11)
	map:addTile("tile-background-ice-02", 140, 0)
	map:addTile("tile-background-ice-07", 140, 1)
	map:addTile("tile-background-ice-05", 140, 4)
	map:addTile("tile-background-ice-big-01", 140, 5)
	map:addTile("tile-background-ice-05", 140, 7)
	map:addTile("tile-background-ice-04", 140, 8)
	map:addTile("tile-background-ice-06", 140, 11)
	map:addTile("tile-background-ice-cave-art-01", 141, 0)
	map:addTile("tile-background-ice-03", 141, 1)
	map:addTile("tile-background-ice-02", 141, 2)
	map:addTile("tile-background-ice-cave-art-01", 141, 3)
	map:addTile("tile-background-ice-cave-art-01", 141, 4)
	map:addTile("tile-background-ice-02", 141, 7)
	map:addTile("tile-background-ice-03", 141, 8)
	map:addTile("tile-background-ice-05", 141, 9)
	map:addTile("tile-background-ice-02", 141, 10)
	map:addTile("tile-background-ice-cave-art-01", 141, 11)

	map:addEmitter("item-package-ice", 1, 3, 1, 0, "")
	map:addEmitter("item-stone", 2, 3, 1, 0, "")
	map:addEmitter("tree", 6, 5, 1, 0, "")
	map:addEmitter("npc-walking", 9, 1, 1, 0, "right=false")
	map:addEmitter("item-apple", 9, 6, 1, 0, "")
	map:addEmitter("npc-blowing", 17, 2, 1, 0, "right=false")
	map:addEmitter("npc-walking", 22, 3, 1, 0, "")
	map:addEmitter("item-apple", 27, 10, 1, 0, "")
	map:addEmitter("item-apple", 28, 9, 1, 0, "")
	map:addEmitter("tree", 39, 2, 1, 0, "")
	map:addEmitter("npc-blowing", 43, 3, 1, 0, "right=false")
	map:addEmitter("tree", 44, 8, 1, 0, "")
	map:addEmitter("npc-walking", 53, 4, 1, 0, "")
	map:addEmitter("tree", 61, 4, 1, 0, "")
	map:addEmitter("tree", 70, 1, 1, 0, "")
	map:addEmitter("item-package-ice", 70, 9, 1, 0, "")
	map:addEmitter("item-package-ice", 72, 2, 1, 0, "")
	map:addEmitter("npc-walking", 90, 7, 1, 0, "")
	map:addEmitter("tree", 94, 0, 1, 0, "")
	map:addEmitter("tree", 109, 8, 1, 0, "")
	map:addEmitter("npc-walking", 112, 3, 1, 0, "right=false")
	map:addEmitter("item-package-ice", 116, 9, 1, 0, "")
	map:addEmitter("npc-walking", 135, 4, 1, 0, "right=false")

	map:setSetting("width", "142")
	map:setSetting("height", "12")
	map:setSetting("fishnpc", "true")
	map:setSetting("flyingnpc", "true")
	map:setSetting("gravity", "9.81")
	map:setSetting("packagetransfercount", "2")
	map:addStartPosition("1", "3")
	map:setSetting("points", "100")
	map:setSetting("referencetime", "60")
	map:setSetting("sideborderfail", "true")
	map:setSetting("theme", "ice")
	map:setSetting("waterchangespeed", "0")
	map:setSetting("waterfallingdelay", "0")
	map:setSetting("waterheight", "1")
	map:setSetting("waterrisingdelay", "0")
	map:setSetting("wind", "4")
end
