l3d4r4drrddll6ulurrldrrurd8lddrulu4r3lddrdd3r6urul9drruulrddll6ulur5d5ldllul4u10rluudd9lddrurllu7r6l4d7r6u8drruulrddll6ulurd4lddlulu7rud5luu3ldu3r3d4lu7r3lddrdd3r5ud7ldd3ldllu4rdruulu7r3lddrdd3r4ulu3rld8ldd7ldr3d3ruluu3dll3uru4rdruulu7r3lddrdd3r4ulurrd8ldd6l4drr3ulu4rdruulu7r3lddrdd3r4ulurd7ldd6l3drdr3ulu4rdruulu7r3lddrdd3r4u7ldd5luulluurr4dldrlddrruulu4rdruulu8r7ldd5l4urrddlruull4dldrlddrruulu4rdruulu7r
