rdrurrdru3r2(drrur)d3rurrdrurrd2(dlddr)dldldlluld3lu3ld4lul2(ldllu)ur3uluurudrd3ru3rdrrurd4lduulldlddrllddlruulrudlullddrrdrulurl4dr3uluu3r3dlru3r3l4urrddlruu3lddll4druddrrurud3(ru)uldd4u4lddll5d3rurrdrr3u3drruulrddlluurrd4rurldllullruurdduulluluurdrrurd3rud4ldduulddldd3rdrr3u3l3r3dlluuddrr4udlldd3l3ulurdrrurrduru3rddldlrdlr3ululldlldll3d3rdd4r3uddrdrr3ullrr3dlluuddrr6ulldruruuruulldllrddluruu3rddldlrurdurrdlduull3drdul3uruu6ld8lu6l3dllddrr5d3rurrd5ruul3urrurrurrlldllulrdrruldldllu3r3l4d3rdd7ruu3ruuludrddlulrr3dlulrrululdll3uruuldrdrrdrdluull3urrddlrul3u6ldll3u8r5d5ulldrur4drrulrulluu8l3drru3rdrulddlululldlluruu5rdrrurdu5ldrurr3d3lud3r3ullddldr3urrdluldduu4l3drdul3u4rddldlduurruullddururdu4ldrur2(dlld)duu4lu6l3dllddrr5d3rurrd5ruul3uluurddrruruulduulldrurduuruulddrdldll3ururddulldd3l3urrdulld4rurd3lu4ld4rlldd3rddlddruuludludldrurrddllrr3drdd3luul3uruu2(lldr)4urdldrrl5u4ld3rur4dldr5u6ld5rur3duu3l3drdru3dr3drddllulld3l5urruurrurdrddlludrruulu2(lldr)ld4luu5rludllurrlluu3dllurruulddld3rldrl4uruulldduur4d4luu4ruulldrr3d4luurrllddrulurdd4rddlulu3ld4rlldrru4ld2(rr3d)ll6ulur5dlluurlddrr4uddlldrdr3uddrrdlrddll3u3druudd4rurrdrdd6l3u3dll4ulldrldruurrdr3dluudd3rulldlud7ruululldlrul3rdll3rdd3luurulrurdll3druuddrurulrruld4ruul3ullrr4drd4lruurldd3ruurr4dlluudrlu4lddrrudluud3rdrru4ldlu3rd4ru4l3ruuldrdlldl2(urru)lrdrdldlu4rulld5rlururrdd8l6ruurd3lurrdrruuldldd4luurlddllddrruudldlud4ruldlururddrruullddruluuru3rddlulrruuldrdl
