3drddrrddldllurrdrrdrdruu3l4u3dllddrulurd5ruuldrd4l3ul3urrdlrdllr3dllddrulurd8rddluru7l3ulur3dllddrulurdr5urulld4urrd4rurrdl8drddluru7lullddrulurd4ruuldrd3l5ul4urrd4rur8d7u5lull4drrul5dllddrulurdr5ulur6d5rdrrul8u5lulldduurrd5r8d6l5u3l3url3d3rdd3luu3r4d3luu3ruu5l3drl3u5rdd3lud3rdd3lull3u4r4l3drruud3ruudd3ldll3u4rll4drddrulurd7r8u5lulldlldduurrurrd5r8d6l3u3ldll3urr
