textures = {
	["deadlock-middle-01"] = {
		image = "cavepacker-environment-small",
		x0 = 0,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["target-back-01"] = {
		image = "cavepacker-environment-small",
		x0 = 0,
		y0 = 0.25,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-background-01-back-01"] = {
		image = "cavepacker-environment-small",
		x0 = 0,
		y0 = 0.5,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-background-02-back-01"] = {
		image = "cavepacker-environment-small",
		x0 = 0,
		y0 = 0.75,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-background-03-back-01"] = {
		image = "cavepacker-environment-small",
		x0 = 0.25,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-background-04-back-01"] = {
		image = "cavepacker-environment-small",
		x0 = 0.5,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-reference"] = {
		image = "cavepacker-environment-small",
		x0 = 0.75,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-rock-01-back-01"] = {
		image = "cavepacker-environment-small",
		x0 = 0.75,
		y0 = 0,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-rock-02-back-01"] = {
		image = "cavepacker-environment-small",
		x0 = 0.25,
		y0 = 0.25,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tile-rock-03-back-01"] = {
		image = "cavepacker-environment-small",
		x0 = 0.25,
		y0 = 0.5,
		x1 = 0.25,
		y1 = 0.25,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
}
