3ldrr4lddrulurruruuldlddrulurddllddruururrdldlrdlr3uluurdlddrddl3udlldrrurrurrd4ldllurruruuldlddrulurdrrdrru4ldrlddruu3ldr2(r3uld)dr3dllurdruudrrurrd4lurrlluluurdrdulldr3dllurdr3uldd3rulluluurdrdulldrddrruldlluururdllddrudrruluululdrr3dlluruddrruld3ruld3lddrululldr
