3r3l3dr3(ru)dldldll3u3rurlddrurudlluru5r5luuluurdu4luu4rdrrurrdrr7dldrrluurr5dld3rurdl4u4l3u6lddruluuluur3d5r4lddllurdruluul3u3luu4rdrrurrdrr7dldrrluurr5dld3r4u4l8ullulldll5d5r5l5urrurrdrr7dldrrluurr4duull3u5lddllurdrul5u3lddrrur3d5r5l5urrurrdrr7dld4rluurr5dlldlur3ull3u5lddllurdrul7ulldrur6d5r5l5urrurrd3l5r7dldrrluurr4durrdd2(ll3u)5lddllurdruluul5ur6d5r5l5u6r7dld4rluurr4du3rdd3l3u4l3u5lddllurdrulu5r5l5u6r7dld4rluurr4duu4l3u5ldll3dluddlluurur2(rdrulu)5r5l5u6r7dld4rluurrddld3rurddrdllr3u7l3u5ldll3dlulur2(rdrulu)5r5l5u6r7dld4rluurrddld3rurdduu7l3u5ldd3l3dluulu3rdrulurdrulu5r5l5u6r7dld4rluurrddld3ru6l3u5ldd4l5drur3u2(lurdru)lu5r5l5u6r7dld4rluurrddldrru5l3u5ldll5dl3ulur2(rdrulu)5r5l5u6r7dld4r3l3u5ldd3l5d3lur3drrur5u2(lurdru)lu5r5l5u6r7dldrrluu4r3dll3ullu5ldll7dl5ulur2(rdrulu)5r5l5u6r7dld4rluurrddrdlu3rdlrrddlurulu7l3u5ldll6dll4ulu3rdrulurdrulu5r4ldll8dll6ulu3rdrulurdrul6u6r7dld4r3l8u4ldlul5d5r5l5u6r7dldrrluurr5d3ull3u5lddllurdrul3u3lurrur4d5r5l5u6r7dldrrluurr4duull3u5lddllurdrul3u3luurrur5d5r5l5u6r7dldrrluurr3dull3u5lddllurdrul5u4lu3rur6d5r5l5u6r7dldrrluurrddll3u5lddllurdrul7u6ld5rur6d5r5l5u6r4d2(rrdd)uulluull3dld4r3l3u5lddllurdrul3u4lulu4rur5d5r5l5u6r7dld3rll3u5lddllurdrul7u6ld5rur6d5r5l5u6r7dldrrl3u5lddllurdrulu5r5l5u6r7dldr
