d9l4dlddru3rd5rdrurrdd3rulu4ldluudruullrdd3rddruru4ldl3uru3lu3r4drrd5ruuld6ldl4urullr4dllddlluluu3ldd3ru5rdruudrrdd4ruru7ldl3urullr3d4ruurdlddrru5ldl4urul4d5lu3l4ulu6rurrd4rdrdr3dlddrru5ldl4u3dllddllulurru4ldld3ru5rdru4r4ululururrdr5drd7ldl3u2(ddll)u3lullururddld3ru8rdrru4ldluudr3ulrd2(lddl)lu4l5u3r4dullddrru5rdr3udd4r4uluur5dlddrru5ldl3u2(ddll)u4l7u3r6dullddrru5rdruud6r6ulul6dlddrru5ldluud5l6u9rur6dlddrru5ldlullddllulu5rdru
